## TreeCLA1-RCode-2024-FFGC.R
## Rebecca M. Dalton, Jesse N. Miller, Tara Greaver, Robert D. Sabo, Kemen G. Austin, Jennifer N. Phelan, R. Quinn Thomas,5, Christopher M. Clark

## Code for compiling data and analysis for:
## "Drivers of regional variation of growth and survival responses to atmospheric nitrogen and sulfur deposition for 140 tree species in the U.S."

## Code created by RMD and JNM
## Last updated: 08282024 by RMD:
##   1. figures updated for resubmission
##   2. RMD found issue with model selection (section 5)
##      the orignal dataframe was dated with 2023 and new update 2024
##      see new section at the end of this file that compares outputs between the
##      two data files
##              

## Data files needed:
## 1. TreeCLA1_finalmodeloutputs_2021.xlsx: Final model outputs 
##    from RTI International - file includes all A1 results
## 2. Jo2019_data_tree_sp_myc_type.xlsx: mycorrhizal association data from Jo et al., 
##    2019 received file via email to C. Clark 
## 3. DIVISION_fia_forestdivision_temp_precip_pH_with species_ALL SPP.csv: 
##    division climate data downloaded by R. Dalton on 14 Jan. 2022. This file was created 
##    by R. Sabo and C. Clark
## 4. CONUS_fia_forestdivision_temp_precip_pH_with species_ALL SPP.csv: 
##    CONUS climate data downloaded by R. Dalton on 14 Jan. 2022. This file was created 
##    by R. Sabo and C. Clark
## 5. Horn2018_SpeciesList.csv : phenology type (E or D) and the number of species in 
##    Horn (2018). Adapted from Supplemental File 1 in Horn et al., 
##    2018 on 25 Jan 2022
## 6. Kattge2020_decid.txt: Kattge, J, Boenisch, G, Diaz, S, et al. TRY plant trait database - 
##    enhanced coverage and open access. Glob Change Biol. 2020; 26: 119-188. 
##    https://doi.org/10.1111/FFGC.14904 as the TRY reference. RMD downloaded this 
##    file from TRY database.
## 7. EcoMapDivisions_centroids_Table.xlsx: Data file which includes centroid points
##    for divisions. Created by J. Miller.
## 8. Map_Divisions.png: outline of division map from USFS    
## 9. Potterwoodall2012_phylogenetic.txt: Phylogenetic supertree file from Potter, K. M., & 
##    Woodall, C. W. (2012). Trends over time in tree and seedling phylogenetic 
##    diversity indicate regional differences in forest biodiversity change. 
##    Ecological Applications, 22(2), 517-531.      

## The final data frame produced from this code, "TreeCLA1_combined_df_FFGC_2024.xlsx" and is used in
## ordinal regressions for the manuscript

## Start at lines 1117 for analysis & visualizations
## after adding packages and setting working directory

################################################################################
# PART 1. SELECTING MODELS FROM ORIGINAL OUTPUT FILES FROM RTI
################################################################################
# 1. Set working directory
################################################################################

rm(list=ls())
# wd <- # set your working directory here
# setwd(wd)
# getwd()

options(scipen = 100)

################################################################################
# 2. Install and load the packages
################################################################################

packages <- c("devtools", # for rtools
              "readxl", # reading in excel data
              "png", # reading in PNG for maps
              "tidyverse", # data clean, format, visuals 
              "reshape2", # the melt() function
              "gtools", # smartbind() function
              "lme4", # mixed effects models
              "corrplot", # creating a correlation matrix
              "Hmisc", # exporting correlation coefficients
              "multcomp", # tukey's and compact letter display
              "rcompanion", # fisher's exact test
              "rstatix", # fisher's exact test (double check results)
              "nnet", # multinomial modeling
              "stargazer", # for creating tables of model outputs
              "sjPlot", # plotting ordinal model outputs
              "ggeffects", # plotting ordinal and multinomial model outputs
              "performance", # model performance
              "generalhoslem", # testing goodness of fit for ordinal and multinom
              "car", # companion to applied regression
              "arsenal", # comparedf() function
              "MuMIn", # AIC score
              "effects", # plotting predictions from polr
              "phytools", # reading in a phylo tree
              "caper", # phylogenetic analysis
              "phyr", # phylogenetic regression
              "sure", # needed for phylogenetic analysis - calculate residuals
              "ggtext", # rmarkdown axis labels for bolding
              "RColorBrewer", # for colors
              "wesanderson", # wes anderson color palette
              "MetBrewer", # metBrewer color palette
              "gdata", # reordering factors
              "ggpubr", # arranging plots
              "gt", # create formatted tables
              "gridExtra", # arranging plots
              "patchwork", # arranging plots 
              "cowplot") # arranging plots 
install.packages(setdiff(packages, rownames(installed.packages())))

library(devtools)
library(readxl)
library(png)
library(tidyverse)
library(reshape2)
library(lme4)
library(corrplot)
library(Hmisc)
library(gtools)
library(multcomp)
library(rcompanion)
library(rstatix)
library(nnet)
library(sjPlot)
library(stargazer)
library(ggeffects)
library(performance)
library(generalhoslem)
library(car)
library(arsenal)
library(MuMIn)
library(effects)
library(phytools)
library(caper)
library(phyr)
library(sure)
library(ggtext)
library(wesanderson)
library(RColorBrewer)
library(MetBrewer)
library(gdata)
library(ggpubr)
library(gridExtra)
library(gt)
library(patchwork)

################################################################################
# 3. Load the survival and growth data
################################################################################

# TreeCLA1_finalmodeloutputs_2021.xlsx: full/all model data and parameters 
# for the A1 (deposition models) and A2 (deposition + ozone models) 
# growth and survival models

# import the Excel file: 
# (make sure the file is closed on your computer or it will not load)

# set your own path here

path <- "C:/Users/rdalton/OneDrive - Environmental Protection Agency (EPA)/Profile/Documents/Projects/TreeCLA1/Manuscript/FFGC submission/Data and R code/data_Rcode_regionaltree/TreeCLA1_finalmodeloutputs_2021.xlsx"

path %>% readxl::excel_sheets() # view of tab names in Excel file

surv.conus.data <- read_excel(path, sheet = "SurvivalCONUS")
surv.conus.data$division <- "CONUS" # CONUS does not have a division associated
surv.conus.data$process <- "survival" # need to add a new column to indicate surv
dim(surv.conus.data) #[1] 2774  179

surv.div.data <- read_excel(path, sheet = "SurvivalDIV")
surv.div.data$process <- "survival" # add new column to indicate surv
dim(surv.div.data) #[1] 3932  179

# create a single df for survival data
surv.data <- rbind(surv.conus.data, surv.div.data)

#str(surv.data)
surv.data[surv.data == "NA"] <- NA

grow.conus.data <- read_excel(path, sheet = "GrowthCONUS")
grow.conus.data$division <- "CONUS"
grow.conus.data$process <- "growth"
dim(grow.conus.data) #[1] 1410  139

grow.div.data <- read_excel(path, sheet = "GrowthDIV")
grow.div.data$process <- "growth"
dim(grow.div.data) #[1] 2410  139

# create a single df for growth data
grow.data <- rbind(grow.conus.data, grow.div.data)
dim(grow.data) #[1] 3820  139

#str(grow.data)
grow.data[grow.data == "NA"] <- NA

################################################################################
# 4. First, format the N and S parameters
################################################################################

# Use the code below to pull out a single species 
# division1 <- "25"
# spcd1 <- 552
# spcd1 <- 15

# First, we need to clean the parameters used in assigning shapes
# Since the data were originally compiled in Microsoft Excel,
# some of the values are in scientific notation and for some reason
# R isn't able to easily convert them. We are therefore splitting
# these values into "base" and "multiplier" and creating "updated" 
# versions of each parameter (n1, npluss1, s1|, and s1T)

surv.param.updates <- 
  as.data.frame(
    surv.data %>%
      dplyr::mutate(model.shorthand = gsub("+", "plus", model.shorthand, fixed = TRUE)) %>%
      # use the row below for a specific species
      # filter(spcd == spcd1) %>% 
      # N and S parameters are class "character" with sci notation - 
      # Nitrogen (n1)
      # this is the long way of converting to numeric
      tidyr::separate(n1, c("n1.base", "n1.multiplier"), 
                      sep = "E", remove = FALSE, 
                      convert = TRUE, fill = "right") %>% 
      #this will turn all "NA" into 0
      dplyr::mutate(n1.multiplier = coalesce(n1.multiplier, 0)) %>% 
      # n.multiplier = 0 equivalent to 1
      dplyr::mutate(n1.updated = (n1.base * 10^(n1.multiplier))) %>% 
      # constrained sulfur (s1| and s1T)
      dplyr::rename(s1bar = s1l) %>% 
      tidyr::separate(s1bar, c("s1bar.base", "s1bar.multiplier"), 
                      sep = "E", remove = FALSE, 
                      convert = TRUE, fill = "right") %>% 
      dplyr::mutate(s1bar.multiplier = coalesce(s1bar.multiplier, 0)) %>% 
      dplyr::mutate(s1bar.updated = (s1bar.base * 10^(s1bar.multiplier))) %>% 
      tidyr::separate(s1T, c("s1T.base", "s1T.multiplier"), 
                      sep = "E", remove = FALSE, 
                      convert = TRUE, fill = "right") %>% 
      dplyr::mutate(s1T.multiplier = coalesce(s1T.multiplier, 0)) %>% 
      dplyr::mutate(s1T.updated = (s1T.base * 10^(s1T.multiplier))) %>% 
      # full model
      tidyr::separate(npluss1, c("npluss1.base", "npluss1.multiplier"), 
                      sep = "E", remove = FALSE, 
                      convert = TRUE, fill = "right") %>% 
      dplyr::mutate(npluss1.multiplier = coalesce(npluss1.multiplier, 0)) %>% 
      dplyr::mutate(npluss1.updated = (npluss1.base * 10^(npluss1.multiplier))) %>%
      # convert n2, s2, s2T, and s3T from character to numeric
      dplyr::mutate(n2 = as.numeric(as.character(n2))) %>%
      dplyr::mutate(s2 = as.numeric(as.character(s2))) %>%
      dplyr::mutate(s2T = as.numeric(as.character(s2T))) %>%
      dplyr::mutate(s3T = as.numeric(as.character(s3T))) %>%
      #dplyr::mutate(across(c("n1.updated","s1bar.updated", "s1T.updated",
      #                       "npluss1.updated"), ~na_if(., ""))) %>%
      dplyr::arrange(spcd, division, AIC) %>%  
      dplyr::select(c("spcd", "GENUS", "SPECIES", "division", "sample.size",
                      "CorNS", "AIC", "dAIC", "min.AIC", "model.shorthand", 
                      "n1.updated", "n2",
                      "s1bar.updated",  "s2",
                      "s1T.updated","s2T", "s3T",
                      "npluss1.updated", 
                      "MinN", "MaxN", "MinS", "MaxS", "MinNS", "MaxNS",
                      "AvgN", "AvgS", "AvgNS", "AvgT", "AvgP", "process")))

str(surv.param.updates)
dim(surv.param.updates) #[1] 6706   30

################################################################################
# 5. Select the "best" model to use in analysis
################################################################################

# Steps in the surv.topmods data frame creation section below:
# 1 - Group data by species and division
# 2 - In the model.shorthand column, change "+" to "plus" to make 
#     calling the model name easier
# 3 - Use the model.shorthand column to select for all models without "unconstrained"
#     sulfur models. These are not biologically relevant. We will have to
#     recalculate dAIC after removing these models (step 5 below)
# 4 - If the model.shorthand column = "NplusS", then fill a newly created 
#     variable ("model.type") with "npluss".  Otherwise, fill it with "preferred".
#     We added this step because npluss models are not preferred unless other
#     conditions are not met (e.g. CorNS > 0.4)
# 5 - Since we removed unconstrained sulfur models, we need to create a new 
#     variable ("new.min.AIC") and fill it with the new calculated min.AIC 
#     for each div x spcd.
# 6 - Create a new variable ("new.dAIC") and fill it with the difference between
#     the original AIC and the new AIC (AIC - new.min.AIC).
# 7 - Sort the rows from high to low AIC to facilitate adding a "rank" column.
# 8 - Create a new variable ("mod.type.list") and fill it with a ranked list of all
#     the model types (the first 5 models only) in that div x spcd.
# 9 - Create a new variable ("new.dAIC.list") and fill it with the new.dAIC
#     values calculated in step 7. This will allow us to determine if the second
#     model is a good option when the first is an npluss model.
# 10 -Select for only models ranked #1.  # NOTE: Currently ranks 1 -> 3.
# 11 -Retain only that list of variables in the surv.topmodels data frame.

surv.topmods <- 
  as.data.frame(
    surv.param.updates %>%
      # use the row below for a specific species
      # dplyr::filter(spcd == spcd1 & division == division1) %>% 
      dplyr::group_by(spcd, division) %>%
      dplyr::filter(!stringr::str_detect(model.shorthand,"unconstrained")) %>%
      dplyr::mutate(model.type = if_else(str_detect(model.shorthand, 
                                                    "NplusS"),"npluss","preferred")) %>%
      dplyr::mutate(new.min.AIC = min(AIC)) %>%
      dplyr::mutate(new.dAIC = AIC - new.min.AIC) %>%
      dplyr::arrange(AIC) %>%
      dplyr::mutate(mod.type.list = toString(model.type[1:3]), 
                    rank = 1:n()) %>%
      dplyr::mutate(new.dAIC.list = toString(new.dAIC[1:3])) %>%
      dplyr::mutate(model.shorthand.list = toString(model.shorthand[1:3])) %>%
      dplyr::filter(rank <= 3) %>%
      dplyr::arrange(spcd, division))

dim(surv.topmods) #[1] 1242   37

# Below, we are trying to add new columns for the top three models
# for every spcd x division
# This step facilitates model selection

surv.parsed.split <- 
  as.data.frame(
    surv.topmods %>%
      dplyr::filter(rank == 1) %>%
      tidyr::separate(new.dAIC.list, c("First_new.dAIC", 
                                       "Second_new.dAIC", 
                                       "Third_new.dAIC"),
                      sep = "[,]+", remove = FALSE, 
                      convert = TRUE, extra = "warn", fill = "warn") %>%
      tidyr::separate(model.shorthand.list, c("First_ModelName", 
                                              "Second_ModelName", 
                                              "Third_ModelName"),
                      sep = "[,]+", remove = FALSE, 
                      convert = TRUE, extra = "warn", fill = "warn") %>%
      tidyr::separate(mod.type.list, c("First_ModelType", 
                                       "Second_ModelType", 
                                       "Third_ModelType"),
                      sep = "[,]+", remove = FALSE, 
                      convert = TRUE, extra = "warn", fill = "warn") %>%
      dplyr::mutate(across(where(is.character), str_trim)))

colnames(surv.parsed.split)
dim(surv.parsed.split) # [1] 414  46

# Quickly double check the data to make sure the dimensions are correct
# Calculate the total number of spcd x div: 

Num_spcdXDiv_actual = dim(unique(surv.parsed.split[c("spcd","division")]))[1] 

if (Num_spcdXDiv_actual != dim(surv.parsed.split)[1]) {
  print("**NOTICE: The number of Spcd X Div from surv.parsed.split DOES NOT EQUAL number of obs in surv.parsed.split!")
  break
}

Num_spcdXDiv_actual # 414

# Here is where we select the "best" model for each spcd x division
# according to the following conditions:

# If the N+S model is not the best, 
# use best model.

# If the N+S model is the best, and if:

# The N-S correlation is weak (<0.4) and 
# the dAIC is low (<4.0), use the next best non-N+S model. 

# The N-S correlation is strong (>0.7) and the dAIC is 
# high (>4.0), we cannot confidently separate out N-effects 
# from S-effects using an observational study for this 
# species and Division, use the N+S model.

BestModelSurv = c()
for(i in 1:dim(surv.parsed.split)[1]){
  print(paste("SPCD:", surv.parsed.split$spcd[i], "& Division:", surv.parsed.split$division[i]))
  # print(paste("First_ModelType:", surv.parsed.split$First_ModelType[i]))
  # print(paste("CorNS:", surv.parsed.split$CorNS[i]))
  # print(paste("First_new.dAIC:", surv.parsed.split$First_new.dAIC[i]))
  if (surv.parsed.split$First_ModelType[i] != "npluss") {
    print('The initial best model is NOT NplusS.')
    print(paste("So use the initial best model, which is:", surv.parsed.split$First_ModelName[i]))
    BestModelSurv[i] = surv.parsed.split$First_ModelName[i]
  }
  else if (surv.parsed.split$First_ModelType[i] == "npluss" & 
           surv.parsed.split$CorNS[i] > 0.4) {
    print('The initial best model is NplusS but CorNS > 0.4 so we cannot confidently separate out N-effects from S-effects.')
    print(paste("So use the initial best model, which is:", surv.parsed.split$First_ModelName[i]))
    BestModelSurv[i] = surv.parsed.split$First_ModelName[i]
  }
  else if (surv.parsed.split$First_ModelType[i] == "npluss" & 
           surv.parsed.split$CorNS[i] <= 0.4 & 
           surv.parsed.split$Second_new.dAIC[i] > 4.0) { # this line originally said "surv.parsed.split$First_new.dAIC[i] > 4.0" which was a mistake
    print('The initial best model is NplusS, CorNS <= 0.4, and dAIC > 4. We cannot confidently separate out N-effects from S-effects so use the N+S model.')
    print(paste("So use the initial best model, which is:", surv.parsed.split$First_ModelName[i]))
    BestModelSurv[i] = surv.parsed.split$First_ModelName[i]
  }
  else if (surv.parsed.split$First_ModelType[i] == "npluss" & 
           surv.parsed.split$CorNS[i] <= 0.4 & 
           surv.parsed.split$Second_new.dAIC[i] <= 4.0 & 
           surv.parsed.split$Second_ModelType[i] != "npluss") {
    print('The initial best model is NplusS, CorNS <= 0.4, dAIC <= 4, and the rank #2 model is not NplusS...')
    print(paste("So use the second-best model, which is:", surv.parsed.split$Second_ModelName[i]))
    print('****ATTENTION ATTENTION ATTENTION! WE ARE USING THE SECOND-BEST MODEL!!')
    BestModelSurv[i] <- surv.parsed.split$Second_ModelName[i]
  }
  else if (surv.parsed.split$First_ModelType[i] == "npluss" & 
           surv.parsed.split$CorNS[i] <= 0.4 & 
           surv.parsed.split$Second_new.dAIC[i] <= 4.0 & 
           surv.parsed.split$Second_ModelType[i] == "npluss") {
    print("!No model found...REPEAT STEPS!")
  }
}

# Now that we have the "BestModel" for each spcd x division,
# we need to add this back to our original df.
# We can do this by creating a dataframe that we will merge with
# surv.param.updates

surv.parsed.split$BestModelSurv <- BestModelSurv

surv.BestModelOnly <-
  as.data.frame(
    surv.parsed.split %>%
      dplyr::select(c("spcd", "division", "BestModelSurv")) %>%
      dplyr::rename(model.shorthand = BestModelSurv)) # need to rename for merge

surv.selected.mods <- merge(surv.BestModelOnly, surv.topmods, 
                            by = c("spcd", "division", "model.shorthand"), all.x = TRUE, all.y = F)
dim(surv.selected.mods) # [1] 414  37

################################################################################
# 6. Now, assign the shapes based on N and S parameters
################################################################################

surv.shapes <- 
  as.data.frame(
    surv.selected.mods %>%    
      # NITROGEN:
      #   decreaser: when n1 term is less than the minimum N [n1 < minN]
      #   increaser: n1 is greater than or equal to the maximum N [n1 > maxN]
      #   unimodal: n1 between the min N and the max N [minN < n1 < maxN]
      #   flat: n1 = NA 
      dplyr::mutate("N.shape" = case_when(
        n1.updated < MinN ~ "decrease", 
        n1.updated >= MaxN ~ "increase",
        n1.updated < MaxN & n1.updated > MinN ~ "unimodal",
        is.na(n1.updated) & is.na(npluss1.updated) ~ "flat")) %>%
      # SULFUR (s1| and s1T)
      dplyr::mutate("S.shape" = case_when(
        s1bar.updated <= MinS ~ "decrease", 
        s1bar.updated >= MaxS ~ "increase",
        is.na(s1bar.updated) & is.na(s1T.updated) &
          is.na(npluss1.updated) ~ "flat",
        s1T.updated >= 0 ~ "tabletop")) %>%
      # NITROGEN AND SULFUR
      dplyr::mutate("NS.shape" = case_when(
        npluss1.updated < MinNS ~ "decrease", 
        npluss1.updated >= MaxNS ~ "increase",
        npluss1.updated < MaxNS & 
          npluss1.updated > MinNS ~ "unimodal")))

dim(surv.shapes) #[1] 414  40

################################################################################
# 7. Repeat steps 4 - 6 for the growth data frames
#    First, format the N and S parameters
################################################################################

# Use the code below to pull out a single species 
# division1 <- "25"
# spcd1 <- 552
# spcd1 <- 15

# First, we need to clean the parameters used in assigning shapes
# Since the data were originally compiled in Microsoft Excel,
# some of the values are in scientific notation and for some reason
# R isn't able to easily convert them. We are therefore splitting
# these values into "base" and "multiplier" and creating "updated" 
# versions of each parameter (n1, npluss1, s1|, and s1T)

grow.param.updates <- 
  as.data.frame(
    grow.data %>%
      dplyr::mutate(model.shorthand = gsub("+", "plus", model.shorthand, fixed = TRUE)) %>%
      # use the row below for a specific species
      # filter(spcd == spcd1) %>% 
      # N and S parameters are class "character" with sci notation - 
      # Nitrogen (n1)
      # this is the long way of converting to numeric
      tidyr::separate(n1, c("n1.base", "n1.multiplier"), 
                      sep = "E", remove = FALSE, 
                      convert = TRUE, fill = "right") %>% 
      #this will turn all "NA" into 0
      dplyr::mutate(n1.multiplier = coalesce(n1.multiplier, 0)) %>% 
      # n.multiplier = 0 equivalent to 1
      dplyr::mutate(n1.updated = (n1.base * 10^(n1.multiplier))) %>% 
      # constrained sulfur (s1| and s1T)
      dplyr::rename(s1bar = s1l) %>% 
      tidyr::separate(s1bar, c("s1bar.base", "s1bar.multiplier"), 
                      sep = "E", remove = FALSE, 
                      convert = TRUE, fill = "right") %>% 
      dplyr::mutate(s1bar.multiplier = coalesce(s1bar.multiplier, 0)) %>% 
      dplyr::mutate(s1bar.updated = (s1bar.base * 10^(s1bar.multiplier))) %>% 
      tidyr::separate(s1T, c("s1T.base", "s1T.multiplier"), 
                      sep = "E", remove = FALSE, 
                      convert = TRUE, fill = "right") %>% 
      dplyr::mutate(s1T.multiplier = coalesce(s1T.multiplier, 0)) %>% 
      dplyr::mutate(s1T.updated = (s1T.base * 10^(s1T.multiplier))) %>% 
      # full model
      tidyr::separate(npluss1, c("npluss1.base", "npluss1.multiplier"), 
                      sep = "E", remove = FALSE, 
                      convert = TRUE, fill = "right") %>% 
      dplyr::mutate(npluss1.multiplier = coalesce(npluss1.multiplier, 0)) %>% 
      dplyr::mutate(npluss1.updated = (npluss1.base * 10^(npluss1.multiplier))) %>%
      # convert n2, s2, s2T, and s3T from character to numeric
      dplyr::mutate(n2 = as.numeric(as.character(n2))) %>%
      dplyr::mutate(s2 = as.numeric(as.character(s2))) %>%
      dplyr::mutate(s2T = as.numeric(as.character(s2T))) %>%
      dplyr::mutate(s3T = as.numeric(as.character(s3T))) %>%
      #dplyr::mutate(across(c("n1.updated","s1bar.updated", "s1T.updated",
      #                       "npluss1.updated"), ~na_if(., ""))) %>%
      dplyr::arrange(spcd, division, AIC) %>%  
      dplyr::select(c("spcd", "GENUS", "SPECIES", "division", "sample.size",
                      "CorNS", "AIC", "dAIC", "min.AIC", "model.shorthand", 
                      "n1.updated", "n2",
                      "s1bar.updated",  "s2",
                      "s1T.updated","s2T", "s3T",
                      "npluss1.updated", 
                      "MinN", "MaxN", "MinS", "MaxS", "MinNS", "MaxNS",
                      "AvgN", "AvgS", "AvgNS", "AvgT", "AvgP", "process")))

str(grow.param.updates)
dim(grow.param.updates) #[1] 3820   30

################################################################################
# 8. Select the "best" model to use in analysis
################################################################################

grow.topmods <- 
  as.data.frame(
    grow.param.updates %>%
      # use the row below for a specific species
      # dplyr::filter(spcd == spcd1 & division == division1) %>% 
      dplyr::group_by(spcd, division) %>%
      dplyr::filter(!stringr::str_detect(model.shorthand,"unconstrained")) %>%
      dplyr::mutate(model.type = if_else(str_detect(model.shorthand, 
                                                    "NplusS"),"npluss","preferred")) %>%
      dplyr::mutate(new.min.AIC = min(AIC)) %>%
      dplyr::mutate(new.dAIC = AIC - new.min.AIC) %>%
      dplyr::arrange(AIC) %>%
      dplyr::mutate(mod.type.list = toString(model.type[1:3]), 
                    rank = 1:n()) %>%
      dplyr::mutate(new.dAIC.list = toString(new.dAIC[1:3])) %>%
      dplyr::mutate(model.shorthand.list = toString(model.shorthand[1:3])) %>%
      dplyr::filter(rank <= 3) %>%
      dplyr::arrange(spcd, division))

dim(grow.topmods) #[1] 1146   37

# Below, we are trying to add new columns for the top three models
# for every spcd x division
# This step facilitates model selection

grow.parsed.split <- 
  as.data.frame(
    grow.topmods %>%
      dplyr::filter(rank == 1) %>%
      tidyr::separate(new.dAIC.list, c("First_new.dAIC", 
                                       "Second_new.dAIC", 
                                       "Third_new.dAIC"),
                      sep = "[,]+", remove = FALSE, 
                      convert = TRUE, extra = "warn", fill = "warn") %>%
      tidyr::separate(model.shorthand.list, c("First_ModelName", 
                                              "Second_ModelName", 
                                              "Third_ModelName"),
                      sep = "[,]+", remove = FALSE, 
                      convert = TRUE, extra = "warn", fill = "warn") %>%
      tidyr::separate(mod.type.list, c("First_ModelType", 
                                       "Second_ModelType", 
                                       "Third_ModelType"),
                      sep = "[,]+", remove = FALSE, 
                      convert = TRUE, extra = "warn", fill = "warn") %>%
      dplyr::mutate(across(where(is.character), str_trim)))

colnames(grow.parsed.split)
dim(grow.parsed.split) # [1] 382  46

# Quickly double check the data to make sure the dimensions are correct
# Calcualate the total number of spcd x div: 

Num_spcdXDiv_actual_grow = dim(unique(grow.parsed.split[c("spcd","division")]))[1] 

if (Num_spcdXDiv_actual_grow != dim(grow.parsed.split)[1]) {
  print("**NOTICE: The number of Spcd X Div from grow.parsed.split DOES NOT EQUAL number of obs in grow.parsed.split!")
  break
}

Num_spcdXDiv_actual_grow # [1] 382

# Here is where we select the "best" model for each spcd x division
# according to the following conditions:

# If the N+S model is not the best, 
# use best model.

# If the N+S model is the best, and if:

# The N-S correlation is weak (<0.4) and 
# the dAIC is low (<4.0), use the next best non-N+S model. 

# The N-S correlation is strong (>0.7) and the dAIC is 
# high (>4.0), we cannot confidently separate out N-effects 
# from S-effects using an observational study for this 
# species and Division, use the N+S model.

BestModelGrow = c()
for(i in 1:dim(grow.parsed.split)[1]){
  print(paste("SPCD:", grow.parsed.split$spcd[i], "& Division:", grow.parsed.split$division[i]))
  # print(paste("First_ModelType:", grow.parsed.split$First_ModelType[i]))
  # print(paste("CorNS:", grow.parsed.split$CorNS[i]))
  # print(paste("First_new.dAIC:", grow.parsed.split$First_new.dAIC[i]))
  if (grow.parsed.split$First_ModelType[i] != "npluss") {
    print('The initial best model is NOT NplusS.')
    print(paste("So use the initial best model, which is:", grow.parsed.split$First_ModelName[i]))
    BestModelGrow[i] = grow.parsed.split$First_ModelName[i]
  }
  else if (grow.parsed.split$First_ModelType[i] == "npluss" & 
           grow.parsed.split$CorNS[i] > 0.4) {
    print('The initial best model is NplusS but CorNS > 0.4 so we cannot confidently separate out N-effects from S-effects.')
    print(paste("So use the initial best model, which is:", grow.parsed.split$First_ModelName[i]))
    BestModelGrow[i] = grow.parsed.split$First_ModelName[i]
  }
  else if (grow.parsed.split$First_ModelType[i] == "npluss" & 
           grow.parsed.split$CorNS[i] <= 0.4 & 
           grow.parsed.split$Second_new.dAIC[i] > 4.0) {
    print('The initial best model is NplusS, CorNS <= 0.4, and dAIC > 4. We cannot confidently separate out N-effects from S-effects so use the N+S model.')
    print(paste("So use the initial best model, which is:", grow.parsed.split$First_ModelName[i]))
    BestModelGrow[i] = grow.parsed.split$First_ModelName[i]
  }
  else if (grow.parsed.split$First_ModelType[i] == "npluss" & 
           grow.parsed.split$CorNS[i] <= 0.4 & 
           grow.parsed.split$Second_new.dAIC[i] <= 4.0 & 
           grow.parsed.split$Second_ModelType[i] != "npluss") {
    print('The initial best model is NplusS, CorNS <= 0.4, dAIC <= 4, and the rank #2 model is not NplusS...')
    print(paste("So use the second-best model, which is:", grow.parsed.split$Second_ModelName[i]))
    print('****ATTENTION ATTENTION ATTENTION! WE ARE USING THE SECOND-BEST MODEL!!')
    BestModelGrow[i] <- grow.parsed.split$Second_ModelName[i]
  }
  else if (grow.parsed.split$First_ModelType[i] == "npluss" & 
           grow.parsed.split$CorNS[i] <= 0.4 & 
           grow.parsed.split$Second_new.dAIC[i] <= 4.0 & 
           grow.parsed.split$Second_ModelType[i] == "npluss") {
    print("!No model found...REPEAT STEPS!")
  }
}

# Now that we have the "BestModel" for each spcd x division,
# we need to add this back to our original df.
# We can do this by creating a dataframe that we will merge with
# surv.param.updates

grow.parsed.split$BestModelGrow <- BestModelGrow

grow.BestModelOnly <-
  as.data.frame(
    grow.parsed.split %>%
      dplyr::select(c("spcd", "division", "BestModelGrow")) %>%
      dplyr::rename(model.shorthand = BestModelGrow)) # need to rename for merge

grow.selected.mods <- merge(grow.BestModelOnly, grow.topmods, 
                            by = c("spcd", "division", "model.shorthand"), all.x = TRUE, all.y = F)
dim(grow.selected.mods) # [1] 382  37

################################################################################
# 9. Now, assign the shapes based on N and S parameters
################################################################################

grow.shapes <- 
  as.data.frame(
    grow.selected.mods %>%    
      # NITROGEN:
      #   decreaser: when n1 term is less than the minimum N [n1 < minN]
      #   increaser: n1 is greater than or equal to the maximum N [n1 > maxN]
      #   humped: n1 between the min N and the max N [minN < n1 < maxN]
      #   flat: n1 = NA 
      dplyr::mutate("N.shape" = case_when(
        n1.updated < MinN ~ "decrease", 
        n1.updated >= MaxN ~ "increase",
        n1.updated < MaxN & n1.updated > MinN ~ "unimodal",
        is.na(n1.updated) & is.na(npluss1.updated) ~ "flat")) %>%
      # SULFUR (s1| and s1T)
      dplyr::mutate("S.shape" = case_when(
        s1bar.updated <= MinS ~ "decrease", 
        s1bar.updated >= MaxS ~ "increase",
        is.na(s1bar.updated) & is.na(s1T.updated) &
          is.na(npluss1.updated) ~ "flat",
        s1T.updated >= 0 ~ "tabletop")) %>%
      # NITROGEN AND SULFUR
      dplyr::mutate("NS.shape" = case_when(
        npluss1.updated < MinNS ~ "decrease", 
        npluss1.updated >= MaxNS ~ "increase",
        npluss1.updated < MaxNS & 
          npluss1.updated > MinNS ~ "unimodal")))

dim(grow.shapes) #[1] 382  40

################################################################################
# 10. Combine surv and growth df and write csv files
################################################################################

# check dimensions of both data frames
dim(grow.shapes) #[1] 382  40
dim(surv.shapes) #[1] 414  40

# combine the growth and survival data frames
shape.df <- rbind(grow.shapes, surv.shapes)
dim(shape.df) #[1] 796  40

shape.df <- as.data.frame(shape.df %>%
                            unite(genus.species, GENUS, SPECIES, sep = " ", remove = FALSE))
dim(shape.df) #[1] 796  41

#write.csv(shape.df, file = "TreeCLA1_shapedf_03212022.csv")

div.histogram <-  as.data.frame(shape.df %>%
                                  dplyr::group_by(division, process) %>%
                                  dplyr::summarize(total.trees = sum(sample.size, na.rm = T),
                                                   total.spec = n()))

################################################################################
# 11. Combine red.df with myco, climate, and pheno
#     Begin by loading climate and myco data
################################################################################

# Jo2019_data_tree_sp_myc_type.xlsx: mycorrhizal 
# association data from Jo et al., 2019 
# received file via email to C. Clark

# Jo, I., Fei, S., Oswalt, C. M., Domke, G. M., & Phillips, R. P. (2019). Shifts in # dominant tree mycorrhizal associations in response to anthropogenic
# impacts.cience advances, 5(4), eaav6358.
# https://www.science.org/doi/10.1126/sciadv.aav6358

# set your own path here
path.myco <- "C:/Users/rdalton/OneDrive - Environmental Protection Agency (EPA)/Profile/Documents/Projects/TreeCLA1/Manuscript/FFGC submission/Data and R code/data_Rcode_regionaltree/Jo2019_data_tree_sp_myc_type.xlsx"

path.myco %>% readxl::excel_sheets() # view of tab names in Excel file
# [1] "data" "meta"

myco.df <- read_excel(path.myco, sheet = "data")
colnames(myco.df)
# [1] "SPCD"             "Family"           "Species name"     "Mycorrhizal type" "ID level" 

# rename column headers
names(myco.df)[names(myco.df) == 'Species name'] <- 'genus.species'
names(myco.df)[names(myco.df) == 'Mycorrhizal type'] <- 'myco'
names(myco.df)[names(myco.df) == 'SPCD'] <- 'spcd'
names(myco.df)[names(myco.df) == 'Family'] <- 'family'
names(myco.df)[names(myco.df) == 'ID level'] <- 'myco.id.level'
myco.df = subset(myco.df, select = -c(genus.species) )

dim(myco.df) #[1] 379   4

str(myco.df) # check the structure
unique(myco.df$myco) #  $ myco         : Factor w/ 5 levels
# there are five groups, but there are few that are not "AM" or "EM"
myco.subset <- subset(myco.df, myco != "AM" & myco != "EM")
dim(myco.subset) # 8 total spcd are not categorized as "AM" or "EM"

# check to see which of these species are in our data frame

unique(myco.merge <- merge(myco.subset, shape.df, by = c("spcd")))$genus.species

# there are three species that don't fall into "AM" or "EM" categories:

# Ailanthus altissima (spcd: 341) (NM):
#     updated A. altissima based on the following citation showing there is myco
#     association in USA populations:
#     Huebner, Cynthia D., Carolyn McQuattie, and Joanne Rebbeck. 
#     "Mycorrhizal associations in Ailanthus altissima (Simaroubaceae) from 
#     forested and non-forested sites1." The Journal of the Torrey Botanical 
#     Society 134.1 (2007): 27-33. 
#     https://www.nrs.fs.fed.us/pubs/jrnl/2007/nrs_2007_huebner_001.pdf
#     Reassigned as "AM" (endo)

# Gledistia triacanthos (spcd 552) (AM + EM)
#     https://link.springer.com/article/10.1007/s00572-010-0314-6 (AM in Canada)
#     Bainard, Luke D., John N. Klironomos, and Andrew M. Gordon. 
#     "The mycorrhizal status and colonization of 26 tree species growing 
#     in urban and rural environments." Mycorrhiza 21.2 (2011): 91-96.
#     Assigned as "AM" to start and then ran models with "EM" as well

# Oxydendrum arboreum (spcd 711) (ERM)
#     Ericoid mycorrhiza is a subtype of endomycorrhiza - assigned "AM"
#     Will remove this species from subsequent model runs to see if
#     results change

myco.df$myco <- as.character(myco.df$myco)
# make the corrections here
myco.df.corrected <-
  as.data.frame(
    myco.df %>%
      dplyr::mutate(myco = case_when(spcd == 341 ~ as.character("AM"),
                                     spcd == 552 ~ as.character("AM"),
                                     spcd == 711 ~ as.character("AM"),
                                     TRUE ~ as.character(myco))))

myco.df.corrected$myco <- as.factor(as.character(myco.df.corrected$myco))
str(myco.df.corrected)
dim(myco.df.corrected) #[1] 379   4
myco.df <- myco.df.corrected

# "DIVISION_fia_forestdivision_temp_precip_pH_with species_ALL SPP.csv": 
# climate data downloaded by R. Dalton on 14 Jan. 2022
# This file was created by R. Sabo and C. Clark

clim.div <- read.csv("DIVISION_fia_forestdivision_temp_precip_pH_with species_ALL SPP.csv",
                     header = T, sep = ",",
                     fileEncoding = 'UTF-8-BOM')
dim(clim.div) #[1] 1073 19

clim.conus <- read.csv("CONUS_fia_forestdivision_temp_precip_pH_with species_ALL SPP.csv",
                       header = T, sep = ",",
                       fileEncoding = 'UTF-8-BOM')
dim(clim.conus) #[1] 352 17

# add "CONUS" as a division ID so we can combine df
clim.conus$DIVISION_ID = "CONUS"
clim.conus$DIVISION_NAME = "CONUS"

# here, we will make the column names easier to use
# in the analysis step - reducing the text and matching
# names with the shape.df data frame

clim <- rbind(clim.conus, clim.div)
dim(clim) #[1] 1425   19

clim.df <- 
  as.data.frame(clim %>%
                  dplyr::rename(division = DIVISION_ID,
                                division.name = DIVISION_NAME,
                                spcd = SPCD,
                                nrows = N.Rows,
                                N.mean = Mean.N.,
                                N.min = Min.N.,
                                N.max = Max.N.,
                                S.mean = Mean.S.,
                                S.min = Min.S.,
                                S.max = Max.S., 
                                pH.mean = Mean.SoilRas_pHwater_DCP_0to20cm_30Meter.,
                                pH.min = Min.SoilRas_pHwater_DCP_0to20cm_30Meter.,
                                pH.max = Max.SoilRas_pHwater_DCP_0to20cm_30Meter.,
                                temp.mean = Mean.PRISM_tmean_30yr_normal_800mM3_annual_bil.,
                                temp.min = Min.PRISM_tmean_30yr_normal_800mM3_annual_bil.,
                                temp.max = Max.PRISM_tmean_30yr_normal_800mM3_annual_bil.,
                                precip.mean = Mean.PRISM_ppt_30yr_normal_800mM3_annual_bil.,
                                precip.min = Min.PRISM_ppt_30yr_normal_800mM3_annual_bil.,
                                precip.max = Max.PRISM_ppt_30yr_normal_800mM3_annual_bil.) %>%
                  dplyr::select(-c("nrows")))
head(clim.df)

# we are adding a parameter - N+S according to the following:
# N+S = N*71.4 + S*62.5
Nmult = 71.4
Smult = 62.5

clim.df <-
  as.data.frame(clim.df %>%
                  mutate(N.mean.mult= N.mean * Nmult, 
                         N.min.mult= N.min * Nmult, 
                         N.max.mult= N.max * Nmult,
                         S.mean.mult= S.mean * Smult, 
                         S.min.mult= S.min * Smult, 
                         S.max.mult= S.max * Smult) %>%
                  rowwise() %>%
                  mutate(NS.mean = sum(c(N.mean.mult, S.mean.mult, na.rm = T)),
                         NS.min = sum(c(N.min.mult, S.min.mult, na.rm = T)),
                         NS.max = sum(c(N.max.mult, S.max.mult, na.rm = T))) %>%
                  select(-c("N.mean.mult", "N.min.mult", "N.max.mult",
                            "S.mean.mult", "S.min.mult", "S.max.mult")))
dim(clim.df)
# [1] 1425   21

# we have two sets of data for phenology type (evergreen or deciduous)
# 1) Horn et al., 2018:
# "Horn2018_SpeciesList.csv" : phenology type (E or D)
# and the number of species in the Horn paper (2018). Adapted
# from Supplemental File 1 in Horn et al., 2018 on 25 Jan 2022

# Horn, Kevin J., et al. "Growth and survival relationships of 
# 71 tree species with nitrogen and sulfur deposition across the 
# conterminous US." PloS one 13.10 (2018): e0205296.

horn.pheno <- read.csv("Horn2018_SpeciesList.csv",
                       header = T, sep = ",",
                       fileEncoding = 'UTF-8-BOM')
horn.pheno <- 
  as.data.frame(horn.pheno %>%
                  unite(genus.species, genus, species, 
                        sep = " ", remove = TRUE) %>%
                  dplyr::rename(pheno.type.horn = phenology.type))

# 2) TRY database:
# Kattge, J, Boenisch, G, Diaz, S, et al. TRY plant trait database - 
# enhanced coverage and open access. Glob Change Biol. 2020; 26: 119-188. 
# https://doi.org/10.1111/FFGC.14904 as the TRY reference.

pheno <- read.delim("Kattge2020_decid.txt",  quote = "", fileEncoding = "latin1")

# first, subset other traits - we just want vegetative phenology 
# Trait ID = 37
pheno <- subset(pheno, TraitID == "37")

# since there are so many entries per species, we want to create
# a list of phenology types per species
# here, we will create "pheno.string"
try.pheno <-
  as.data.frame(pheno %>%
                  dplyr::group_by(AccSpeciesName) %>%
                  dplyr::rename(genus.species = AccSpeciesName) %>%
                  dplyr::summarise(pheno.strings = 
                                     OrigValueStr %>% 
                                     unique %>% 
                                     sort %>% 
                                     paste(collapse = ", ")))

# combine the horn and TRY data
pheno.combined <- merge(horn.pheno, try.pheno, by = c("genus.species"), all = T)
head(pheno.combined)

# now, we need to create a single phenology column
# we also want to double check that horn et al == TRY phenology
# for species with data from both

pheno.df <- as.data.frame(pheno.combined %>%
                            # dplyr::mutate("pheno.data" = case_when(
                            #   !is.na(pheno.type.horn) ~ "horn et al",
                            #   is.na(pheno.type.horn) ~ "TRY")) %>%
                            dplyr::mutate("pheno.type.try" =  str_extract(pheno.strings, "D|E")) %>%
                            dplyr::mutate(same=(ifelse(pheno.type.horn==pheno.type.try,TRUE,FALSE))))

# subset species when Horn and TRY data are not equivalent
pheno.df.check <-
  as.data.frame(pheno.df %>%
                  dplyr::filter(same == "FALSE"))

# 8 species
# Corrections:
# Juniperus monosperma correctly labeled "E" in Horn et al [HORN]
# Juniperus virginiana correctly labeled "E" in Horn et al [HORN]
# Larix laricina labeled "E" in Horn, but loses its needles so it is a "D" [TRY]
# Magnolia virginiana can be "E" or "D" depending on climate [E AND D]
#   Since the division in our dataset is the southeast, it is likely E in that area
#   Chose E in this case, but can try with both in the analysis
# Pinus virginiana correctly labeled "E" in Horn, just one entry is "D" in TRY but others are "E" [HORN]
# Quercus chrysolepis labeled "D" in Horn is an evergreen tree - [TRY]
# Taxodium distichum does bear needles ("E" in Horn), but it drops its leaves - "D" - [TRY]
# Tilia americana was labeled as "E" in Horn, but should be "D" - [TRY]

# make the corrections here
pheno.df.corrected <-
  as.data.frame(pheno.df %>%
                  # create a new column for the combined or updated pheno type
                  dplyr::mutate("pheno.type.updated" = 
                                  ifelse(same %in% c("TRUE"), as.character(pheno.type.horn),
                                         ifelse(same %in% c("FALSE"), as.character(pheno.type.try), 
                                                ifelse(is.na(pheno.type.horn), as.character(pheno.type.try),
                                                       as.character(pheno.type.horn))))) %>%
                  # make the corrections below:
                  dplyr::mutate(pheno.type.updated = 
                                  case_when(genus.species %in% c("Juniperus monosperma") ~ as.character(pheno.type.horn),
                                            genus.species %in% c("Juniperus virginiana") ~ as.character(pheno.type.horn),
                                            genus.species %in% c("Larix laricina") ~ as.character(pheno.type.try),
                                            genus.species %in% c("Magnolia virginiana") ~ "E",
                                            genus.species %in% c("Pinus virginiana") ~ as.character(pheno.type.horn),
                                            genus.species %in% c("Quercus chrysolepis") ~ as.character(pheno.type.try),
                                            genus.species %in% c("Taxodium distichum") ~ as.character(pheno.type.try),
                                            genus.species %in% c("Tilia americana") ~ as.character(pheno.type.try),
                                            TRUE ~ as.character(pheno.type.updated))) %>%
                  dplyr::select(c("genus.species", "pheno.type.updated")) %>%
                  dplyr::rename("pheno.type" = "pheno.type.updated" ))

unique(pheno.df.corrected$genus.species)

# check to make sure we aren't missing species
pheno.df.spcd <- as.data.frame(
  pheno.df.corrected %>% 
    dplyr::select(c("genus.species")) 
)

shape.df.spcd <- as.data.frame(
  shape.df %>% 
    dplyr::select(c("genus.species")) 
)

pheno.diff <- setdiff(shape.df.spcd, pheno.df.spcd)
pheno.diff

#      genus.species
# 1  Abies shastensis # [E]: https://www.fs.fed.us/database/feis/plants/tree/abimag/all.html
# 2     Acer barbatum # [D]: https://www.srs.fs.usda.gov/pubs/misc/ag_654/volume_2/acer/barbatum.htm 
# 3  Amelanchier spp. # [D]: https://www.nrcs.usda.gov/Internet/FSE_PLANTMATERIALS/publications/njpmcpg12709.pdf 
# 4        Malus spp. # [D]: https://plants.ces.ncsu.edu/plants/malus-hybrids/
# 5 Triadica sebifera # [D]: https://www.fs.fed.us/database/feis/plants/tree/triseb/all.html 
# 6    Crataegus spp. # [D]: https://plants.ces.ncsu.edu/plants/crataegus-spathulata/#:~:text=Crataegus%2C%20or%20Hawthorn%2C%20is%20a,mountain%20ridges%20in%20the%20west.

pheno.type <- c("E", # 1  Abies shastensis
                "D", # 2  Acer barbatum 
                "D", # 3  Amelanchier spp.
                "D", # 4  Malus spp.
                "D", # 5  Triadica sebifera
                "D") # 6  Crataegus spp.

pheno.new <- data.frame(pheno.diff, pheno.type)

pheno.df <- rbind(pheno.df.corrected, pheno.new)

################################################################################
# 12. Merge shape.df with myco, pheno, and climate data
################################################################################
# merge the tree, climate, and myco data frames
dim(clim.df)  #[1] 1425  21
dim(myco.df)  #[1] 379   4
dim(pheno.df) #[1] 145  2

data <- merge(shape.df, clim.df, 
              by = c("division", 'spcd'), 
              all.x = T, all.y = F)
dim(data) #[1] 796  60
colnames(data)

data <- merge(data, myco.df, 
              by =  c("spcd"), 
              all.x = T, all.y = F)
dim(data) #[1] 796  63
colnames(data)

data <- merge(data, pheno.df, 
              by =  c("genus.species"), 
              all.x = T, all.y = F)
dim(data) #[1] 796  64
colnames(data)

# clean up the remaining column names and create final df

data.clean <- as.data.frame(
  data %>%
    # convert all cap columns to lowercase
    dplyr::rename(genus = GENUS,
                  species = SPECIES) %>%
    # remove "updated" from N and S parameter estimates
    dplyr::rename(n1 = n1.updated,
                  s1bar = s1bar.updated,
                  s1T = s1T.updated,
                  npluss1 = npluss1.updated) %>%
    # reorder column names
    dplyr::select(c("spcd", "family", "genus", "species",
                    "genus.species", "division", "division.name",
                    "process", "sample.size", "AIC",
                    "new.dAIC", "rank", "model.shorthand",
                    "n1", "s1bar", "s1T", "s2T", "s3T", "npluss1",
                    "N.shape", "S.shape", "NS.shape",
                    "CorNS", "AvgT", "AvgP",
                    "AvgN", "MinN", "MaxN", 
                    "AvgS", "MinS", "MaxS",            
                    "AvgNS","MinNS", "MaxNS",
                    "N.mean", "N.min", "N.max",
                    "S.mean", "S.min", "S.max",
                    "NS.mean", "NS.min", "NS.max",
                    "pH.mean", "pH.min", "pH.max",
                    "temp.mean", "temp.min", "temp.max",
                    "precip.mean", "precip.min", "precip.max",
                    "myco", "myco.id.level", "pheno.type")))

dim(data.clean) #[1] 796  55
colnames(data.clean)

################################################################################
# 13. Check for missing data
################################################################################

# first, check for missing values
dim(myco.missing <- subset(data.clean, is.na(myco))) #[1]  0 55
dim(pheno.missing <- subset(data.clean, is.na(pheno.type))) #[1]  0 55
dim(temp.missing <- subset(data.clean, is.na(temp.mean))) #[1]  3 55
dim(precip.missing <- subset(data.clean, is.na(precip.mean))) #[1]  3 55
dim(pH.missing <- subset(data.clean, is.na(pH.mean))) #[1]  3 55

View(temp.missing)

# next, determine whether there are missing spcd x div
# from the clim.df

clim.df.spcd.div <- as.data.frame(
  clim.df %>%
    dplyr::select(c("division", "spcd"))
)

shape.df.spcd.div <- as.data.frame(
  shape.df %>% 
    dplyr::select(c("division", "spcd")) 
)

diff <- setdiff(shape.df.spcd.div, clim.df.spcd.div)
diff

#   division spcd
#1       33  101
#2       33   18

# note, division name is missing from these lines, although they are associated with myco and pheno data. It is only for division 33

data.clean1 <- 
  as.data.frame(
    data.clean %>%
      mutate(division.name = ifelse(is.na(division.name),
                                    subset(data.clean, division == "33")$division.name, 
                                    division.name)))

is.na(data.clean1$division.name)

data.clean <- data.clean1
# next, check the structure
str(data.clean)
summary(data.clean)

write.csv(data.clean, row.names = F, "TreeCLA1_combined_df_FFGC_2024.csv")

################################################################################
# END DATA COMPILING
# BEGIN PART 2. ORDINAL ANALYSIS AND VISUALIZATIONS
################################################################################

################################################################################
# 1. Create consistent color palettes for visuals
################################################################################

shape.brew <- MetBrewer::met.brewer("Johnson", 12)
scales::show_col(shape.brew) 
# different shapes (flat, decrease, increase, tt, and unimodal)


# color palette for N and S shapes
shape.cols <- c(
  "increase" = shape.brew[8], # green
  "tabletop" = shape.brew[7], # yellow
  "unimodal" = shape.brew[5], # orange 
  "decrease" = shape.brew[1], # red
  "flat" = shape.brew[9], # blue
  "NA" = "gray70")

# labels for N and S shapes
shape.cols.labels <- c(
  "increase" = "increase",
  "flat" = "flat",
  "unimodal" = "unimodal",
  "tabletop" = "sigmoidal",
  "decrease" = "decrease",
  "NA" = "not applicable")

# color palette for N shape only
shape.cols.N <- c(  "increase" = shape.brew[8], # green
                    "unimodal" = shape.brew[5], # orange 
                    "decrease" = shape.brew[1], # red
                    "flat" = shape.brew[9], # blue
                    "NA" = "gray70")

# labels for N shape only    
shape.cols.labels.N <- c(
  "increase" = "increase",
  "flat" = "flat",
  "unimodal" = "unimodal",
  "decrease" = "decrease")

# color palette for S shape only
shape.cols.S <- c(
  "tabletop" = shape.brew[7], # yellow
  "decrease" = shape.brew[1], # red
  "flat" = shape.brew[9], # blue
  "NA" = "gray70")

# labels for S shape only
shape.cols.labels.S <- c("flat" = "flat",
                         "tabletop" = "sigmoidal",
                         "decrease" = "decrease")

# color palette positive and negative effects
display.brewer.all(n = NULL, type = "all", select = NULL,
                   colorblindFriendly = FALSE)
posneg <- brewer.pal(8, "RdBu")
effect.cols <- c("neg" = posneg[7], # blue
                 "pos" = posneg[1]) # red

# labels for positive and negative effects
effect.labels <- c("pos" = "OR > 1 (more vulnerable responses)",
                   "neg" = "OR < 1 (less vulnerable responses)")

# labels for significance
sig.labels <- c("0" = "p > 0.05",
                "1" = "p < 0.05")

## create a color palette for covariates

covariate.cols.pos <- MetBrewer::met.brewer("OKeeffe2", 3)
scales::show_col(covariate.cols.pos)

covariate.cols.pos <- c(covariate.cols.pos[1],
                        covariate.cols.pos[2], 
                        covariate.cols.pos[3])

covariate.cols.neg <- MetBrewer::met.brewer("OKeeffe1", 3)
scales::show_col(covariate.cols.neg)

## create a color palettes for divisions

div.cols <- rev(MetBrewer::met.brewer("Renoir", 11))

div.pal <- c("CONUS" = "gray70",
             "24" = div.cols[1],
             "26" = div.cols[2],
             "32" = div.cols[3],
             "34" = div.cols[4],
             "31" = div.cols[5],
             "33" = div.cols[6],
             "25" = div.cols[7],
             "23" = div.cols[8],
             "22" = div.cols[9],
             "1"  = "black",
             "21" = div.cols[10],
             "41" = div.cols[11])

# labels for the division color palette
div.pal.name <- 
  c("CONUS" = "gray70",
    "Marine" = div.cols[1],
    "Mediterranean" = div.cols[2],
    "Tropical/Subtropical Desert" = div.cols[3],
    "Temperate Desert" = div.cols[4],
    "Tropical/Subtropical Steppe" = div.cols[5],
    "Temperate Steppe" = div.cols[6],
    "Prairie" = div.cols[7],
    "Subtropical" = div.cols[8],
    "Hot Continental" = div.cols[9],
    "Warm Continental" = div.cols[10],
    "Savannah" = div.cols[11])

################################################################################
# 2. Load data 
################################################################################

# add data from csv file
data <- read.csv("TreeCLA1_combined_df_FFGC_2024.csv",
                  header = T, sep = ",",
                 fileEncoding = 'UTF-8-BOM')
head(data)
dim(data) #[1] 796  55

# here, we will change spp. to sp to match the phylogenetic 
# tree for FIA species
data$genus.species <- sub("spp.", "sp", data$genus.species)

# now, read in the file that has the centroid points for each
# division to use for creating visualizations

path.div <- "C:/Users/rdalton/OneDrive - Environmental Protection Agency (EPA)/Profile/Documents/Projects/TreeCLA1/Analysis/EcoMapDivisions_centroids_Table.xlsx"

path.div %>% readxl::excel_sheets() # view of tab names in Excel file

div <- as.data.frame(readxl::read_excel(path.div))

# create a df that we can combine to "data"
div.loc <- 
  as.data.frame(div %>%
                  dplyr:: rename("division" = "DIVISION_ID",
                                 "division.name" = "DIVISION_NAME") %>%
                  dplyr::arrange(Longitude))

div.order <- as.data.frame(as.factor(div.loc$division))
names(div.order)[1] <- "division"
CONUS <- data.frame(division = "CONUS")
CONUS$division <- as.factor(CONUS$division)
div.order.df <- rbind(CONUS, div.order)
div.order <- c("CONUS", "24", "26", "32", "34",
               "31", "33", "25", "23", "22", "1",
               "21", "41")
data$division <- reorder.factor(data$division, new.order=div.order) 

div.loc$number <- paste0("(", div.loc$division, ")") 
div.loc$div.label <- paste(div.loc$division.name, div.loc$number, sep=" ")
div.name.labs <- c(div.loc$div.label)
div.name.labels <- c("CONUS" = "Continental U.S.",
                     "Marine" = div.name.labs[1],
                     "Mediterranean" = div.name.labs[2],
                     "Tropical/Subtropical Desert" = div.name.labs[3],
                     "Temperate Desert" = div.name.labs[4],
                     "Tropical/Subtropical Steppe" = div.name.labs[5],
                     "Temperate Steppe" = div.name.labs[6],
                     "Prairie" = div.name.labs[7],
                     "Subtropical" = div.name.labs[8],
                     "Hot Continental" = div.name.labs[9],
                     "Warm Continental" = div.name.labs[11],
                     "Savannah" = div.name.labs[12])

data.div <- as.data.frame(
  data %>%
    dplyr::filter(division != "CONUS")
)

data.div <- droplevels(data.div)
print(data.div)

data.sub <- as.data.frame(
  data %>%
    filter(division != 41 & division != 32))

data.sub <- droplevels(data.sub)

################################################################################
# 3. Figure 1: Climate, edaphic, deposition across div
################################################################################

# Step A) first, separate survival and growth
#   remove growth: we will use survival values for the analysis - if we use growth
#   as well would double most of the data set
#   remove CONUS: we will also remove CONUS becuase we are looking at differnces
#   among divisions

head(temp.data <- as.data.frame(
  data %>% 
    dplyr::filter(process == "survival" & division != "CONUS") %>%
    dplyr::select(division, division.name, temp.mean)))

# Step B) run an ANOVA
summary(aov.temp <- stats::aov(temp.mean ~ division, data = temp.data))

# Step C) calculate compact letter displays (clds) using a Tukey's HSD test
head(ch.temp <- multcomp::cld(glht(aov.temp, linfct = mcp(division = "Tukey"))))

# Step D) create a dataframe of clds
ch.temp.df <- as.data.frame(t(as.data.frame(t(multcomp:::print.cld(ch.temp)))))
ch.temp.df$division <- rownames(ch.temp.df)
names(ch.temp.df)[1] <- "letter"

# Step E) calculate the y-axis necessary to show the entire data frame
# for temperature
ypos.temp = as.data.frame(temp.data %>%
                            dplyr::group_by(division) %>%
                            dplyr::summarize(ypos = max(temp.mean, na.rm = T) + 2.2))

# Step F) combine the cld df and the ypos - use this df for creating the 
# visualization
ch.temp.df<- merge(ch.temp.df, div.loc, by = "division", all.x = T, all.y = F)
ch.temp.df <- merge(ch.temp.df, ypos.temp, by = "division")
ch.temp.df$climate.var = "temp.mean"

head(ch.temp.df)

# repeat steps A - F for the rest of the environmental covariates:

# mean precipitation
precip.data <- as.data.frame(
  data %>% 
    dplyr::filter(process == "survival" & division != "CONUS") %>%
    dplyr::select(division, division.name, precip.mean))

summary(aov.precip <- stats::aov(precip.mean ~ division, data = precip.data))
ch.precip <- multcomp::cld(glht(aov.precip, linfct = mcp(division = "Tukey") ), decreasing = TRUE)
ch.precip.df <- as.data.frame(t(as.data.frame(t(multcomp:::print.cld(ch.precip)))))
ch.precip.df$division <- rownames(ch.precip.df)
names(ch.precip.df)[1] <- "letter"

ypos.precip = precip.data %>%
  dplyr::group_by(division) %>%
  dplyr::summarize(ypos = max(precip.mean, na.rm = T) + 220 )

ch.precip.df<- merge(ch.precip.df, div.loc, by = "division", all.x = T, all.y = F)
ch.precip.df <- merge(ch.precip.df, ypos.precip, by = "division")
ch.precip.df$climate.var = "precip.mean"

# mean soil pH
pH.data <- as.data.frame(
  data %>% 
    dplyr::filter(process == "survival" & division != "CONUS") %>%
    dplyr::select(division, division.name, pH.mean))

summary(aov.pH <- stats::aov(pH.mean ~ division, data = pH.data))
ch.pH <- multcomp::cld(glht(aov.pH, linfct = mcp(division = "Tukey")))
ch.pH.df <- as.data.frame(t(as.data.frame(t(multcomp:::print.cld(ch.pH)))))
ch.pH.df$division <- rownames(ch.pH.df)
names(ch.pH.df)[1] <- "letter"

ypos.pH = as.data.frame(pH.data %>%
                          dplyr::group_by(division) %>%
                          dplyr::summarize(ypos = max(pH.mean, na.rm = T) + 0.2 ))

ch.pH.df<- merge(ch.pH.df, div.loc, by = "division", all.x = T, all.y = F)
ch.pH.df <- merge(ch.pH.df, ypos.pH, by = "division")
ch.pH.df$climate.var = "pH.mean"

# mean N deposition
N.data <- as.data.frame(
  data %>% 
    dplyr::filter(process == "survival" & division != "CONUS") %>%
    dplyr::select(division, division.name, N.mean))

print(N.by.division <- as.data.frame(
  N.data %>% 
    group_by(division, division.name) %>%
    summarise(mean = mean(N.mean), 
              min = min(N.mean), 
              max = max(N.mean)))  %>%
    arrange(division))

summary(aov.N <- aov(N.mean ~ division, data = N.data))
ch.N <- cld(glht(aov.N, linfct = mcp(division = "Tukey")))
ch.N.df <- as.data.frame(t(as.data.frame(t(multcomp:::print.cld(ch.N)))))
ch.N.df$division <- rownames(ch.N.df)
names(ch.N.df)[1] <- "letter"

ypos.N = as.data.frame(N.data %>%
                         dplyr::group_by(division) %>%
                         dplyr::summarize(ypos = max(N.mean, na.rm = T) + 1.2))

ch.N.df<- merge(ch.N.df, div.loc, by = "division", all.x = T, all.y = F)
ch.N.df <- merge(ch.N.df, ypos.N, by = "division")
ch.N.df$climate.var = "N.mean"

# mean S deposition
S.data <- as.data.frame(
  data %>% 
    dplyr::filter(process == "survival" & division != "CONUS") %>%
    dplyr::select(division, division.name, S.mean))

summary(aov.S <- stats::aov(S.mean ~ division, data = S.data))
ch.S <- multcomp::cld(glht(aov.S, linfct = mcp(division = "Tukey")))
ch.S.df <- as.data.frame(t(as.data.frame(t(multcomp:::print.cld(ch.S)))))
ch.S.df$division <- rownames(ch.S.df)
names(ch.S.df)[1] <- "letter"

ypos.S = as.data.frame(S.data %>%
                         dplyr::group_by(division) %>%
                         dplyr::summarize(ypos = max(S.mean, na.rm = T) + 2.2 ))

ch.S.df<- merge(ch.S.df, div.loc, by = "division", all.x = T, all.y = F)
ch.S.df <- merge(ch.S.df, ypos.S, by = "division")
ch.S.df$climate.var = "S.mean"

# mean NS deposition
NS.data <- as.data.frame(
  data %>% 
    dplyr::filter(process == "survival" & division != "CONUS") %>%
    dplyr::select(division, division.name, NS.mean))

summary(aov.NS <- stats::aov(NS.mean ~ division, data = NS.data))
ch.NS <- multcomp::cld(glht(aov.NS, linfct = mcp(division = "Tukey")))
ch.NS.df <- as.data.frame(t(as.data.frame(t(multcomp:::print.cld(ch.NS)))))
ch.NS.df$division <- rownames(ch.NS.df)
names(ch.NS.df)[1] <- "letter"

ypos.NS = as.data.frame(NS.data %>%
                          dplyr::group_by(division) %>%
                          dplyr::summarize(ypos = max(NS.mean, na.rm = T) + 2.2 ))

ch.NS.df<- merge(ch.NS.df, div.loc, by = "division", all.x = T, all.y = F)
ch.NS.df <- merge(ch.NS.df, ypos.NS, by = "division")
ch.NS.df$climate.var = "NS.mean"

# proportion myco (AM vs EM)
myco.data <- as.data.frame(
  data %>% 
    dplyr::filter(process == "survival" & division != "CONUS") %>%
    drop.levels() %>%
    dplyr::mutate(myco.am = ifelse(myco == "AM", 1, 0 )) %>%
    dplyr::select(division, division.name, myco, myco.am))

myco.data.table <- table(myco.data$division, myco.data$myco)
chisq.myco <- chisq.test(myco.data.table)

# Warning message:
# In chisq.test(myco.data.table) : Chi-squared approximation may be incorrect

chisq.test(myco.data.table)$expected # some are less than 5, need to use Fisher's
fishers.myco <- fisher.test(myco.data.table, workspace=2e7)
fishers.myco$p.value #p-value = 0.03408

fisher.test(myco.data.table,
            alternative="two.sided",
            simulate.p.value = T)

myco.pairwise.rstatix <- as.data.frame(rstatix::pairwise_fisher_test(myco.data.table, p.adjust.method = "fdr"))

myco.pairwise.rcompanion <-  rcompanion::pairwiseNominalIndependence(myco.data.table,
                                                                     fisher = TRUE,
                                                                     gtest  = FALSE,
                                                                     chisq  = FALSE,
                                                                     digits = 3)

myco.pairwise.rcompanion

ch.myco.df <- rcompanion::cldList(comparison = myco.pairwise.rcompanion$Comparison,
                                  p.value    = myco.pairwise.rcompanion$p.adj.Fisher,
                                  threshold  = 0.05)

names(ch.myco.df)[1] <- "division"
names(ch.myco.df)[2] <- "letter"
ch.myco.df = subset(ch.myco.df, select = -c(MonoLetter) )
ch.myco.df <- merge(div.loc, ch.myco.df, by = c("division"))
ch.myco.df$var = "myco"

myco.data.prop <- as.data.frame(
  data %>% 
    dplyr::filter(process == "survival") %>%
    dplyr::select(division, division.name, myco) %>%
    dplyr::group_by(division, division.name, myco) %>%
    dplyr::summarise(n = dplyr::n()) %>%
    dplyr::mutate(freq = n / sum(n)) %>%
    dplyr::rename(value = myco) %>%
    dplyr::mutate(var = "myco"))

ypos.myco = as.data.frame(myco.data.prop %>%
                            dplyr::group_by(division) %>%
                            dplyr::filter(value == "AM") %>%
                            dplyr::summarize(ypos = max(freq, na.rm = T) + 0.1))

ch.myco.df <- merge(ch.myco.df, ypos.myco, by = c("division"))

# proportion decidousness
pheno.data <- as.data.frame(
  data %>% 
    dplyr::filter(process == "survival" & division != "CONUS") %>%
    drop.levels() %>%
    dplyr::mutate(pheno.d = ifelse(pheno.type == "D", 1, 0 )) %>%
    dplyr::select(division, division.name, pheno.type, pheno.d))

pheno.data.table <- table(pheno.data$division, pheno.data$pheno.type)
chisq.pheno <- chisq.test(pheno.data.table)

# Warning message:
# In chisq.test(myco.data.table) : Chi-squared approximation may be incorrect

chisq.test(pheno.data.table)$expected # some are less than 5, need to use Fisher's

fisher.test(pheno.data.table,
            alternative="two.sided",
            simulate.p.value = T)
# p = 0.004998

pheno.pairwise.rstatix <- as.data.frame(rstatix::pairwise_fisher_test(pheno.data.table, 
                                                                      p.adjust.method = "fdr"))
pheno.pairwise.rstatix

pheno.pairwise.rcompanion <-  
  rcompanion::pairwiseNominalIndependence(pheno.data.table,
                                          fisher = TRUE,
                                          gtest  = FALSE,
                                          chisq  = FALSE,
                                          digits = 3)

pheno.pairwise.rcompanion

ch.pheno.df <- rcompanion::cldList(comparison = pheno.pairwise.rcompanion$Comparison,
                                   p.value    = pheno.pairwise.rcompanion$p.adj.Fisher,
                                   threshold  = 0.05)
names(ch.pheno.df)[1] <- "division" #rename columns to match other climate dataframes
names(ch.pheno.df)[2] <- "letter"
ch.pheno.df <- subset(ch.pheno.df, select = c(division, letter))

ch.pheno.df <- merge(ch.pheno.df, div.loc, by = "division", all.x = T, all.y = F)
ch.pheno.df$var = "pheno.type"

pheno.data.prop <- as.data.frame(
  data %>% 
    dplyr::filter(process == "survival") %>%
    dplyr::select(division, division.name, pheno.type) %>%
    dplyr::group_by(division, division.name, pheno.type) %>%
    dplyr::summarise(n = dplyr::n()) %>%
    dplyr::mutate(freq = n / sum(n)) %>%
    dplyr::rename(value = pheno.type) %>%
    dplyr::mutate(var = "pheno.type"))

ypos.pheno = as.data.frame(pheno.data.prop %>%
                             dplyr::filter(value == "E") %>%
                             dplyr::group_by(division) %>%
                             dplyr::summarize(ypos = max(freq, na.rm = T) + 0.1))

ch.pheno.df <- merge(ch.pheno.df, ypos.pheno, by = c("division"))

# Step G) combine the covariate cld dataframes into one df
# "climate" df will be separate from "plant functional traits df"
ch.clim <- rbind(ch.temp.df, ch.precip.df, ch.pH.df, ch.N.df, ch.S.df, ch.NS.df)
ch.clim$climate.var <- as.factor(ch.clim$climate.var)

# plant functional traits
ch.plant <- rbind(ch.myco.df, ch.pheno.df)

# Step H) reformat the data to make it easier when plotting
clim.melt <- tidyr::gather(subset(data, process = "survival" & division != "CONUS"), climate.var, value, c(temp.mean, precip.mean, pH.mean, N.mean, S.mean, NS.mean), factor_key = F)

plant.melt <- rbind.data.frame(myco.data.prop, pheno.data.prop)

plant.melt <- as.data.frame(
  plant.melt %>% 
    dplyr::mutate(letter = case_when(
      var == "myco" ~ "(D)",
      var == "pheno.type" ~ "(G)",
      TRUE ~ "(H)"
    )))

# Step I) reorder the climate variables and create labels
clim.order <- c("temp.mean",
                "N.mean",
                "precip.mean",
                "S.mean", 
                "pH.mean", 
                "NS.mean")
clim.melt$climate.var <- reorder.factor(clim.melt$climate.var, 
                                        new.order=clim.order) 

clim.melt <- as.data.frame(
  clim.melt %>% 
    dplyr::mutate(letter = case_when(
      climate.var == "temp.mean" ~ "(A)",
      climate.var == "precip.mean" ~ "(B)",
      climate.var == "pH.mean" ~ "(C)",
      climate.var == "N.mean" ~ "(E)",
      TRUE ~ "(F)"
    )))

clim.labels <- c(temp.mean = "Temperature\n(°C)", 
                 precip.mean = "Precipitation\n(mm)",
                 pH.mean = "Soil pH",
                 N.mean = "N deposition\n(kg/ha/yr)",
                 S.mean = "S deposition\n(kg/ha/yr)",
                 NS.mean = "NS deposition\n(kg/ha/yr)")

plant.labels <- c(myco = "Proportion\nAMF",
                  pheno.type = "Proportion\nEvergreen")

# Step J) create the visualization (Fig. 1)

a1 <-  
  ggplot2::ggplot(subset(clim.melt, climate.var == "temp.mean"|
                           climate.var == "precip.mean"|
                           climate.var == "pH.mean"),
                  aes(x = division, y = value, fill = as.factor(division.name))) + 
  labs(x = NULL, y = NULL, fill = "USFS Division Name") +
  facet_wrap(~climate.var,
             ncol = 1, scales = "free_y", strip.position ="left",
             labeller = as_labeller(clim.labels)) + 
  geom_jitter(size = 0.5, alpha = 0.5, color = "grey30") +
  geom_boxplot(outlier.shape = NA, alpha = 0.9) +
  geom_text(data = subset(ch.clim, climate.var == "temp.mean"|
                            climate.var == "precip.mean"|
                            climate.var == "pH.mean"),
            aes(label = letter, x = division, y = ypos), 
            vjust = 1, size = 3) +
  geom_label(data = subset(clim.melt, division == "CONUS"
                           & genus.species == "Abies amabilis" &
                             (climate.var == "temp.mean"|
                                climate.var == "precip.mean"|
                                climate.var == "pH.mean")),
             aes(x = 0, y = Inf,
                 label = letter, group = letter),
             fill = NA,
             fontface = "bold",
             size = 4,  hjust = "left",
             vjust = "top", label.size = NA,
             inherit.aes = F) +
  scale_fill_manual(values = div.pal.name,
                    labels = div.name.labels) + 
  theme_bw() + 
  theme(text = element_text(size = 13, color = "black"),
        axis.text = element_text(size = 13, color = "black"),
        #axis.text.x = element_text(angle = 45, hjust = 1), 
        axis.text.x = element_blank(),
        axis.ticks.x = element_blank(),
        panel.grid = element_blank(),
        strip.background = element_blank(), strip.placement = "outside",
        strip.text = element_text(size = 13),
        legend.position = "none")

a2 <-  
  ggplot2::ggplot(subset(clim.melt, climate.var == "N.mean"|
                           climate.var == "S.mean"),
                  aes(x = division, y = value, fill = as.factor(division.name))) + 
  labs(x = NULL, y = NULL, fill = "USFS Division Name") +
  facet_wrap(~climate.var,
             ncol = 1, scales = "free_y", strip.position ="left",
             labeller = as_labeller(clim.labels)) + 
  geom_jitter(size = 0.5, alpha = 0.5, color = "grey30") +
  geom_boxplot(outlier.shape = NA, alpha = 0.9) +
  geom_text(data = subset(ch.clim, climate.var == "N.mean"|
                            climate.var == "S.mean" ),
            aes(label = letter, x = division, y = ypos), 
            vjust = 1, size = 3) +
  geom_label(data = subset(clim.melt, division == "CONUS"
                           & genus.species == "Abies amabilis" &
                             (climate.var == "N.mean"|
                                climate.var == "S.mean")),
             aes(x = 0, y = Inf,
                 label = letter, group = letter),
             fill = NA,
             fontface = "bold",
             size = 4,  hjust = "left",
             vjust = "top", label.size = NA,
             inherit.aes = F) +
  scale_fill_manual(values = div.pal.name,
                    labels = div.name.labels) + 
  theme_bw() + 
  theme(text = element_text(size = 13, color = "black"),
        axis.text = element_text(size = 13, color = "black"),
        #axis.text.x = element_text(angle = 45, hjust = 1), 
        axis.text.x = element_blank(),
        axis.ticks.x = element_blank(),
        panel.grid = element_blank(),
        strip.background = element_blank(), strip.placement = "outside",
        strip.text = element_text(size = 13),
        legend.position = "none")

b <- 
  ggplot2::ggplot(subset(plant.melt, value == "AM" | value == "E"),
                  aes(x = division, y = freq,  fill = as.factor(division.name))) + 
  labs(x = "USFS Division", y = NULL, fill = "USFS Division Name") +
  facet_wrap(~var,
             ncol = 2, scales = "free_y", strip.position ="left",
             labeller = as_labeller(plant.labels)) + 
  geom_col( position = "identity", col = "grey30") +
  geom_text(data = ch.plant, 
            aes(label = letter, x = division, y = ypos), 
            vjust = 1, size = 3) +
  geom_label(data = subset(plant.melt, division == "CONUS" & (value == "AM" | value == "E")),
             aes(x = 0, y = Inf,
                 label = letter, group = letter),
             fill = NA,
             fontface = "bold",
             size = 4,  hjust = "left",
             vjust = "top", label.size = NA,
             inherit.aes = F) +
  scale_y_continuous(breaks = c(0.0, 0.5, 1),
                     limits = c(0.0, 1.10)) +
  scale_fill_manual(values = div.pal.name,
                    labels = div.name.labels) + 
  theme_bw() + 
  theme(text = element_text(size = 13, color = "black"),
        axis.text = element_text(size = 13, color = "black"),
        axis.text.x = element_text(angle = 45, hjust = 1),
        panel.grid = element_blank(),
        strip.background = element_blank(), strip.placement = "outside",
        strip.text = element_text(size = 13),
        legend.position = "none") +
  guides(fill = guide_legend(nrow = 12, byrow = TRUE))

# add the map to the upper right, make a blank plot to start
blank <- ggplot2::ggplot(subset(plant.melt, value == "AM"),
                         aes(x = division, y = freq,  fill = as.factor(division.name))) + 
  theme_void()

map20 <- png::readPNG("Map_USFSDivisions.png")
c <- blank + annotation_raster(map20, xmin = -Inf, xmax = Inf, ymin = 0.2, ymax = 0.8)

# use the following code to add a map to the tiff
layout.map <- "
AADD
AABB
AABB
CCCC
"
# tiff(filename = "TreeCLA1_FFGC_Fig1_submitted.tiff", 
#      height = 9, width = 7.5, units="in", 
#      res=800, compression = "lzw")
# 
# a1 + a2 + b + c + patchwork::plot_layout(design = layout.map)
# 
# dev.off()


tiff(filename = "TreeCLA1_FFGC_Fig1_submitted.tiff", 
     height = 9, width = 7.5, units="in", 
     res=800, compression = "lzw")

a1 + a2 + b + c + patchwork::plot_layout(design = layout.map)

dev.off()

# # use the following code to create figure without map
# layout <- "
# AA##
# AABB
# AABB
# CCCC
# "
# tiff(filename = "TreeCLA1_FFGC_Fig1_nomap.tiff", 
#      height = 9, width = 7.5, units="in", 
#      res=800, compression = "lzw")
# 
# 
# a1 + a2 + b + patchwork::plot_layout(design = layout)
# 
# dev.off()

## Values of means and test statistics calculated for 
## results section

# temperature
temp.data.means <- 
  as.data.frame(
    temp.data %>%
      group_by(division.name, division) %>%
      summarise(mean = mean(temp.mean, na.rm = T), 
                sd = sd(temp.mean, na.rm = T),
                range = range(temp.mean, na.rm = T),
                min = min(temp.mean, na.rm = T),
                max = max(temp.mean, na.rm = T),
                n = n()))

print(temp.data.means)
temp.data.means$metric <- "temperature"
min(temp.data.means$min) #[1] 2.546675
max(temp.data.means$max) #[1] 23.99979
ch.temp.df

# precipitation
precip.data.means <- 
  as.data.frame(
    precip.data %>%
      group_by(division.name, division) %>%
      summarise(mean = mean(precip.mean, na.rm = T), 
                sd = sd(precip.mean, na.rm = T),
                range = range(precip.mean, na.rm = T),
                min = min(precip.mean, na.rm = T),
                max = max(precip.mean, na.rm = T),
                n = n()))

print(precip.data.means)
precip.data.means$metric <- "precipitation"
min(precip.data.means$min) #[1] 263.0384
max(precip.data.means$max) #[1] 2552.27
mean(precip.data.means$mean) #[1] 991.1086
sd(precip.data.means$mean) #[1] 421.8737
ch.precip.df
summary(aov.precip)
ch.precip

# pH

pH.data.means <- 
  as.data.frame(
    pH.data %>%
      group_by(division.name, division) %>%
      summarise(mean = mean(pH.mean, na.rm = T), 
                sd = sd(pH.mean, na.rm = T),
                range = range(pH.mean, na.rm = T),
                min = min(pH.mean, na.rm = T),
                max = max(pH.mean, na.rm = T),
                n = n()))

print(pH.data.means)
pH.data.means$metric <- "soil pH"
min(pH.data.means$mean) #[1] 5.304928
max(pH.data.means$mean) #[1]  7.724411
mean(pH.data.means$mean) #[1] 6.302135
sd(pH.data.means$mean) #[1] 0.7811921
ch.pH.df
summary(aov.pH)

# N dep

N.data.means <- 
  as.data.frame(
    N.data %>%
      group_by(division.name, division) %>%
      summarise(mean = mean(N.mean, na.rm = T), 
                sd = sd(N.mean, na.rm = T),
                range = range(N.mean, na.rm = T),
                min = min(N.mean, na.rm = T),
                max = max(N.mean, na.rm = T),
                n = n()))

print(N.data.means)
N.data.means$metric <- "N deposition"
min(N.data.means$mean) #[1] 2.94548
max(N.data.means$mean) #[1] 11.58691
mean(N.data.means$mean) #[1] 6.378331
sd(N.data.means$mean) #[1] 3.185627
ch.N.df
summary(aov.N)

# S dep

S.data.means <- 
  as.data.frame(
    S.data %>%
      group_by(division.name, division) %>%
      summarise(mean = mean(S.mean, na.rm = T), 
                sd = sd(S.mean, na.rm = T),
                range = range(S.mean, na.rm = T),
                min = min(S.mean, na.rm = T),
                max = max(S.mean, na.rm = T),
                n = n()))

print(S.data.means)
min(S.data.means$mean) #[1] 0.8795032
max(S.data.means$mean) #[1] 11.34621
mean(S.data.means$mean) #[1] 4.01333
sd(S.data.means$mean) #[1] 3.475485
S.data.means$metric <- "S deposition"
ch.S.df
summary(aov.S)

# NS dep (not reported in paper)

NS.data.means <- 
  as.data.frame(
    NS.data %>%
      group_by(division.name, division) %>%
      summarise(mean = mean(NS.mean, na.rm = T), 
                sd = sd(NS.mean, na.rm = T),
                range = range(NS.mean, na.rm = T),
                min = min(NS.mean, na.rm = T),
                max = max(NS.mean, na.rm = T),
                n = n()))

print(NS.data.means)
min(NS.data.means$mean) #[1] 303.1914
max(NS.data.means$mean) #[1] 1506.897
mean(NS.data.means$mean) #[1] 707.246
sd(NS.data.means$mean) #[1] 434.0073
NS.data.means$metric <- "N+S deposition"
ch.NS.df
summary(aov.NS)

# myco

print(myco.data.prop)
min(myco.pairwise.rstatix$p.adj)

# pheno

print(pheno.data.prop)
min(pheno.pairwise.rstatix$p.adj)

# create a table (Appendix S2: Table S4) with summary information
# on climate, pH, deposition, and functional
# trait info across divisions

data.means <- rbind(temp.data.means, precip.data.means,
                    pH.data.means, N.data.means,
                    S.data.means)

data.means <- 
  data.means %>%
  select(c(division, division.name, metric, mean, sd, n)) %>%
  distinct()

# TABLE S4 - mean and standard deviation of MAT, MAP, soil pH,
# N dep, S dep, % AM, % decid
show(data.means)

################################################################################
# 4. Figure 2: Variation in curve shape across divisions
################################################################################
# first, create example curves

n <- 10000    # number of data points
min <- 0.94   # lower bound of prob. of survival
max <- 1      # upper bound of prob. of survival
avg <- 0.97   # avg prob. of survival

# create the functions needed for graphing
Ndep <- c(seq(0, 30, length.out = n )) # range of N deposition
Sdep <- c(seq(0, 30, length.out = n))
increase <- c(seq(min, max, length.out = n))
decrease <- c(seq(max, min, length.out = n))
unimodal <-  (dnorm(Ndep, mean = mean(Ndep), sd = 25))
height <- 0.998/max(unimodal)
unimodal <- unimodal * height
tabletop <- pnorm(Sdep, mean = 25, sd = 2, lower.tail = 0.9405)
flat <- 0.97

# combine into a single data frame and reformat
example <- data.frame(flat, increase, decrease, unimodal, tabletop, Ndep, Sdep)
example.long <- gather(example, 
                       shape, value, flat:tabletop, factor_key=TRUE)

dat_text <- data.frame(
  label = c("flat (N + S)", "increase (N)", "decrease (N + S)", "unimodal (N)", "sigmoidal (S)"),
  shape = c("flat", "increase", "decrease", "unimodal", "tabletop"),
  colors.fig = c("#168B98", "#6FA15B","#A00E00", "#E18200", "#C9B71E")
)

shape.order <- c("decrease", "unimodal", "tabletop", "flat", "increase")

example.long$shape <- 
  reorder.factor(
    example.long$shape, 
    new.order=rev(shape.order))

ggplot(subset(example.long), 
       aes(x = Ndep, y = value)) +
  geom_point(aes(colour = shape), size = 1) +
  #geom_smooth(aes(colour = shape), se = T, size = 2) +
  facet_wrap(~forcats::fct_rev(shape), ncol = 1, scales = "free") +
  labs(x = expression("N or S deposition ("~kg~N/S~ha^{"-1"}~year^{"-1"}~")"),
       y = "probability of growth or survival") +
  scale_colour_manual("shape", values = shape.cols) +
  scale_x_continuous(limits = c(0, 25), breaks = c(0, 5, 10, 15, 20, 25)) +
  scale_y_continuous(limits = c(0.94, 1), breaks = c(0.94, 0.97, 1)) +
  theme(#plot.title = element_text(color = "black", size = 14),
    axis.line = element_line(colour = "black", size = 1),
    axis.text = element_text(size = 14, colour= "black"),
    axis.title = element_text(size = 20, colour = "black"),
    panel.grid = element_blank(),
    panel.border = element_rect(colour = NA, fill= NA , size = 0), 
    panel.background = element_blank(),
    strip.background = element_rect(colour = NA, fill= NA, size = 0),
    strip.text = element_blank(), 
    legend.position = "none") +
  geom_text(
    data    = dat_text,
    mapping = aes(x = 0, y = 0.985, label = label),
    hjust   = 0,
    vjust   = 1,
    size = 6, fontface = "bold", 
    color = dat_text$colors.fig
  )


# format data to "long" to aid in creating the ggplot
data.long <- 
  as.data.frame(
    data %>%
      dplyr::rename("Nitrogen" = "N.shape" ) %>%
      dplyr::rename("Sulfur" = "S.shape") %>%  
      reshape2::melt(data,
                     # ID variables - all the variables to keep but not split apart on
                     id.vars=c("division", "division.name", "process", "genus.species"),
                     # The source columns
                     measure.vars=c("Nitrogen", "Sulfur"),
                     # Name of the destination column that will identify the original
                     # column that the measurement came from
                     variable.name="deposition",
                     value.name="shape") %>%
      dplyr::mutate(process = sub("(.)", "\\U\\1", process, perl=TRUE))
  )

data.long$label <- stringr::str_to_title((paste(data.long$deposition, " - ", data.long$process)))
data.long <- as.data.frame(
  data.long %>% 
    dplyr::mutate(letter.num = case_when(
      label == "Nitrogen  -  Growth" ~ "(A)",
      label == "Nitrogen  -  Survival" ~ "(B)",
      label == "Sulfur  -  Growth" ~ "(C)",
      label == "Sulfur  -  Survival" ~ "(D)",
      TRUE ~ "A)")) %>% 
    dplyr::mutate(letter.prop = case_when(
      label == "Nitrogen  -  Growth" ~ "(E)",
      label == "Nitrogen  -  Survival" ~ "(F)",
      label == "Sulfur  -  Growth" ~ "(G)",
      label == "Sulfur  -  Survival" ~ "(H)",
      TRUE ~ "(A)")))


div.order <- c("CONUS", "24", "26", "32", "34",
               "31", "33", "25", "23", "22", "1",
               "21", "41")
data.long$division <- reorder.factor(data.long$division, new.order=div.order)

div.name.order <- c("CONUS",
                     "Marine",
                     "Mediterranean",
                     "Tropical/Subtropical Desert",
                     "Temperate Desert",
                     "Tropical/Subtropical Steppe",
                     "Temperate Steppe",
                     "Prairie",
                     "Subtropical",
                     "Hot Continental",
                     "Warm Continental",
                     "Savannah")
data.long$division.name <- reorder.factor(data.long$division.name, new.order=div.name.order)


# tile plots for curve response across all species (not in MS)

ggplot2::ggplot(subset(data.long), 
                mapping = aes(x = factor(division),
                              y = forcats::fct_reorder2(genus.species, 
                                                        desc(genus.species), 
                                                        genus.species))) + 
  coord_equal() +
  geom_tile(aes(fill = shape), colour = "white", width = 0.9, height = 0.9) +
  labs( y = "Tree species", x = "USFS Division") +
  facet_grid(~deposition + process, scales =  "fixed") +
  #facet_grid(~deposition, scales =  "fixed") +
  geom_hline(yintercept = 0.5 + 0:145, colour = "gray90", size = 0.02) +
  geom_vline(xintercept = 0.5 + 0:12, colour = "gray90", size = 0.02) +
  scale_fill_manual("Response to\nN or S deposition", 
                    na.value = "gray70",
                    values = shape.cols,
                    labels = shape.cols.labels) +
  scale_x_discrete(position = "bottom") +
  theme(plot.title = element_text(color="black", size=14),
        plot.margin = unit(c(0,0,0,0), "cm"),
        panel.spacing.x = unit(0, "lines"),
        panel.spacing.y = unit(0.1, "lines"), 
        axis.line = element_blank(),
        axis.text.x = element_text(colour = "black", 
                                   angle = 45, hjust = 1, size = 3),
        axis.text.y = element_text(size = 4, face = "italic", colour = "black"),
        axis.title.x = element_text(size = 8),
        axis.title.y = element_text(size = 8),
        #panel.grid = element_line(color="gray65"),
        panel.grid = element_blank(),
        panel.border = element_rect(colour = NA, fill = NA , size = 0), 
        strip.text = element_text(colour = "black", size = 8),
        panel.background = element_blank(),
        #strip.text = element_blank(),
        strip.background = element_rect(colour = NA, fill = NA, size = 0.1),
        legend.position = "none",
        legend.title = element_text(size = 8),
        legend.text = element_text(size = 8))

tiff(filename = "TreeCLA1_FFGC_Fig2_resubmitted.tiff", 
          height = 10.5, width = 9, units="in", 
           res=800, compression = "lzw")

# A2 species
ggplot2::ggplot(subset(data.long, genus.species == "Acer saccharum"| 
                         genus.species == "Betula papyrifera"| 
                         genus.species == "Liriodendron tulipifera"| 
                         genus.species == "Picea rubens"| 
                         genus.species == "Pinus ponderosa"| 
                         genus.species == "Populus deltoides"| 
                         genus.species == "Populus tremuloides"| 
                         genus.species == "Prunus serotina"| 
                         genus.species == "Pseudotsuga menziesii"| 
                         genus.species == "Sequoia sempervirens"| 
                         genus.species == "Tsuga heterophylla"), 
                mapping = aes(x = factor(division.name),
                              y = forcats::fct_reorder2(genus.species, desc(genus.species), genus.species))) + 
  geom_tile(aes(fill = shape), colour = "white", width = 1) +
  labs( y = "Tree species", x = "USFS Division") +
  facet_grid(deposition ~ process, scales =  "fixed") +
  coord_equal() +
  scale_fill_manual("Response to\nN or S deposition", 
                    na.value = "gray50",
                    values = shape.cols,
                    labels = shape.cols.labels) +
  scale_x_discrete(position = "bottom") +
  theme(plot.title = element_text(color="black", size=16),
        plot.margin = unit(c(0,0,0,0), "cm"),
        panel.spacing.x = unit(0, "lines"),
        panel.spacing.y = unit(0.1, "lines"), 
        axis.line = element_blank(),
        axis.text.x = element_text(colour = "black", angle = 45, hjust = 1, size = 16),
        axis.text.y = element_text(size = 16, face = "italic", colour = "black"),
        axis.title.x = element_text(size = 16),
        axis.title.y = element_text(size = 16),
        panel.grid = element_blank(),
        panel.border = element_rect(colour = "grey50", fill = NA , size = 0.5), 
        strip.text = element_text(colour = "black", size = 16),
        panel.background = element_blank(),
        #strip.text = element_blank(),
        strip.background = element_rect(colour = NA, fill = NA, size = 0),
        legend.position = "none")
dev.off()

################################################################################
# 5. Figure 3: Stacked bar chart
################################################################################

shape.order <- c("decrease", "unimodal", "tabletop", "flat", "increase")

data.long$shape <- 
  reorder.factor(
    data.long$shape, 
    new.order=rev(shape.order))

# proportion graphs for curve shape across divisions (N + S) 
NS.prop <- ggplot2::ggplot(subset(data.long, division != "CONUS"), 
                           aes(x = division.name, fill = shape)) + 
  # use the lines below to remove CONUS from the figure
  # ggplot2::ggplot(subset(data.long, division != "CONUS"), 
  #                         aes(x = division, fill = shape)) + 
  labs(x = "USFS Division", y = "Proportion of species'\nresponses to N or S dep") +
  geom_bar(position = "fill", color = "white") +
  facet_grid(~ deposition + process) +
  scale_fill_manual("Response to\nN or S deposition", 
                    na.value = "gray50",
                    values = shape.cols,
                    labels = shape.cols.labels) +
  guides(fill = guide_legend(nrow = 1)) + # if required nrow = 2
  # scale_y_continuous(limits = c(0,40),
  #                    breaks = c(0, 10, 20, 30, 40)) +
  scale_y_continuous(limits = c(0,1.05),
                     breaks = c(0, 0.25, 0.5, 0.75, 1)) +
  geom_label(data = subset(data.long, division == "24"
                           & genus.species == "Abies amabilis"),
             aes(x = 0, y = Inf,
                 label = letter.prop, group = letter.prop),
             fill = NA,
             fontface = "bold",
             size = 3,  hjust = "left",
             vjust = "top", label.size = NA,
             inherit.aes = F) +
  geom_label(data = subset(data.long, division == "24"
                           & genus.species == "Abies amabilis"),
             aes(x = 0, y = Inf,
                 label = label, group = label),
             fill = NA,
             fontface = "plain",
             size = 3,  x = 5.5,
             vjust = "top", label.size = NA,
             inherit.aes = F) +
  theme_bw() +
  guides(color = guide_legend(override.aes = list(size = 0.5))) +
  theme(text = element_text(size = 8, color = "black"),
        axis.text = element_text(size = 8, color = "black"),
        #axis.text.x = element_blank(), 
        axis.text.x = element_text(size = 7, angle = 45, hjust = 1), 
        #axis.title.x = element_blank(),
        #axis.ticks.x = element_blank(),
        panel.grid = element_blank(),
        strip.background = element_blank(), strip.placement = "outside",
        strip.text =  element_blank(),
        legend.position = "bottom",
        legend.title = element_text(size=7),
        legend.text = element_text(size=7))

# number graphs for curve shape across divisions (N + S) 
NS.number <- 
  ggplot2::ggplot(subset(data.long, division != "CONUS"), 
                  aes(x = division.name, fill = shape)) + 
  # use the lines below to remove CONUS from the figure
  # ggplot2::ggplot(subset(data.long, division != "CONUS"), 
  #                         aes(x = division, fill = shape)) + 
  labs(x = "USFS Division", 
       y = "Number of species'\nresponses to N or S dep") +
  geom_bar(color = "white") +
  facet_grid(~ deposition + process) +
  geom_label(data = subset(data.long, division == "24"
                           & genus.species == "Abies amabilis"),
             aes(x = 0, y = Inf,
                 label = letter.num, group = letter.num),
             fill = NA,
             fontface = "bold",
             size = 3,  hjust = "left",
             vjust = "top", label.size = NA,
             inherit.aes = F) +
  geom_label(data = subset(data.long, division == "24"
                           & genus.species == "Abies amabilis"),
             aes(x = 0, y = Inf,
                 label = label, group = label),
             fill = NA,
             fontface = "plain",
             size = 3,  x = 5.5,
             vjust = "top", label.size = NA,
             inherit.aes = F) +
  scale_fill_manual("Response to\nN or S deposition", 
                    na.value = "gray50",
                    values = shape.cols,
                    labels = shape.cols.labels) +
  scale_y_continuous(limits = c(0, 70), 
                     breaks = c(0, 10, 20, 30, 40, 50, 60, 70)) +
  #scale_y_continuous(limits = c(0, 160),
  #                   breaks = c(0, 50, 100, 150)) +
  guides(color = guide_legend(override.aes = list(size = 0.5))) +
  theme_bw() + 
  theme(text = element_text(size = 8, color = "black"),
        axis.text = element_text(size = 8, color = "black"),
        axis.text.x = element_blank(), 
        #axis.text.x = element_text(angle = 45, hjust = 1), 
        axis.title.x = element_blank(),
        axis.ticks.x = element_blank(),
        panel.grid = element_blank(),
        strip.background = element_blank(), strip.placement = "outside",
        strip.text =  element_blank(),
        legend.position = "none",
        legend.title = element_text(size=7),
        legend.text = element_text(size=7))

tiff(file = "TreeCLA1_FFGC_Fig3_resubmitted.tiff",
     width = 7.5, # The width of the plot in inches
     height = 5, res=1000, compression = "lzw",
     units = "in") # The height of the plot in inches

(NS.number +  plot_layout(guides = "collect") & theme(legend.position = "none")) / (NS.prop + plot_layout(guides = "collect") & theme(legend.position = 'bottom'))

dev.off()

################################################################################
# 6. Fisher's exact test - distribution of patterns 
# across regions
################################################################################

# values for reporting in the paper
print(data.prop <- as.data.frame(
  data.long %>% 
    dplyr::select(division, division.name, label, shape) %>%
    dplyr::group_by(division, division.name, label, shape) %>%
    dplyr::summarise(n = dplyr::n()) %>%
    dplyr::mutate(freq = n / sum(n)) %>%
    dplyr::rename(value = shape) %>%
    dplyr::mutate(var = "shape") %>%
    dplyr::filter(division.name == "CONUS")))

# division division.name                 label    value  n       freq   var
# 1     CONUS         CONUS   Nitrogen  -  Growth increase 55 0.39007092 shape
# 2     CONUS         CONUS   Nitrogen  -  Growth     flat 35 0.24822695 shape
# 3     CONUS         CONUS   Nitrogen  -  Growth unimodal 26 0.18439716 shape
# 4     CONUS         CONUS   Nitrogen  -  Growth decrease  7 0.04964539 shape
# 5     CONUS         CONUS   Nitrogen  -  Growth     <NA> 18 0.12765957 shape
# 6     CONUS         CONUS Nitrogen  -  Survival increase 11 0.07534247 shape
# 7     CONUS         CONUS Nitrogen  -  Survival     flat 80 0.54794521 shape
# 8     CONUS         CONUS Nitrogen  -  Survival unimodal 35 0.23972603 shape
# 9     CONUS         CONUS Nitrogen  -  Survival decrease 12 0.08219178 shape
# 10    CONUS         CONUS Nitrogen  -  Survival     <NA>  8 0.05479452 shape
# 11    CONUS         CONUS     Sulfur  -  Growth     flat 17 0.12056738 shape
# 12    CONUS         CONUS     Sulfur  -  Growth tabletop 98 0.69503546 shape
# 13    CONUS         CONUS     Sulfur  -  Growth decrease  8 0.05673759 shape
# 14    CONUS         CONUS     Sulfur  -  Growth     <NA> 18 0.12765957 shape
# 15    CONUS         CONUS   Sulfur  -  Survival     flat 50 0.34246575 shape
# 16    CONUS         CONUS   Sulfur  -  Survival tabletop 76 0.52054795 shape
# 17    CONUS         CONUS   Sulfur  -  Survival decrease 12 0.08219178 shape
# 18    CONUS         CONUS   Sulfur  -  Survival     <NA>  8 0.05479452 shape


data.s1s2 <- as.data.frame(
  data.prop %>% 
    dplyr::select(division, division.name, label, value, n) %>%
    dplyr::group_by(division, division.name, label, value) %>%
    tidyr::spread(value, n))

# Tables S1 (distribution of N dep responses) and S2 (S dep)
View(data.s1s2)

# run fisher's exact test to examine differences between distribution of patterns
# report these results in the text

# 1) N - growth
data.fishers.growN <- table(subset(data, process == "growth")$division, 
                            subset(data, process == "growth")$N.shape) 
row_names_df_to_remove<-c("CONUS", "1")
data.fishers.growN[!(row.names(data.fishers.growN) %in% row_names_df_to_remove),]

stats::fisher.test(data.fishers.growN,
                   alternative="two.sided",
                   simulate.p.value = T)
# p-value = 0.003498

data.fishers.growN.sub <- 
  table(subset(data.sub, process == "growth")$division, 
        subset(data.sub, process == "growth")$N.shape) 
row_names_df_to_remove<-c("CONUS", "1")
data.fishers.growN.sub[!(row.names(data.fishers.growN.sub) %in% row_names_df_to_remove),]

stats::fisher.test(data.fishers.growN.sub,
                   alternative="two.sided",
                   simulate.p.value = T)
# p-value = 0.001999

data %>%
  filter(division != "CONUS" & 
           process == "growth" & N.shape == "decrease") %>%
  select(division, genus.species) %>%
  arrange(division) %>%
  print()

# division          genus.species
# 1        24            Alnus rubra
# 2        34 Cercocarpus ledifolius
# 3        34       Quercus gambelii
# 4        33   Juniperus virginiana
# 5        33      Picea engelmannii
# 6        23           Betula nigra
# 7        23   Juniperus virginiana
# 8        23        Prunus serotina
# 9        22           Acer negundo
# 10       22  Platanus occidentalis
# 11       22     Quercus macrocarpa
# 12       21         Acer saccharum
# 13       21           Picea rubens

# 2) N - survival
data.fishers.survN <- table(subset(data, process == "survival")$division, 
                            subset(data, process == "survival")$N.shape) 
data.fishers.survN[!(row.names(data.fishers.survN) %in% row_names_df_to_remove),]

stats::fisher.test(data.fishers.survN,
                   alternative="two.sided",
                   simulate.p.value = T)
#p-value = 0.3633

data.fishers.survN.sub <- 
  table(subset(data.sub, process == "survival")$division, 
        subset(data.sub, process == "survival")$N.shape) 
row_names_df_to_remove<-c("CONUS", "1")
data.fishers.survN.sub[!(row.names(data.fishers.survN.sub) %in% row_names_df_to_remove),]

stats::fisher.test(data.fishers.survN.sub,
                   alternative="two.sided",
                   simulate.p.value = T)
# p-value = 0.3393

data %>%
  filter(division != "CONUS" & process == "survival" & N.shape == "decrease") %>%
  select(division, genus.species) %>%
  arrange(division) %>%
  print()

# division         genus.species
# 1        26       Abies magnifica
# 2        33        Pinus contorta
# 3        33 Pseudotsuga menziesii
# 4        23          Betula nigra
# 5        23          Carya glabra
# 6        23          Quercus alba
# 7        23       Quercus falcata
# 8        23         Quercus nigra
# 9        23      Quercus velutina
# 10       23    Taxodium distichum
# 11       23           Ulmus alata
# 12       22          Betula lenta
# 13       22          Carya glabra
# 14       22   Populus tremuloides
# 15       22 Quercus muehlenbergii
# 16       22           Ulmus rubra
# 17       21          Picea glauca

# 3) S - growth
data.fishers.growS <- table(subset(data, process == "growth")$division, 
                            subset(data, process == "growth")$S.shape) 
data.fishers.growS[!(row.names(data.fishers.growS) %in% row_names_df_to_remove),]

stats::fisher.test(data.fishers.growS,
                   alternative="two.sided",
                   simulate.p.value = T)
# p-value = 0.1014

data.fishers.growS.sub <- table(subset(data.sub, process == "growth")$division, 
                                subset(data.sub, process == "growth")$S.shape) 
data.fishers.growS.sub[!(row.names(data.fishers.growS.sub) %in% row_names_df_to_remove),]

stats::fisher.test(data.fishers.growS.sub,
                   alternative="two.sided",
                   simulate.p.value = T)
# p-value = 0.1199

data %>%
  filter(division != "CONUS" & process == "growth" & S.shape == "decrease") %>%
  select(division, genus.species) %>%
  arrange(division) %>%
  print()

# division         genus.species
# 1       24           Alnus rubra
# 2       34 Juniperus osteosperma
# 3       25      Quercus stellata
# 4       23          Betula nigra
# 5       23       Nyssa sylvatica
# 6       23           Pinus taeda
# 7       22          Acer negundo
# 8       22       Pinus banksiana
# 9       22  Robinia pseudoacacia

# 4) S - survival
data.fishers.survS <- table(subset(data, process == "survival")$division, 
                            subset(data, process == "survival")$S.shape) 
data.fishers.survS[!(row.names(data.fishers.survS) %in% row_names_df_to_remove),]

stats::fisher.test(data.fishers.survS,
                   alternative="two.sided",
                   simulate.p.value = T)
# p-value = 0.0004998

data.fishers.survS.sub <- 
  table(subset(data.sub, process == "survival")$division, 
        subset(data.sub, process == "survival")$S.shape) 
data.fishers.survS.sub[!(row.names(data.fishers.survS.sub) %in% row_names_df_to_remove),]

stats::fisher.test(data.fishers.survS.sub,
                   alternative="two.sided",
                   simulate.p.value = T)
# p-value = 0.0004998

data %>%
  filter(division != "CONUS" & process == "survival" & S.shape == "decrease") %>%
  select(division, genus.species) %>%
  arrange(division) %>%
  print()

# division          genus.species
# 1        24         Abies amabilis
# 2        24       Abies lasiocarpa
# 3        24      Picea engelmannii
# 4        24  Pseudotsuga menziesii
# 5        26        Pinus ponderosa
# 6        26  Pseudotsuga menziesii
# 7        32  Juniperus osteosperma
# 8        34 Juniperus occidentalis
# 9        34      Picea engelmannii
# 10       34  Pseudotsuga menziesii
# 11       31  Juniperus osteosperma
# 12       31           Pinus edulis
# 13       33          Abies grandis
# 14       33   Juniperus monosperma
# 15       33      Picea engelmannii
# 16       33         Pinus contorta
# 17       33        Pinus ponderosa
# 18       33  Pseudotsuga menziesii
# 19       33     Quercus macrocarpa
# 20       25  Gleditsia triacanthos
# 21       25          Juglans nigra
# 22       25        Prunus serotina
# 23       25       Quercus stellata
# 24       25            Ulmus rubra
# 25       23      Ostrya virginiana
# 26       23       Quercus stellata
# 27       22         Fraxinus nigra
# 28       22  Platanus occidentalis
# 29       22       Tsuga canadensis
# 30       22            Ulmus rubra
# 31       21     Betula populifolia
# 32       21        Pinus banksiana
# 33       21  Populus grandidentata
# 34       21     Quercus macrocarpa
# 35       21        Tilia americana
# 36       21        Ulmus americana


################################################################################
# 7. Figure S2: Variable and consistent responses across
# divisions
################################################################################

data.wide <- 
  as.data.frame(
    data %>%
      reshape2::melt(id = c("spcd", "genus.species", "division", "process"), 
                     measure.vars = c("N.shape", "S.shape"),
                     variable.name = c("deposition"), value.name = "shape") %>%
      tidyr::spread(key = c(division), value = c(shape))) %>%
  dplyr::mutate_at(c("deposition"), ~gsub("N.shape", "Nitrogen", .)) %>%
  dplyr::mutate_at(c("deposition"), ~gsub("S.shape", "Sulfur", .)) %>%
  dplyr::select(-c("CONUS")) %>%
  dplyr::rename_at(vars("24":"41"), ~paste0('div_',.)) %>%
  dplyr::mutate_all(~gsub("NA", NA, .))

data.wide.shapes <-
  as.data.frame(
    data.wide %>%
      dplyr::select(c("div_24":"div_41")) %>%
      rowwise %>%
      dplyr::mutate(shape.count = n_distinct(na.omit(c_across()))) %>%
      #cur_data has been depreciated since original code written
      #dplyr::mutate(shape.count = n_distinct(na.rm = T, 
      #                                       x = unlist(dplyr::cur_data()))) %>%
      ungroup %>%
      dplyr::mutate(shape.pattern = ifelse(shape.count == 1, "C", "V"))  %>%
      dplyr::select(c("shape.count", "shape.pattern")))

data.wide <- cbind(data.wide, data.wide.shapes)
data.wide$NA_frequency <-rowSums(apply(is.na(data.wide),2,as.numeric))
i <- ncol(subset(data.wide, select = div_24:div_41))

data.wide.graph <- 
  as.data.frame(
    data.wide %>%
      dplyr::mutate(div_number = i - NA_frequency) %>%
      dplyr::group_by(div_number, 
                      deposition, 
                      process, 
                      shape.pattern) %>%
      dplyr::summarise(count = n()))

data.wide.graph <- 
  as.data.frame(
    data.wide.graph %>% 
      dplyr::mutate(letter = case_when(
        deposition == "Nitrogen" & process == "growth" ~ "(A)",
        deposition == "Nitrogen" & process == "survival" ~ "(B)",
        deposition == "Sulfur" & process == "growth" ~ "(C)",
        deposition == "Sulfur" & process == "survival" ~ "(D)",
        TRUE ~ "F)")))

data.wide.graph$label <- stringr::str_to_title((paste(data.wide.graph$deposition, " - ", data.wide.graph$process)))

# data.wide.results <-
#   as.data.frame(
#     data.wide.graph %>%
#       dplyr::filter(div_number >= 2) %>%
#       #dplyr::select(-c(deposition, div_number, process, letter)) %>%
#       dplyr::count(label, shape.pattern) %>%
#       dplyr::mutate(Freq = count/sum(count)))

# number of species with data for only 1 division
data.wide.counts <-
  as.data.frame(data.wide.graph %>%
                  dplyr::filter(div_number >= 0) %>%
                  dplyr::group_by(deposition, process) %>%
                  dplyr::summarize(spcd.number = sum(count)))

data.wide.counts
# 141 species total forw growth, 146 total for survival

# number of species with data in 2 or more divisions
data.wide.counts.2 <-
  as.data.frame(data.wide.graph %>%
                  dplyr::filter(div_number >= 2) %>%
                  dplyr::group_by(deposition, process) %>%
                  dplyr::summarize(spcd.number = sum(count)))

data.wide.counts.2
# 70 species for survival
# 58 species for growth

print(data.wide.counts.2 <-
        as.data.frame(
          data.wide.graph %>%
            dplyr::filter(div_number >= 2) %>%
            dplyr::group_by(deposition, process, shape.pattern) %>%
            dplyr::summarize(count1 = sum(count))) %>%
            dplyr::group_by(deposition, process) %>%
            dplyr::mutate(prop = count1/sum(count1)) %>%
            dplyr::arrange(shape.pattern, prop))


print(data.wide.counts.3 <-
        as.data.frame(
          data.wide.graph %>%
            dplyr::filter(div_number >= 3) %>%
            dplyr::group_by(deposition, process, shape.pattern) %>%
            dplyr::summarize(count1 = sum(count))) %>%
        dplyr::group_by(deposition, process) %>%
        dplyr::mutate(prop = count1/sum(count1)) %>%
        dplyr::arrange(shape.pattern, prop))

# A tibble: 8 × 5
# Groups:   deposition, process [4]
# deposition process  shape.pattern count1  prop
# <chr>      <chr>    <chr>          <int> <dbl>
#   1 Nitrogen   growth   C                  5 0.263
# 2 Nitrogen   growth   V                 14 0.737
# 3 Nitrogen   survival C                  8 0.267
# 4 Nitrogen   survival V                 22 0.733
# 5 Sulfur     growth   C                  9 0.474
# 6 Sulfur     growth   V                 10 0.526
# 7 Sulfur     survival C                  5 0.167
# 8 Sulfur     survival V                 25 0.833

cv.pal <- MetBrewer::met.brewer("VanGogh1", 3)
scales::show_col(cv.pal) 

tiff(filename = "TreeCLA1_FFGC_FigS2_resubmitted.tiff", 
     height = 7.5, width = 7.5, units="in", 
     res=800, compression = "lzw")

ggplot(subset(data.wide.graph,
              div_number >= 2), aes(group = shape.pattern)) +
  geom_bar(stat = "identity", position = "stack", colour="black",
           aes(x = div_number, y = count,  fill = shape.pattern)) +
  facet_grid(deposition~process) +
  labs( x = "Number of USFS Divisions", 
        y = "Number of tree species with \n consistent or variable responses") +
  geom_label(data = subset(data.wide.graph, div_number == 2 &
                             shape.pattern == "V"),
             aes(x = Inf, y = Inf,
                 label = label, group = label),
             fill = NA,
             fontface = "plain",
             size = 5, 
             vjust = 1,
             hjust = 1.2, 
             label.size = NA,
             inherit.aes = F) +
  geom_label(data = subset(data.wide.graph, div_number == 2 &
                             shape.pattern == "V"),
             aes(x = Inf, y = Inf,
                 label = letter, group = letter),
             fill = NA,
             fontface = "bold",
             size = 5, hjust = "top",
             vjust = "right", label.size = NA,
             inherit.aes = F) +
  scale_fill_manual("legend", 
                    labels = c("C" = "consistent response",
                               "V" = "variable responses"),
                    values = c(cv.pal[2], cv.pal[1])) +
  theme(plot.title = element_text(color="black", size=14),
        plot.margin = unit(c(0.5,0.5,0.5,0.5), "cm"),
        axis.line = element_line(colour = "black"),
        axis.text = element_text(size = 14),
        axis.text.x = element_text(size = 14),
        axis.title.x = element_text(size = 14),
        axis.title.y = element_text(size = 14),
        panel.grid = element_blank(),
        panel.border = element_rect(colour = "black", fill= NA , size = 0.5), 
        panel.background = element_blank(),
        strip.text = element_blank(),
        strip.background = element_rect(colour=NA, fill= NA, size = 1),
        legend.title=element_blank(),
        legend.text = element_text(size = 14),
        legend.position='bottom')

dev.off()

################################################################################
# 8. Check possible mulitcollinearity between covariates
################################################################################

# correlation between all variables that we could use
# note, we will move forward with mean values in the
# analysis, but included minimum and maximum values 

data.corrplot <- 
  as.data.frame(data %>%
                  dplyr::filter(process == "survival" & division != "CONUS") %>%
                  dplyr::select(c("temp.mean", "temp.min", "temp.max",
                                  "precip.mean", "precip.min", "precip.max", 
                                  "pH.mean", "pH.min", "pH.max",
                                  "N.mean", "N.min", "N.max", 
                                  "S.mean", "S.min", "S.max")))

data.corrplot.mean <- 
  as.data.frame(data %>%
                  dplyr::filter(process == "survival" & division != "CONUS") %>%
                  dplyr::select(c("temp.mean", "precip.mean", "pH.mean", 
                                  "N.mean", "S.mean")))

corrplot.data.mean <- cor(data.corrplot.mean, use="complete.obs")
corrplot(corrplot.data.mean,  tl.col = "black",
         order = "hclust", method = "color", type = "upper",
         addCoef.col = "black", number.digits = 2,
         number.cex = 2) 
corr.matrix <- cor(data.corrplot, 
                   use = "pairwise.complete.obs",
                   method = "pearson")

corr.table <- 
  as.data.frame(
    corr.matrix %>%
      as.table %>% as.data.frame() %>%     
      dplyr::filter(!duplicated(paste0(pmax(as.character(Var1), 
                                            as.character(Var2)), 
                                       pmin(as.character(Var1), 
                                            as.character(Var2))))) %>%
      dplyr::arrange(desc(Freq)) %>%
      dplyr::filter(Freq <1 & abs(Freq) >= 0.68)) 

corr.table

# We should consider checking VIFs - N.mean and 
# S. mean are highly correlated and pH.mean and 
# precip.mean 

# Var1        Var2       Freq
# 1    temp.min   temp.mean  0.9481921
# 2    temp.max   temp.mean  0.9265611
# 3       S.min  precip.min  0.9192460
# 4       N.min      N.mean  0.8911392
# 5       S.max      S.mean  0.8810174
# 6    temp.max    temp.min  0.8202708
# 7      S.mean      N.mean  0.8092977
# 8      pH.min     pH.mean  0.7879809
# 9  precip.min    temp.min  0.7770102
# 10      S.max      N.mean  0.7699701
# 11      S.min      S.mean  0.7632287
# 12      S.min      N.mean  0.7410574
# 13 precip.min   temp.mean  0.7206825
# 14      S.min       N.min  0.7166254
# 15 precip.max precip.mean  0.6938774
# 16      S.min    temp.min  0.6932463
# 17    pH.mean  precip.min -0.7122688
# 18    pH.mean precip.mean -0.7234622 

# function from: https://www.r-bloggers.com/2020/07/create-a-publication-ready-correlation-matrix-with-significance-levels-in-r/

cor.test(data.corrplot$N.mean, data.corrplot$S.mean, use = "pairwise.complete.obs")
cor.test(data.corrplot$pH.mean, data.corrplot$precip.mean, use = "pairwise.complete.obs")

correlation_matrix <- function(df, 
                               type = "pearson",
                               digits = 3, 
                               decimal.mark = ".",
                               use = "all", 
                               show_significance = TRUE, 
                               replace_diagonal = FALSE, 
                               replacement = ""){
  
  # check arguments
  stopifnot({
    is.numeric(digits)
    digits >= 0
    use %in% c("all", "upper", "lower")
    is.logical(replace_diagonal)
    is.logical(show_significance)
    is.character(replacement)
  })
  # we need the Hmisc package for this
  require(Hmisc)
  
  # retain only numeric and boolean columns
  isNumericOrBoolean = vapply(df, function(x) is.numeric(x) | is.logical(x), logical(1))
  if (sum(!isNumericOrBoolean) > 0) {
    cat('Dropping non-numeric/-boolean column(s):', paste(names(isNumericOrBoolean)[!isNumericOrBoolean], collapse = ', '), '\n\n')
  }
  df = df[isNumericOrBoolean]
  
  # transform input data frame to matrix
  x <- as.matrix(df)
  
  # run correlation analysis using Hmisc package
  correlation_matrix <- Hmisc::rcorr(x, type = )
  R <- correlation_matrix$r # Matrix of correlation coeficients
  p <- correlation_matrix$P # Matrix of p-value 
  
  # transform correlations to specific character format
  Rformatted = formatC(R, format = 'f', digits = digits, decimal.mark = decimal.mark)
  
  # if there are any negative numbers, we want to put a space before the positives to align all
  if (sum(R < 0) > 0) {
    Rformatted = ifelse(R > 0, paste0(' ', Rformatted), Rformatted)
  }
  
  # add significance levels if desired
  if (show_significance) {
    # define notions for significance levels; spacing is important.
    stars <- ifelse(is.na(p), "   ", ifelse(p < .001, "***", ifelse(p < .01, "**", ifelse(p < .05, "* ", " "))))
    Rformatted = paste0(Rformatted, stars)
  }
  # build a new matrix that includes the formatted correlations and their significance stars
  Rnew <- matrix(Rformatted, ncol = ncol(x))
  rownames(Rnew) <- colnames(x)
  colnames(Rnew) <- paste(colnames(x), "", sep =" ")
  
  # replace undesired values
  if (use == 'upper') {
    Rnew[lower.tri(Rnew, diag = replace_diagonal)] <- replacement
  } else if (use == 'lower') {
    Rnew[upper.tri(Rnew, diag = replace_diagonal)] <- replacement
  } else if (replace_diagonal) {
    diag(Rnew) <- replacement
  }
  
  return(Rnew)
}

# all data correlation matrix (include min, max, mean)
corr.matrix.table <- correlation_matrix(data.corrplot)

# data used in analysis correlation matrix (mean only)
corr.matrix.table.mean <- correlation_matrix(data.corrplot.mean)

# create a nice html table for publication (Table S3)
sjPlot::tab_corr(data.corrplot.mean,
                 corr.method = "pearson",
                 na.deletion = "pairwise",
                 triangle = "upper", p.numeric = FALSE)

# now add information for the factored variables
data.corrplot.mean.all <- 
  as.data.frame(data %>%
                  dplyr::filter(process == "survival" & division != "CONUS") %>%
                  dplyr::mutate(pheno.type.1 = ifelse(pheno.type == "E", 1, 0)) %>%
                  dplyr::mutate(myco.1 = ifelse(myco == "AM", 1, 0)) %>%
                  dplyr::select(c("temp.mean", "precip.mean", "pH.mean", 
                                  "N.mean", "S.mean",  "myco.1", "pheno.type.1")))

# create a nice html table for publication
sjPlot::tab_corr(data.corrplot.mean.all,
                 corr.method = "pearson",
                 na.deletion = "pairwise",
                 triangle = "upper", p.numeric = FALSE)

################################################################################
# 9. Set up the data for ordinal models
################################################################################

# first, set the reference level and make sure curves are factors
data$N.shape <- as.factor(data$N.shape)
class(data$N.shape)
data$N.shape <- relevel(data$N.shape, ref="flat")

data$S.shape <- as.factor(data$S.shape)
class(data$S.shape)
data$S.shape <- relevel(data$S.shape, ref="flat")

data<- as.data.frame(data %>% 
                       dplyr::mutate(N.shape.num = ifelse(N.shape == "flat", 0, 
                                                          ifelse(N.shape == "increase", -1,
                                                                 ifelse(N.shape == "unimodal",  1,
                                                                        ifelse(N.shape == "decrease", 2, NA))))) %>% 
                       dplyr::mutate(S.shape.num = ifelse(S.shape == "flat", 0, 
                                                          ifelse(S.shape == "tabletop",  1,
                                                                 ifelse(S.shape == "decrease", 2, NA)))) %>% 
                       dplyr::mutate(NS.shape.num = ifelse(NS.shape == "flat", 0, 
                                                           ifelse(NS.shape == "increase", -1,
                                                                  ifelse(NS.shape == "unimodal",  1,
                                                                         ifelse(NS.shape == "decrease", 2, NA))))))

# next, we will separate growth and survival and deposition
# Nitrogen - Survival

data.surv <- subset(data, process == "survival" & division != "CONUS")
data.surv$N.shape.ord <- ordered(data.surv$N.shape,c("increase","flat",
                                                     "unimodal", "decrease"))
data.surv$N.shape.num <- ordered(data.surv$N.shape.num,c("-1","0", "1", "2"))

data.surv.N <- as.data.frame(
  data.surv %>% 
    dplyr::mutate(genus.species = sub(" ", "_", genus.species)) %>%
    dplyr::select(c("N.shape", "N.shape.num", "N.shape.ord","genus.species", "temp.mean", "precip.mean",  "pH.mean", "N.mean", "S.mean", "NS.mean", "myco", "pheno.type")) %>%
    drop_na())

data.surv.N$z.temp.mean <- as.numeric(scale(data.surv.N$temp.mean, center = TRUE, scale = TRUE))
data.surv.N$z.precip.mean <- as.numeric(scale(data.surv.N$precip.mean, center = TRUE, scale = TRUE))
data.surv.N$z.pH.mean <- as.numeric(scale(data.surv.N$pH.mean, center = TRUE, scale = TRUE))
data.surv.N$z.N.mean <- as.numeric(scale(data.surv.N$N.mean, center = TRUE, scale = TRUE))
data.surv.N$z.S.mean <- as.numeric(scale(data.surv.N$S.mean, center = TRUE, scale = TRUE))
data.surv.N$z.NS.mean <- as.numeric(scale(data.surv.N$NS.mean, center = TRUE, scale = TRUE))
dim(data.surv.N) #[1] 251  18

# Nitrogen - Growth
data.grow <- subset(data, process == "growth" & division != "CONUS")
data.grow$N.shape.ord <- ordered(data.grow$N.shape,c("increase","flat",
                                                     "unimodal", "decrease"))
data.grow$N.shape.num <- ordered(data.grow$N.shape.num,c("-1","0", "1", "2"))

data.grow.N <- as.data.frame(
  data.grow %>% 
    dplyr::mutate(genus.species = sub(" ", "_", genus.species)) %>%
    dplyr::select(c("N.shape", "N.shape.num", "N.shape.ord","genus.species", "temp.mean", "precip.mean",  "pH.mean", "N.mean", "S.mean", "NS.mean", "myco", "pheno.type")) %>%
    drop_na())

data.grow.N$z.temp.mean <- as.numeric(scale(data.grow.N$temp.mean, center = TRUE, scale = TRUE))
data.grow.N$z.precip.mean <- as.numeric(scale(data.grow.N$precip.mean, center = TRUE, scale = TRUE))
data.grow.N$z.pH.mean <- as.numeric(scale(data.grow.N$pH.mean, center = TRUE, scale = TRUE))
data.grow.N$z.N.mean <- as.numeric(scale(data.grow.N$N.mean, center = TRUE, scale = TRUE))
data.grow.N$z.S.mean <- as.numeric(scale(data.grow.N$S.mean, center = TRUE, scale = TRUE))
data.grow.N$z.NS.mean <- as.numeric(scale(data.grow.N$NS.mean, center = TRUE, scale = TRUE))
dim(data.grow.N) #[1] 208  18

# Sulfur - Survival

data.surv$S.shape.ord <- ordered(data.surv$S.shape,c("flat",
                                                     "tabletop", 
                                                     "decrease"))
data.surv$S.shape.num <- ordered(data.surv$S.shape.num,c("0", "1", "2"))

data.surv.S <- as.data.frame(
  data.surv %>% 
    dplyr::mutate(genus.species = sub(" ", "_", genus.species)) %>%
    dplyr::select(c("S.shape", "S.shape.num", "S.shape.ord","genus.species", "temp.mean", "precip.mean",  "pH.mean", "N.mean", "S.mean", "NS.mean", "myco", "pheno.type")) %>%
    drop_na())

data.surv.S$z.temp.mean <- as.numeric(scale(data.surv.S$temp.mean, center = TRUE, scale = TRUE))
data.surv.S$z.precip.mean <- as.numeric(scale(data.surv.S$precip.mean, center = TRUE, scale = TRUE))
data.surv.S$z.pH.mean <- as.numeric(scale(data.surv.S$pH.mean, center = TRUE, scale = TRUE))
data.surv.S$z.N.mean <- as.numeric(scale(data.surv.S$N.mean, center = TRUE, scale = TRUE))
data.surv.S$z.S.mean <- as.numeric(scale(data.surv.S$S.mean, center = TRUE, scale = TRUE))
data.surv.S$z.NS.mean <- as.numeric(scale(data.surv.S$NS.mean, center = TRUE, scale = TRUE))
dim(data.surv.S) #[1] 251  18

# Sulfur - Growth

data.grow$S.shape.ord <- ordered(data.grow$S.shape,c("flat",
                                                     "tabletop", 
                                                     "decrease"))
data.grow$S.shape.num <- ordered(data.grow$S.shape.num,c("0", "1", "2"))

data.grow.S <- as.data.frame(
  data.grow %>% 
    dplyr::mutate(genus.species = sub(" ", "_", genus.species)) %>%
    dplyr::select(c("S.shape", "S.shape.num", "S.shape.ord","genus.species", "temp.mean", "precip.mean",  "pH.mean", "N.mean", "S.mean", "NS.mean", "myco", "pheno.type")) %>%
    drop_na())

data.grow.S$z.temp.mean <- as.numeric(scale(data.grow.S$temp.mean, center = TRUE, scale = TRUE))
data.grow.S$z.precip.mean <- as.numeric(scale(data.grow.S$precip.mean, center = TRUE, scale = TRUE))
data.grow.S$z.pH.mean <- as.numeric(scale(data.grow.S$pH.mean, center = TRUE, scale = TRUE))
data.grow.S$z.N.mean <- as.numeric(scale(data.grow.S$N.mean, center = TRUE, scale = TRUE))
data.grow.S$z.S.mean <- as.numeric(scale(data.grow.S$S.mean, center = TRUE, scale = TRUE))
data.grow.S$z.NS.mean <- as.numeric(scale(data.grow.S$NS.mean, center = TRUE, scale = TRUE))
dim(data.grow.S) #[1] 208  18


# check correlations once more using z-score standardized data
z.data.corrplot.mean <- 
  as.data.frame(data.surv.N %>%
                  dplyr::select(c("z.temp.mean", "z.precip.mean", "z.pH.mean", 
                                  "z.N.mean", "z.S.mean",
                                  "z.NS.mean")))
z.corrplot.data.mean <- cor(z.data.corrplot.mean, use="complete.obs")
corrplot(z.corrplot.data.mean,  tl.col = "black",
         order = "hclust", method = "color", type = "upper",
         addCoef.col = "black", number.digits = 2,
         number.cex = 2) 
corr.matrix <- cor(z.data.corrplot.mean, 
                   use = "pairwise.complete.obs",
                   method = "pearson")

################################################################################
# 9A. Ordinal  models: Nitrogen - Growth
################################################################################

# lowest ordinal model is an intercept only model
ord.grow.N.int <- MASS::polr(N.shape.ord ~ 1,  data = data.grow.N, Hess = T)

# ordinal models for N growth
# all interactions included
ord.grow.N.global <- MASS::polr(N.shape.ord ~ (z.temp.mean + z.precip.mean + z.pH.mean + z.N.mean + z.S.mean + myco + pheno.type)^2,  data = data.grow.N, Hess = T)
vif(ord.grow.N.global)
AIC(ord.grow.N.global)
car::Anova(ord.grow.N.global)           
summary(ord.grow.N.global)
print(MuMIn::AICc(ord.grow.N.global)) #[1] 546.8311
performance::r2_nagelkerke(ord.grow.N.global) # 0.1840522 

# ordinal stepwise selection based on AIC - direction = "both" for global models
ord.grow.N.global.step <- 
  stepAIC(ord.grow.N.global, 
          direction = "both", 
          scope=list(lower=ord.grow.N.int, upper=ord.grow.N.global),
          trace = FALSE)

summary(ord.grow.N.global.step)
performance::r2_nagelkerke(ord.grow.N.global.step) #  0.135728 
print(MuMIn::AICc(ord.grow.N.global.step)) #[1] 503.2382


# hypothesis-driven interactions
ord.grow.N.hypoth <- MASS::polr(N.shape.ord ~ z.temp.mean + z.precip.mean + z.pH.mean + z.N.mean + z.S.mean + myco + pheno.type +
                                  z.temp.mean*z.precip.mean + z.temp.mean*z.N.mean + z.pH.mean*z.S.mean + z.N.mean*z.S.mean + z.N.mean*myco + z.pH.mean*myco,  
                                data = data.grow.N, Hess = T)

vif(ord.grow.N.hypoth)
AIC(ord.grow.N.hypoth)

# N and S only models
ord.grow.N.NS <- MASS::polr(N.shape.ord ~  z.N.mean + z.S.mean + z.N.mean*z.S.mean,  
                                data = data.grow.N, Hess = T)

vif(ord.grow.N.NS)
AIC(ord.grow.N.NS)
summary(ord.grow.N.NS)
performance::r2_nagelkerke(ord.grow.N.NS) #    0.03386365  
print(MuMIn::AICc(ord.grow.N.NS)) #[1] 517.7739

# ordinal stepwise selection based on AIC - direction = "both" for hypothesis models
ord.grow.N.hypoth.step <- 
  stepAIC(ord.grow.N.hypoth, 
          direction = "both", 
          scope=list(lower=ord.grow.N.int, upper=ord.grow.N.hypoth),
          trace = FALSE)

summary(ord.grow.N.hypoth.step)
performance::r2_nagelkerke(ord.grow.N.hypoth.step) #  0.07476374 
print(MuMIn::AICc(ord.grow.N.hypoth.step)) #[1] 509.5849


# main effects only
ord.grow.N.main <- MASS::polr(N.shape.ord ~ z.temp.mean + z.precip.mean + z.pH.mean + z.N.mean + z.S.mean + myco + pheno.type,  data = data.grow.N, Hess = T)

vif(ord.grow.N.main)
AIC(ord.grow.N.main)

# ordinal stepwise selection based on AIC - direction = "both" for main effects models
ord.grow.N.main.step <- 
  stepAIC(ord.grow.N.main, 
          direction = "both", 
          scope=list(lower=ord.grow.N.int, upper=ord.grow.N.main),
          trace = FALSE)

summary(ord.grow.N.main.step)
performance::r2_nagelkerke(ord.grow.N.main.step) #  0.07476374  
print(MuMIn::AICc(ord.grow.N.main.step)) #[1]  509.5849

# ordinal stepwise selection based on AIC - direction = "both" for global effects models
ord.grow.N.global.step <- 
  stepAIC(ord.grow.N.global, 
          direction = "both", 
          scope=list(lower=ord.grow.N.int, upper=ord.grow.N.global),
          trace = FALSE)

summary(ord.grow.N.global.step)
performance::r2_nagelkerke(ord.grow.N.global.step) #  0.135728 
print(MuMIn::AICc(ord.grow.N.global.step)) #[1] 503.2382

################################################################################
# 9B. Ordinal  models: Nitrogen - Survival
################################################################################

# lowest ordinal model is an intercept only model
ord.surv.N.int <- MASS::polr(N.shape.ord ~ 1,  data = data.surv.N, Hess = T)

# ordinal models for N survth
# all interactions included
ord.surv.N.global <- MASS::polr(N.shape.ord ~ (z.temp.mean + z.precip.mean + z.pH.mean + z.N.mean + z.S.mean + myco + pheno.type)^2,  data = data.surv.N, Hess = T)
vif(ord.surv.N.global)
AIC(ord.surv.N.global)
car::Anova(ord.surv.N.global)           
summary(ord.surv.N.global)
print(MuMIn::AICc(ord.surv.N.global)) #[1] 531.4726
performance::r2_nagelkerke(ord.surv.N.global) # 0.1620071 

# ordinal stepwise selection based on AIC - direction = "both" for global models
ord.surv.N.global.step <- 
  stepAIC(ord.surv.N.global, 
          direction = "both", 
          scope=list(lower=ord.surv.N.int, upper=ord.surv.N.global),
          trace = FALSE)

summary(ord.surv.N.global.step)
performance::r2_nagelkerke(ord.surv.N.global.step) #  0.1125961  
print(MuMIn::AICc(ord.surv.N.global.step)) #[1] 493.4676

# hypothesis-driven interactions
ord.surv.N.hypoth <- MASS::polr(N.shape.ord ~ z.temp.mean + z.precip.mean + z.pH.mean + z.N.mean + z.S.mean + myco + pheno.type +
                                  z.temp.mean*z.precip.mean + z.temp.mean*z.N.mean + z.pH.mean*z.S.mean + z.N.mean*z.S.mean + z.N.mean*myco + z.pH.mean*myco,  
                                data = data.surv.N, Hess = T)

vif(ord.surv.N.hypoth)
AIC(ord.surv.N.hypoth)

# ordinal stepwise selection based on AIC - direction = "both" for hypothesis models
ord.surv.N.hypoth.step <- 
  stepAIC(ord.surv.N.hypoth, 
          direction = "both", 
          scope=list(lower=ord.surv.N.int, upper=ord.surv.N.hypoth),
          trace = FALSE)

summary(ord.surv.N.hypoth.step)
performance::r2_nagelkerke(ord.surv.N.hypoth.step) #  0.07258645 
print(MuMIn::AICc(ord.surv.N.hypoth.step)) #[1] 494.3108

# N and S only models
ord.surv.N.NS <- MASS::polr(N.shape.ord ~  z.N.mean + z.S.mean + z.N.mean*z.S.mean,  
                            data = data.surv.N, Hess = T)

vif(ord.surv.N.NS)
AIC(ord.surv.N.NS)
summary(ord.surv.N.NS)
performance::r2_nagelkerke(ord.surv.N.NS) #    0.04117321 
print(MuMIn::AICc(ord.surv.N.NS)) # [1] 501.4636

# main effects only
ord.surv.N.main <- MASS::polr(N.shape.ord ~ z.temp.mean + z.precip.mean + z.pH.mean + z.N.mean + z.S.mean + myco + pheno.type,  data = data.surv.N, Hess = T)

vif(ord.surv.N.main)
AIC(ord.surv.N.main)

# ordinal stepwise selection based on AIC - direction = "both" for main effects models
ord.surv.N.main.step <- 
  stepAIC(ord.surv.N.main, 
          direction = "both", 
          scope=list(lower=ord.surv.N.int, upper=ord.surv.N.main),
          trace = FALSE)

summary(ord.surv.N.main.step)
performance::r2_nagelkerke(ord.surv.N.main.step) #  0.07258645  
print(MuMIn::AICc(ord.surv.N.main.step)) #[1]  494.3108 


################################################################################
# 9C. Ordinal  models: Sulfur - Growth
################################################################################

# lowest ordinal model is an intercept only model
ord.grow.S.int <- MASS::polr(S.shape.ord ~ 1,  data = data.grow.S, Hess = T)

# ordinal models for N growth
# all interactions included
ord.grow.S.global <- MASS::polr(S.shape.ord ~ (z.temp.mean + z.precip.mean + z.pH.mean + z.N.mean + z.S.mean + myco + pheno.type)^2,  data = data.grow.S, Hess = T)
vif(ord.grow.S.global)
AIC(ord.grow.S.global)
car::Anova(ord.grow.S.global)           
summary(ord.grow.S.global)
print(MuMIn::AICc(ord.grow.S.global)) #[1] 305.4204
performance::r2_nagelkerke(ord.grow.S.global) #  0.2332145   

# ordinal stepwise selection based on AIC - direction = "both" for global models
ord.grow.S.global.step <- 
  stepAIC(ord.grow.S.global, 
          direction = "both", 
          scope=list(lower=ord.grow.S.int, upper=ord.grow.S.global),
          trace = FALSE)

summary(ord.grow.S.global.step)
performance::r2_nagelkerke(ord.grow.S.global.step) #   0.1725754  
print(MuMIn::AICc(ord.grow.S.global.step)) #[1] 269.1034

# hypothesis-driven interactions
ord.grow.S.hypoth <- MASS::polr(S.shape.ord ~ z.temp.mean + z.precip.mean + z.pH.mean + z.N.mean + z.S.mean + myco + pheno.type +
                                  z.temp.mean*z.precip.mean + z.temp.mean*z.N.mean + z.pH.mean*z.S.mean + z.N.mean*z.S.mean + z.N.mean*myco + z.pH.mean*myco,  
                                data = data.grow.S, Hess = T)

vif(ord.grow.S.hypoth)
AIC(ord.grow.S.hypoth)

# ordinal stepwise selection based on AIC - direction = "both" for hypothesis models
ord.grow.S.hypoth.step <- 
  stepAIC(ord.grow.S.hypoth, 
          direction = "both", 
          scope=list(lower=ord.grow.S.int, upper=ord.grow.S.hypoth),
          trace = FALSE)

summary(ord.grow.S.hypoth.step)
performance::r2_nagelkerke(ord.grow.S.hypoth.step) #    0.1384507 
print(MuMIn::AICc(ord.grow.S.hypoth.step)) #[1] 266.1794

# N and S only models
ord.grow.S.NS <- MASS::polr(S.shape.ord ~  z.N.mean + z.S.mean + z.N.mean*z.S.mean,  
                            data = data.grow.S, Hess = T)

vif(ord.grow.S.NS)
AIC(ord.grow.S.NS)
summary(ord.grow.S.NS)
performance::r2_nagelkerke(ord.grow.S.NS) # 0.03434918
print(MuMIn::AICc(ord.grow.S.NS)) # [1]  278.8446

# main effects only
ord.grow.S.main <- MASS::polr(S.shape.ord ~ z.temp.mean + z.precip.mean + z.pH.mean + z.N.mean + z.S.mean + myco + pheno.type,  data = data.grow.S, Hess = T)

vif(ord.grow.S.main)
AIC(ord.grow.S.main)

# ordinal stepwise selection based on AIC - direction = "both" for main effects models
ord.grow.S.main.step <- 
  stepAIC(ord.grow.S.main, 
          direction = "both", 
          scope=list(lower=ord.grow.S.int, upper=ord.grow.S.main),
          trace = FALSE)

summary(ord.grow.S.main.step)
performance::r2_nagelkerke(ord.grow.S.main.step) #  0.06317684  
print(MuMIn::AICc(ord.grow.S.main.step)) #[1]  272.1932

################################################################################
# 9D. Ordinal  models: Sulfur - Survival
################################################################################

# lowest ordinal model is an intercept only model
ord.surv.S.int <- MASS::polr(S.shape.ord ~ 1,  data = data.surv.S, Hess = T)

# ordinal models for N survth
# all interactions included
ord.surv.S.global <- MASS::polr(S.shape.ord ~ (z.temp.mean + z.precip.mean + z.pH.mean + z.N.mean + z.S.mean + myco + pheno.type)^2,  data = data.surv.S, Hess = T)
vif(ord.surv.S.global)
AIC(ord.surv.S.global)
car::Anova(ord.surv.S.global)           
summary(ord.surv.S.global)
print(MuMIn::AICc(ord.surv.S.global)) #[1] 518.9503
performance::r2_nagelkerke(ord.surv.S.global) # 0.2110772  

# ordinal stepwise selection based on AIC - direction = "both" for global models
ord.surv.S.global.step <- 
  stepAIC(ord.surv.S.global, 
          direction = "both", 
          scope=list(lower=ord.surv.S.int, upper=ord.surv.S.global),
          trace = FALSE)

summary(ord.surv.S.global.step)
performance::r2_nagelkerke(ord.surv.S.global.step) #   0.1851688 
print(MuMIn::AICc(ord.surv.S.global.step)) #[1] 498.5667

# hypothesis-driven interactions
ord.surv.S.hypoth <- MASS::polr(S.shape.ord ~ z.temp.mean + z.precip.mean + z.pH.mean + z.N.mean + z.S.mean + myco + pheno.type +
                                  z.temp.mean*z.precip.mean + z.temp.mean*z.N.mean + z.pH.mean*z.S.mean + z.N.mean*z.S.mean + z.N.mean*myco + z.pH.mean*myco,  
                                data = data.surv.S, Hess = T)

vif(ord.surv.S.hypoth)
AIC(ord.surv.S.hypoth)

# ordinal stepwise selection based on AIC - direction = "both" for hypothesis models
ord.surv.S.hypoth.step <- 
  stepAIC(ord.surv.S.hypoth, 
          direction = "both", 
          scope=list(lower=ord.surv.S.int, upper=ord.surv.S.hypoth),
          trace = FALSE)

summary(ord.surv.S.hypoth.step)
performance::r2_nagelkerke(ord.surv.S.hypoth.step) #   0.0683706  
print(MuMIn::AICc(ord.surv.S.hypoth.step)) #[1] 502.3525

# N and S only models
ord.surv.S.NS <- MASS::polr(S.shape.ord ~  z.N.mean + z.S.mean + z.N.mean*z.S.mean,  
                            data = data.surv.S, Hess = T)

vif(ord.surv.S.NS)
AIC(ord.surv.S.NS)
summary(ord.surv.S.NS)
performance::r2_nagelkerke(ord.surv.S.NS) #   0.01101938  
print(MuMIn::AICc(ord.surv.S.NS)) # [1]  ] 508.8866


# main effects only
ord.surv.S.main <- MASS::polr(S.shape.ord ~ z.temp.mean + z.precip.mean + z.pH.mean + z.N.mean + z.S.mean + myco + pheno.type,  data = data.surv.S, Hess = T)

vif(ord.surv.S.main)
AIC(ord.surv.S.main)

# ordinal stepwise selection based on AIC - direction = "both" for main effects models
ord.surv.S.main.step <- 
  stepAIC(ord.surv.S.main, 
          direction = "both", 
          scope=list(lower=ord.surv.S.int, upper=ord.surv.S.main),
          trace = FALSE)

summary(ord.surv.S.main.step)
performance::r2_nagelkerke(ord.surv.S.main.step) #   0.02382124  
print(MuMIn::AICc(ord.surv.S.main.step)) #[1]  503.9851 

# we will select the selected hypothesis models to present in the paper

ord.surv.N.selected <- ord.surv.N.hypoth.step

ord.grow.N.selected <- ord.grow.N.hypoth.step

ord.surv.S.selected <- ord.surv.S.hypoth.step

ord.grow.S.selected <- ord.grow.S.hypoth.step

################################################################################
# 10. Model summaries and outputs
################################################################################

# create a table comparing model outputs of all selection
# procedures between ordinal models

predictor.labels = 
  c('(Intercept)' = "Intercept",
    "z.temp.mean" = "temperature",
    "z.precip.mean" = "precipitation",
    "z.pH.mean" = "soil pH",
    "z.N.mean" = "N deposition",
    "z.S.mean" = "S deposition",
    "pheno.typeE" = "deciduousness",
    "mycoEM" = "mycorrhizal association",
    "z.temp.mean:z.pH.mean" = "temp x soil pH",
    "z.temp.mean:z.precip.mean" = "temp x precip",
    "z.temp.mean:z.N.mean" = "temp x N dep", 
    "z.temp.mean:z.S.mean" = "temp x S dep ",
    "z.temp.mean:mycoEM" =  "temp x myco",
    "z.temp.mean:pheno.typeE" = "temp x decid",
    "z.precip.mean:z.pH.mean" =  "precip x soil pH",
    "z.precip.mean:z.N.mean" = "precip x N dep",
    "z.precip.mean:z.S.mean" = "precip x S dep",
    "z.precip.mean:mycoEM" = "precip x myco",
    "z.precip.mean:pheno.typeE" = "precip x decid",
    "z.pH.mean:z.N.mean" = "soil pH x N dep",
    "z.pH.mean:z.S.mean" = "soil pH x S dep",
    "z.pH.mean:mycoEM" = "soil pH x myco",
    "z.pH.mean:pheno.typeE" = "soil pH x decid",
    "z.N.mean:z.S.mean" = "N dep x S dep",
    "z.N.mean:mycoEM" = "N dep x myco",
    "z.N.mean:pheno.typeE" = "N dep x decid",
    "z.S.mean:mycoEM" = "S dep x myco",
    "z.S.mean:pheno.typeE" = "S dep x decid",
    "mycoEM:pheno.typeE" =  "myco x decid")

# Nitrogen - Survival 
sjPlot::tab_model(# ord.surv.N.global.step,
                  ord.surv.N.hypoth,
                  ord.surv.N.hypoth.step,
                  ord.surv.N.global,
                  ord.surv.N.main,
                  # ord.surv.N.main.step,
                  ord.surv.N.NS,
                  pred.labels = predictor.labels,
                  show.aicc = TRUE,
                  title = "Ordinal Models for Tree 
                  Survival Response to Nitrogen Deposition Model Comparison",
                  dv.labels = c("Hypothesis", "Hypothesis Step", "Global", "Main Effects", "N and S only"),
                  file = "ordinal_N_surv_updated_modcomp_2024.html")

# moving forward, we will begin using the mixed selection
# procedure, rename as "selected" and create a dataframe
# of odds ratio and CIs for visualization
sjPlot::plot_model(ord.surv.N.selected, type = "est")
plot(effects::allEffects(ord.surv.N.selected))
(ci <- stats::confint(ord.surv.N.selected))
OR.ord.surv.N <- exp(cbind(OR = coef(ord.surv.N.selected), ci))
ord.surv.N.selected.data <- sjPlot::get_model_data(ord.surv.N.selected, type = "est")
Anova(ord.surv.N.selected)

# Nitrogen - Growth 
sjPlot::tab_model(#ord.grow.N.global.step,
                  ord.grow.N.hypoth,
                  ord.grow.N.hypoth.step,
                  ord.grow.N.global,
                  ord.grow.N.main,
                  #ord.grow.N.main.step,
                  ord.grow.N.NS,
                  pred.labels = predictor.labels,
                  show.aicc = TRUE,
                  title = "Ordinal Models for Tree 
                  Growth Response to Nitrogen Deposition Model Comparison",
                  dv.labels = c("Hypothesis", "Hypothesis Step", "Global", "Main Effects", "N and S only"),
                  file = "ordinal_N_grow_updated_modcomp_2024.html")

sjPlot::plot_model(ord.grow.N.selected)
(ci <- stats::confint(ord.grow.N.selected))
OR.ord.grow.N <- exp(cbind(OR = coef(ord.grow.N.selected), ci))
print(ord.grow.N.selected)
plot(effects::allEffects(ord.grow.N.selected))
Anova(ord.grow.N.selected)


#moving forward, we will begin using the mixed selection
# procedure, rename as "selected" and create a dataframe
# of odds ratio and CIs for visualization
sjPlot::plot_model(ord.grow.N.selected, type = "est")
ord.grow.N.selected.data <- sjPlot::get_model_data(ord.grow.N.selected, type = "est")

# Sulfur - Survival 
sjPlot::tab_model(#ord.surv.S.global.step,
                  ord.surv.S.hypoth,
                  ord.surv.S.hypoth.step,
                  ord.surv.S.global,
                  ord.surv.S.main,
                  #ord.surv.S.main.step,
                  ord.surv.S.NS,
                  pred.labels = predictor.labels,
                  show.aicc = TRUE,
                  title = "Ordinal Models for Tree 
                  Survival Response to Sulfur Deposition Model Comparison",
                  dv.labels = c("Hypothesis", "Hypothesis Step", "Global", "Main Effects", "N and S only"),
                  file = "ordinal_S_surv_updated_modcomp_2024.html")

sjPlot::plot_model(ord.surv.S.selected)
(ci <- stats::confint(ord.surv.S.selected))
OR.ord.surv.S <- exp(cbind(OR = coef(ord.surv.S.selected), ci))
Anova(ord.surv.S.selected)
plot(effects::allEffects(ord.surv.S.selected))

# moving forward, we will begin using the mixed selection
# procedure, rename as "selected" and create a dataframe
# of odds ratio and CIs for visualization
sjPlot::plot_model(ord.surv.S.selected, type = "est")
ord.surv.S.selected.data <- sjPlot::get_model_data(ord.surv.S.selected, type = "est")

# Sulfur - Growth 
sjPlot::tab_model(#ord.grow.S.global.step,
                  ord.grow.S.hypoth,
                  ord.grow.S.hypoth.step,
                  ord.grow.S.global,
                  ord.grow.S.main,
                  #ord.grow.S.main.step,
                  ord.grow.S.NS,
                  pred.labels = predictor.labels,
                  show.aicc = TRUE,
                  title = "Ordinal Models for Tree 
                  Growth Response to Sulfur Deposition Model Comparison",
                  dv.labels = c("Hypothesis", "Hypothesis Step", "Global", "Main Effects", "N and S only"),
                  file = "ordinal_S_grow_updated_modcomp_2024.html")

sjPlot::plot_model(ord.grow.S.selected)
(ci <- stats::confint(ord.grow.S.selected))
OR.ord.grow.S <- exp(cbind(OR = coef(ord.grow.S.selected), ci))
Anova(ord.grow.S.selected)
plot(effects::allEffects(ord.grow.S.selected))

# moving forward, we will begin using the mixed selection
# procedure, rename as "selected" and create a dataframe
# of odds ratio and CIs for visualization
sjPlot::plot_model(ord.grow.S.selected, type = "est")
ord.grow.S.selected.data <- sjPlot::get_model_data(ord.grow.S.selected, type = "est")


################################################################################
# 11. Visualize odds ratio for model outputs - ordinal 
#     Creates Fig. 4
################################################################################

target.order <- c("increase - flat", 
                  "flat - unimodal/sigmoidal", 
                  "unimodal/sigmoidal - decrease",
                  "Temperature", 
                  "Precipitation",
                  "Soil pH",
                  "N deposition",
                  "S deposition", 
                  "Deciduousness",
                  "Mycorrhizal",
                  "Temp x pH",
                  "Temp x precip",
                  "Temp x N dep",
                  "Temp x S dep",
                  "Temp x myco",
                  "Temp x decid",
                  "Precip x pH",
                  "Precip x N dep",
                  "Precip x S dep",
                  "Precip x myco",
                  "Precip x decid",
                  "pH x N dep",
                  "pH x S dep",
                  "pH x myco",
                  "pH x decid",
                  "N dep x S dep",
                  "N dep x myco",
                  "N dep x decid",
                  "S dep x myco",
                  "S dep x decid",
                  "Myco x decid"
)

ord.surv.N.selected.data$process = "survival"
ord.surv.N.selected.data$deposition = "nitrogen"

ord.grow.N.selected.data$process = "growth"
ord.grow.N.selected.data$deposition = "nitrogen"

ord.surv.S.selected.data$process = "survival"
ord.surv.S.selected.data$deposition = "sulfur"

ord.grow.S.selected.data$process = "growth"
ord.grow.S.selected.data$deposition = "sulfur"

# combine selected data outputs to create a data frame
ord.OR.df <- rbind(ord.surv.N.selected.data,
                   ord.grow.N.selected.data,
                   ord.surv.S.selected.data,
                   ord.grow.S.selected.data)
ord.OR.df <- 
  as.data.frame(
    ord.OR.df %>%
      mutate(term.new = 
               forcats::fct_recode(term,
                                   "increase - flat" = "increase|flat",
                                   "flat - unimodal/sigmoidal" = "flat|unimodal",
                                   "flat - unimodal/sigmoidal" = "flat|tabletop",
                                   "unimodal/sigmoidal - decrease" = "unimodal|decrease",
                                   "unimodal/sigmoidal - decrease" = "tabletop|decrease",
                                   "Temperature"  = "z.temp.mean",
                                   "Precipitation" = "z.precip.mean",
                                   "Soil pH" = "z.pH.mean",
                                   "N deposition" = "z.N.mean",
                                   "S deposition" = "z.S.mean",
                                   "Deciduousness" = "pheno.typeE",
                                   "Mycorrhizal" = "mycoEM",
                                   "Temp x pH" = "z.temp.mean:z.pH.mean",
                                   "Temp x precip" = "z.temp.mean:z.precip.mean",
                                   "Temp x N dep" = "z.temp.mean:z.N.mean",
                                   "Temp x S dep" = "z.temp.mean:z.S.mean",
                                   "Temp x myco" = "z.temp.mean:mycoEM",
                                   "Temp x decid" = "z.temp.mean:pheno.typeE",
                                   "Precip x pH" = "z.precip.mean:z.pH.mean",
                                   "Precip x N dep" = "z.precip.mean:z.N.mean",
                                   "Precip x S dep" = "z.precip.mean:z.S.mean",
                                   "Precip x myco" = "z.precip.mean:mycoEM",
                                   "Precip x decid" = "z.precip.mean:pheno.typeE",
                                   "pH x N dep" = "z.pH.mean:z.N.mean",
                                   "pH x S dep" = "z.pH.mean:z.S.mean",
                                   "pH x myco" = "z.pH.mean:mycoEM",
                                   "pH x decid" = "z.pH.mean:pheno.typeE",
                                   "N dep x S dep" = "z.N.mean:z.S.mean",
                                   "N dep x myco" = "z.N.mean:mycoEM",
                                   "N dep x decid" = "z.N.mean:pheno.typeE",
                                   "S dep x myco" = "z.S.mean:mycoEM",
                                   "S dep x decid" = "z.S.mean:pheno.typeE",
                                   "Myco x decid" = "mycoEM:pheno.typeE"
               )))

ord.OR.df$term.new <- factor(ord.OR.df$term.new, levels=target.order)
ord.OR.df$sig <- ifelse(ord.OR.df$p.value >= 0.05, "0", "1")
ord.OR.df$term.new <- factor(ord.OR.df$term.new, levels=rev(target.order))
ord.OR.df$label <- stringr::str_to_title((paste(ord.OR.df$deposition, " - ", ord.OR.df$process)))
ord.OR.df$letter <- ifelse(ord.OR.df$label == "Nitrogen - Growth", 'A)', 
                           ifelse(ord.OR.df$label == "Nitrogen - Growth", 'A)'))

ord.OR.df <- as.data.frame(
  ord.OR.df %>% 
    dplyr::mutate(letter = case_when(
      label == "Nitrogen - Growth" ~ "A)",
      label == "Nitrogen  -  Survival" ~ "B)",
      label == "Sulfur  -  Growth" ~ "C)",
      label == "Sulfur  -  Survival" ~ "D)",
      TRUE ~ "A)"
    )))

tiff(filename = "TreeCLA1_FFGC_Fig4_resubmitted.tiff", 
     height = 4.5, width = 7.5, units="in", 
     res = 1000, compression = "lzw")

ggplot(subset(ord.OR.df,
              wrap.facet == "beta"), 
       aes(x = estimate, y = term.new, fill = group, colour = group, 
           alpha = sig)) + 
  labs(x = "Proportional Odds Ratio", y = "Covariates") +
  facet_wrap(~deposition + process, ncol = 4, nrow = 1,
             scales = "fixed") +
  geom_errorbar(aes(xmin = conf.low, xmax = conf.high, 
                    group = group, color = group, 
                    alpha = sig), size = 0.5, width = 0.5) +
  geom_vline(aes(xintercept = 1), size = 0.25, linetype = "dashed", color = "gray25") +
  geom_point(size = 1.5, aes(color = group, fill = group, alpha = sig)) +
  geom_rect(aes(xmin = -Inf, xmax = Inf, ymin = 9.5, ymax = 11), 
            fill = "white", color = NA, alpha = 1) +
  scale_colour_manual(name = "Effect direction:",
                      values = effect.cols,
                      labels = effect.labels) +
  scale_fill_manual(name = "Effect direction:",
                    values = effect.cols,
                    labels = effect.labels) +
  scale_shape_manual(values = c(21, 22)) +
  scale_x_continuous(limits = c(-0.1,8),
                     breaks = c(0, 2, 4, 6, 8)) +
  scale_y_discrete(expand = expansion(add = c(0))) +
  scale_alpha_discrete(name = "Significance:",
                       range = c(0.2, 1),
                       labels = sig.labels) +
  geom_label(data = subset(ord.OR.df,
                           term.new == "N deposition"),
             aes(x = -0.1, y = Inf,
                 label = letter, group = letter),
             fill = NA,
             fontface = "bold",
             size = 3,  hjust = "left",
             vjust = "top", label.size = NA,
             inherit.aes = F) +
  geom_label(data = subset(ord.OR.df,
                           term.new == "N deposition"),
             aes(x = 4.5, y = Inf,
                 label = label, group = label),
             fontface = "italic", fill = NA,
             size = 3,  hjust = "center",
             vjust = "top", label.size = NA,
             inherit.aes = F) +
  theme_bw() + 
  theme(axis.text = element_text(size = 10, color = "black"),
        axis.title = element_text(size = 10, color = "black"),
        panel.grid = element_blank(),
        panel.grid.major.y = element_line(colour = "grey90"), 
        strip.background = element_blank(),
        strip.placement = "none",
        strip.text = element_blank(),
        legend.position = "bottom", 
        legend.box="vertical", legend.margin=margin(),
        legend.text = element_text(size = 10))

dev.off()

################################################################################
# 12. Visualize predictions from models - ordinal
#     Create Figs 5 - 7
################################################################################

## First, all x vars are z-score standardized from the models
## and we therefore need to back-transform them in ggplot

# back-transform function
x.back.fun <-function(x, std, mn){
  (x*std) + mn
}

# z-score transform function
x.z.fun <-function(x, std, mn){
  (x - mn)/(std)
}

# example to make sure function works correctly
ph.back.eg <- x.back.fun(2, sd(data.grow.N$pH.mean), mean(data.grow.N$pH.mean)) # 7.172323
ph.z <- x.z.fun(ph.back.eg, sd(data.grow.N$pH.mean), mean(data.grow.N$pH.mean)) # 2

# All main effects will be included in the supplement, while
# interactions will be displayed in the main text

# Important predictors for growth - nitrogen response
#   Precip,

anova.growN <- car::Anova(ord.grow.N.selected, type=3)
precip.anova <- anova.growN["z.precip.mean",]

# Important predictors for survival
#  N dep, decid

anova.survN <- car::Anova(ord.surv.N.selected, type=3)
decid.anova <- anova.survN["pheno.type",]
N.anova <- anova.survN["z.N.mean",]

################################################################################
# 12A) Fig 5. Effects for N grow and surv
################################################################################

# Figure 5A) precip: N-growth
growN.precip <- ggeffects::ggeffect(ord.grow.N.selected, 
                                    terms = c("z.precip.mean"), 
                                    ci.lvl = 0.95)

growN.precip$response.level <- factor(growN.precip$response.level, 
                                      levels = c("decrease", 
                                                 "unimodal", 
                                                 "flat", 
                                                 "increase"))

print(min.precip.growN <- min(data.grow.N$precip.mean)) # 263.0384
print(max.precip.growN <- max(data.grow.N$precip.mean)) # 2552.27

precip.grow.raw <- c(00, 650, 1300, 1950, 2600)

precip.grow.mux <- mean(data.grow.N$precip.mean, na.rm = T)
precip.grow.sdx <- sd(data.grow.N$precip.mean, na.rm = T)
tr1 <- precip.grow.raw - precip.grow.mux
precip.grow.scaled <- tr1/precip.grow.sdx

precip.grow.labels <- c(0, 65, 130, 195, 260)

data.grow.N$response.level <- data.grow.N$N.shape.ord

growN.precip.fig <- 
  ggplot2::ggplot(growN.precip, 
                  aes(x = x, y = predicted, 
                      group = response.level, 
                      colour = response.level,
                      fill = response.level)) + 
  xlab(expression("Mean annual precipitation (cm)")) +
  labs(y = expression(atop(paste("Probability of ", bold("growth")),"response to N")))  +
  #geom_smooth(se = FALSE) +
  geom_ribbon(aes(ymin = conf.low, ymax = conf.high), alpha = 0.2, linetype = 1) +
  geom_text(aes(x = -Inf,
                y = Inf, 
                label = paste0("χ²(", precip.anova$'Df', ") = ",
                               c(round(precip.anova$'LR Chisq', 2)),
                               "; p = ", round(precip.anova$'Pr(>Chisq)', 3))),
            size = 3, vjust = 2, hjust = -0.1,
            color = "black", check_overlap = TRUE) +
  #scale_x_continuous(breaks = seq(-2.5, 4, by = 2)) + 
  #labels = seq(-3.5, 3, by = 2)) +
  scale_x_continuous(breaks = precip.grow.scaled,
                     labels = precip.grow.labels) +
  scale_fill_manual("response.level", 
                    values = shape.cols.N, 
                    labels = shape.cols.labels.N, 
                    name = "Growth or survival response to N") +
  scale_colour_manual("response.level", 
                      values = shape.cols.N, 
                      labels = shape.cols.labels.N, 
                      name = "Growth or survival response to N") +
  scale_y_continuous(breaks = c(0.0,  0.5,  1.0),
                     limits = c(0, 1)) +
  theme_bw() + 
  theme(text = element_text(size = 10, color = "black"),
        axis.text = element_text(size = 10, color = "black"),
        panel.grid = element_blank(),
        strip.background = element_blank(),
        strip.text = element_text(size = 10)) +
  geom_point(data = data.grow.N, aes (x = z.precip.mean, y = 0), pch = 73)

# Figure 5B) N-dep: N-surv

data.surv.N$response.level <- data.surv.N$N.shape.ord

survN.N <- ggeffects::ggeffect(ord.surv.N.selected, 
                               terms = c("z.N.mean"), ci.lvl = 0.95)


print(min.N.survN <- min(data.surv.N$N.mean)) # 1.543697
print(max.N.survN <- max(data.surv.N$N.mean)) # 12.7922

N.surv.raw <- c(1, 4, 7, 10, 13)

N.surv.mux <- mean(data.surv.N$N.mean, na.rm = T)
N.surv.sdx <- sd(data.surv.N$N.mean, na.rm = T)
tr1 <- N.surv.raw - N.surv.mux
N.surv.scaled <- tr1/N.surv.sdx

survN.N$response.level <- factor(survN.N$response.level, 
                                 levels = c("decrease", 
                                            "unimodal",
                                            "flat",
                                            "increase"))

survN.N.fig <- 
  ggplot2::ggplot(survN.N, aes(x = x, y = predicted, 
                               group = response.level,
                               colour = response.level,
                               fill = response.level)) + 
  xlab(expression("N dep (kg ha"^-1*" yr"^-1*")")) +
  labs(y = expression(atop(paste("Probability of ", bold("survival")),"response to N")))  +
  #geom_smooth(se = FALSE) +
  geom_text(aes(x = -1.2,
                y = 1, 
                label = paste0("χ²(", N.anova$'Df', ") = ",
                               c(round(N.anova$'LR Chisq', 2)),
                               "; p = ", round(N.anova$'Pr(>Chisq)', 4))),
            size = 3, vjust = 1, hjust = 0.4,
            color = "black", check_overlap = TRUE) +
  geom_ribbon(aes(ymin = conf.low, ymax = conf.high), alpha = 0.2, linetype = 1) +
  scale_fill_manual("response.level", 
                    values = shape.cols.N, 
                    labels = shape.cols.labels.N, 
                    name = "Survival response to N") +
  scale_colour_manual("response.level", 
                      values = shape.cols.N, 
                      labels = shape.cols.labels.N, 
                      name = "Survival response to N") +
  scale_x_continuous(breaks = N.surv.scaled,
                     labels = N.surv.raw) +
  scale_y_continuous(breaks = c(0.0,  0.5, 1.0),
                     limits = c(0, 1)) +
  theme_bw() + 
  theme(text = element_text(size = 10, color = "black"),
        axis.text = element_text(size = 10, color = "black"),
        panel.grid = element_blank(),
        strip.background = element_blank(),
        strip.text = element_text(size = 10)) +
  geom_point(data = data.surv.N, aes (x = z.N.mean, y = 0), pch = 73)

# Figure 5C) decidiousness: N-surv
pheno.names <- c(
  `D` = "Deciduous",
  `E` = "Evergreen"
)

survN.pheno <- ggeffect(ord.surv.N.selected, terms = c("pheno.type"), 
                        back.transform = FALSE, ci.lvl = 0.95)

survN.pheno$response.level <- factor(survN.pheno$response.level, 
                                     levels = c("decrease", 
                                                "unimodal", 
                                                "flat", 
                                                "increase"))
survN.pheno.fig  <-
  ggplot(subset(survN.pheno), 
         aes(x = x, y = predicted, 
             group = response.level, 
             colour = response.level,
             fill = response.level)) + 
  geom_bar(stat = "identity", position=position_dodge(.9),  alpha = 0.4,
           linetype = 2) +
  geom_errorbar( aes(x=x, ymin=conf.low, ymax=conf.high), width=0.2, colour="black", alpha=0.9, size=0.5, position=position_dodge(.9)) +
  geom_text(aes(x = "D",
                y = 1, 
                label = paste0("χ²(", decid.anova$'Df', ") = ",
                               c(round(decid.anova$'LR Chisq', 2)),
                               "; p = ", round(decid.anova$'Pr(>Chisq)', 3))),
            size = 3, vjust = 1, hjust = 0.25,
            color = "black", check_overlap = TRUE) +
  xlab(expression("Deciduousness")) +
  labs(y = expression(atop(paste("Probability of ", bold("survival")),"response to N")))  +
  scale_fill_manual("response.level", 
                    values = shape.cols.N, 
                    labels = shape.cols.labels.N, 
                    name = "Growth or survival response to N") +
  scale_colour_manual("response.level", 
                      values = shape.cols.N, 
                      labels = shape.cols.labels.N, 
                      name = "Growth or survival response to N") +
  scale_alpha_manual(values = c(0.2)) +
  scale_x_discrete(breaks = c("D", "E"),
                   labels = c("Deciduous", "Evergreen")) +
  scale_y_continuous(breaks = c(0.0, 0.5,  1.0),
                     limits = c(0, 1)) +
  theme_bw() + 
  theme(text = element_text(size = 10, color = "black"),
        axis.text = element_text(size = 10, color = "black"),
        panel.grid = element_blank(),
        strip.background = element_blank(),
        strip.text = element_blank())

tiff(filename = "TreeCLA1_FFGC_5_resubmitted.tiff", 
     height = 2.5, width = 8, units="in", 
     res = 1000, compression = "lzw")

ggarrange(growN.precip.fig, survN.N.fig, 
          survN.pheno.fig, 
          labels = c("A)", "B)", "C)"),
          font.label = list(size = 12, color = "black", face = "bold", family = NULL),
          hjust = -1.5, 
          align = c("hv"),
          common.legend = TRUE,
          nrow = 1,
          legend = "bottom")

dev.off()

################################################################################
# 12B) - Fig. S3 and S4. Main effects for S-growth & S-surv
################################################################################

anova.growS <- car::Anova(ord.grow.S.selected, type=3)
N.anova.growS <- anova.growS["z.N.mean",]
S.anova.growS <- anova.growS["z.S.mean",]
pHxS.anova.growS <- anova.growS["z.pH.mean:z.S.mean",]
decid.anova.growS <- anova.growS["pheno.type",]


anova.survS <- car::Anova(ord.surv.S.selected, type=3)
precip.anova.survS <- anova.survS["z.precip.mean",]
precip.anova.survS <- anova.survS["z.N.mean",]
Nxmyco.anova.survS <- anova.survS["z.N.mean:myco",]
pHxmyco.anova.survS <- anova.survS["z.pH.mean:myco",]



# Figure S3A) Ndep: S-growth

growS.N <- ggeffects::ggeffect(ord.grow.S.selected, 
                               terms = c("z.N.mean"), ci.lvl = 0.95)


print(min.N.growS <- min(data.grow.S$N.mean)) # 1.543697
print(max.N.growS <- max(data.grow.S$N.mean)) # 12.53618

growS.N$response.level <- factor(growS.N$response.level, 
                                 levels = c("decrease", 
                                            "tabletop", 
                                            "flat"))
data.grow.S$response.level <- data.grow.S$S.shape.ord

N.grow.raw <- c(1, 4, 7, 10, 13)

N.grow.mux <- mean(data.grow.S$N.mean, na.rm = T)
N.grow.sdx <- sd(data.grow.S$N.mean, na.rm = T)
tr1 <- N.grow.raw - N.grow.mux
N.grow.scaled <- tr1/N.grow.sdx

growS.N.fig <- 
  ggplot2::ggplot(growS.N, aes(x = x, y = predicted, 
                               group = response.level,
                               colour = response.level,
                               fill = response.level)) + 
  xlab(expression("N dep (kg ha"^-1*" yr"^-1*")")) +
  labs(y = expression(atop(paste("Probability of ", bold("growth")),"response to S")))  +
  #geom_smooth(se = FALSE) +
  geom_text(aes(x = -1.7,
                y = 1, 
                label = paste0("χ²(", N.anova.growS$'Df', ") = ",
                               c(round(N.anova.growS$'LR Chisq', 2)),
                               "; p = ", round(N.anova.growS$'Pr(>Chisq)', 4))),
            size = 3, vjust = 1, hjust = 0.4,
            color = "black", check_overlap = TRUE) +
  geom_ribbon(aes(ymin = conf.low, ymax = conf.high), alpha = 0.2, linetype = 1) +
  scale_fill_manual("response.level", 
                    values = shape.cols.S, 
                    labels = shape.cols.labels.S, 
                    name = "Growth response to S") +
  scale_colour_manual("response.level", 
                      values = shape.cols.S, 
                      labels = shape.cols.labels.S, 
                      name = "Growth response to S") +
  scale_x_continuous(breaks = N.grow.scaled,
                     labels = N.grow.raw) +
  scale_y_continuous(breaks = c(0.0,  0.5, 1.0),
                     limits = c(0, 1)) +
  theme_bw() + 
  theme(text = element_text(size = 10, color = "black"),
        axis.text = element_text(size = 10, color = "black"),
        panel.grid = element_blank(),
        strip.background = element_blank(),
        strip.text = element_text(size = 10)) +
  geom_point(data = data.grow.S, aes (x = z.N.mean, y = 0), pch = 73)

# Figure S3B) Sdep: S-growth

growS.S <- ggeffects::ggeffect(ord.grow.S.selected, 
                               terms = c("z.S.mean"), 
                               ci.lvl = 0.95)

growS.S$response.level <- factor(growS.S$response.level, 
                                 levels = c("decrease", 
                                            "tabletop", 
                                            "flat"))
print(miS.S.growS <- min(data.grow.S$S.mean)) # 0.4008913
print(max.S.growS <- max(data.grow.S$S.mean)) # 16.78446

S.grow.raw <- c(0, 4, 8, 12, 16)

S.grow.mux <- mean(data.grow.S$S.mean, na.rm = T)
S.grow.sdx <- sd(data.grow.S$S.mean, na.rm = T)
tr1 <- S.grow.raw - S.grow.mux
S.grow.scaled <- tr1/S.grow.sdx

growS.S.fig <- 
  ggplot2::ggplot(growS.S, aes(x = x, y = predicted, 
                               group = response.level,
                               colour = response.level,
                               fill = response.level)) + 
  xlab(expression("S deposition (kg ha"^-1*" yr"^-1*")")) +
  labs(y = expression(atop(paste("Probability of ", bold("growth")),"response to S")))  +
  #geom_smooth(se = FALSE) +
  geom_text(aes(x = -1,
                y = 1, 
                label = paste0("χ²(", S.anova.growS$'Df', ") = ",
                               c(round(S.anova.growS$'LR Chisq', 2)),
                               "; p = ", round(S.anova.growS$'Pr(>Chisq)', 3))),
            size = 3, vjust = 1, hjust = 0.4,
            color = "black", check_overlap = TRUE) +
  geom_ribbon(aes(ymin = conf.low, ymax = conf.high), alpha = 0.2, linetype = 1) +
  scale_fill_manual("response.level", 
                    values = shape.cols.S, 
                    labels = shape.cols.labels.S, 
                    name = "Growth response to S") +
  scale_colour_manual("response.level", 
                      values = shape.cols.S, 
                      labels = shape.cols.labels.S, 
                      name = "Growth response to S") +
  scale_x_continuous(breaks = S.grow.scaled,
                     labels = S.grow.raw) +
  scale_y_continuous(breaks = c(0.0,  0.5, 1.0),
                     limits = c(0, 1)) +
  theme_bw() + 
  theme(text = element_text(size = 10, color = "black"),
        axis.text = element_text(size = 10, color = "black"),
        panel.grid = element_blank(),
        strip.background = element_blank(),
        strip.text = element_text(size = 10)) +
  geom_point(data = data.grow.S, aes (x = z.S.mean, y = 0), pch = 73)

# Figure S3C) pheno.type

pheno.names <- c(
  `D` = "Deciduous",
  `E` = "Evergreen"
)

growS.pheno <- ggeffect(ord.grow.S.selected, terms = c("pheno.type"), 
                        back.transform = FALSE, ci.lvl = 0.95)

growS.pheno$response.level <- factor(growS.pheno$response.level, 
                                     levels = c("decrease", 
                                                "tabletop", 
                                                "flat"))
growS.pheno.fig  <-
  ggplot(subset(growS.pheno), 
         aes(x = x, y = predicted, 
             group = response.level, 
             colour = response.level,
             fill = response.level)) + 
  geom_bar(stat = "identity", position=position_dodge(.9),  alpha = 0.4,
           linetype = 2) +
  geom_errorbar( aes(x=x, ymin=conf.low, ymax=conf.high), width=0.2, colour="black", alpha=0.9, size=0.5, position=position_dodge(.9)) +
  geom_text(aes(x = "D",
                y = 1, 
                label = paste0("χ²(", decid.anova.growS$'Df', ") = ",
                               c(round(decid.anova.growS$'LR Chisq', 2)),
                               "; p = ", round(decid.anova.growS$'Pr(>Chisq)', 3))),
            size = 3, vjust = 1, hjust = 0.25,
            color = "black", check_overlap = TRUE) +
  xlab(expression("Deciduousness")) +
  labs(y = expression(atop(paste("Probability of ", bold("growth")),"response to S")))  +
  scale_fill_manual("response.level", 
                    values = shape.cols.S, 
                    labels = shape.cols.labels.S, 
                    name = "Growth or survival response to S") +
  scale_colour_manual("response.level", 
                      values = shape.cols.S, 
                      labels = shape.cols.labels.S, 
                      name = "Growth or survival response to S") +
  scale_alpha_manual(values = c(0.2)) +
  scale_x_discrete(breaks = c("D", "E"),
                   labels = c("Deciduous", "Evergreen")) +
  scale_y_continuous(breaks = c(0.0, 0.5,  1.0),
                     limits = c(0, 1)) +
  theme_bw() + 
  theme(text = element_text(size = 10, color = "black"),
        axis.text = element_text(size = 10, color = "black"),
        panel.grid = element_blank(),
        strip.background = element_blank(),
        strip.text = element_blank())


tiff(filename = "TreeCLA1_FFGC_FigS3_resubmitted.tiff", 
     height = 9, width = 4, units="in", 
     res = 1000, compression = "lzw")

ggarrange(growS.N.fig, 
          growS.S.fig, 
          growS.pheno.fig,
          labels = c("A)", "B)", "C)"),
          nrow = 3, ncol = 1, 
          common.legend = T, 
          legend = "bottom")

dev.off()

# Fig. S4A) precip: S-survival
data.surv.S$response.level <- data.surv.S$S.shape.ord
survS.precip <- ggeffects::ggeffect(ord.surv.S.selected, 
                                    terms = c("z.precip.mean"), 
                                    ci.lvl = 0.95)

survS.precip$response.level <- factor(survS.precip$response.level, 
                                      levels = c("decrease", 
                                                 "tabletop", 
                                                 "flat"))

precip.surv.scaled <- precip.grow.scaled
precip.surv.labels <- precip.grow.labels

survS.precip.fig <- 
  ggplot2::ggplot(survS.precip, 
                  aes(x = x, y = predicted, 
                      group = response.level, 
                      colour = response.level,
                      fill = response.level)) + 
  xlab(expression("Mean annual precipitation (cm)")) +
  labs(y = expression(atop(paste("Probability of ", bold("survival")),"response to S")))  +
  #labs(y = expression(atop("Probability of "~bold("survival"),~"response to S")))  +
  #geom_smooth(se = FALSE, linetype = "dashed") +
  geom_ribbon(aes(ymin = conf.low, ymax = conf.high), alpha = 0.2, linetype = 2) +
  geom_text(aes(x = -2,
                y = 1, 
                label = paste0("χ²(", precip.anova.survS$'Df', ") = ",
                               c(round(precip.anova.survS$'LR Chisq', 2)),
                               "; p = ", round(precip.anova.survS$'Pr(>Chisq)', 3))),
            size = 3, vjust = 1, hjust = 0.4,
            color = "black", check_overlap = TRUE) +
  scale_fill_manual("response.level", 
                    values = shape.cols.S, 
                    labels = shape.cols.labels.S, 
                    name = "Survival response to S") +
  scale_colour_manual("response.level", 
                      values = shape.cols.S, 
                      labels = shape.cols.labels.S, 
                      name = "Survival response to S") +
  scale_x_continuous(breaks = precip.surv.scaled,
                     labels = precip.surv.labels) +
  scale_y_continuous(breaks = c(0.0,  0.5,  1.0),
                     limits = c(0, 1)) +
  theme_bw() + 
  theme(text = element_text(size = 10, color = "black"),
        axis.text = element_text(size = 10, color = "black"),
        panel.grid = element_blank(),
        strip.background = element_blank(),
        strip.text = element_text(size = 10)) +
  geom_point(data = data.surv.S, aes (x = z.precip.mean, y = 0), pch = 73)


# Fig. S4A) Ndep: S-survival
survS.N <- ggeffects::ggeffect(ord.surv.S.selected, 
                               terms = c("z.N.mean"), ci.lvl = 0.95)


print(min.N.survS <- min(data.surv.S$N.mean)) # 1.543697
print(max.N.survS <- max(data.surv.S$N.mean)) # 12.7922

survS.N$response.level <- factor(survS.N$response.level, 
                                 levels = c("decrease", 
                                            "tabletop", 
                                            "flat"))

N.surv.raw <- c(1, 4, 7, 10, 13)

N.surv.mux <- mean(data.surv.S$N.mean, na.rm = T)
N.surv.sdx <- sd(data.surv.S$N.mean, na.rm = T)
tr1 <- N.surv.raw - N.surv.mux
N.surv.scaled <- tr1/N.surv.sdx

survS.N.fig <- 
  ggplot2::ggplot(growS.N, aes(x = x, y = predicted, 
                               group = response.level,
                               colour = response.level,
                               fill = response.level)) + 
  xlab(expression("N dep (kg ha"^-1*" yr"^-1*")")) +
  labs(y = expression(atop(paste("Probability of ", bold("survival")),"response to S")))  +
  #geom_smooth(se = FALSE) +
  geom_text(aes(x = -1.7,
                y = 1, 
                label = paste0("χ²(", N.anova.growS$'Df', ") = ",
                               c(round(N.anova.growS$'LR Chisq', 2)),
                               "; p = ", round(N.anova.growS$'Pr(>Chisq)', 4))),
            size = 3, vjust = 1, hjust = 0.4,
            color = "black", check_overlap = TRUE) +
  geom_ribbon(aes(ymin = conf.low, ymax = conf.high), alpha = 0.2, linetype = 2) +
  scale_fill_manual("response.level", 
                    values = shape.cols.S, 
                    labels = shape.cols.labels.S, 
                    name = "Survival response to S") +
  scale_colour_manual("response.level", 
                      values = shape.cols.S, 
                      labels = shape.cols.labels.S, 
                      name = "Survival response to S") +
  scale_x_continuous(breaks = N.surv.scaled,
                     labels = N.surv.raw) +
  scale_y_continuous(breaks = c(0.0,  0.5, 1.0),
                     limits = c(0, 1)) +
  theme_bw() + 
  theme(text = element_text(size = 10, color = "black"),
        axis.text = element_text(size = 10, color = "black"),
        panel.grid = element_blank(),
        strip.background = element_blank(),
        strip.text = element_text(size = 10)) +
  geom_point(data = data.surv.S, aes (x = z.N.mean, y = 0), pch = 73)


tiff(filename = "TreeCLA1_FFGC_FigS4_resubmitted.tiff", 
     height = 3, width = 7, units="in", 
     res = 1000, compression = "lzw")

ggarrange(survS.precip.fig, 
          survS.N.fig, 
          labels = c("A)", "B)"),
          nrow = 1, ncol = 2, 
          common.legend = T, 
          legend = "bottom")

dev.off()


################################################################################
# 12C) - Fig. 6. S-growth: N dep and pH x Sdep
################################################################################

# Figure 6A) Ndep: S-growth

growS.N <- ggeffects::ggeffect(ord.grow.S.selected, 
                               terms = c("z.N.mean"), 
                               ci.lvl = 0.95)

growS.N$response.level <- 
  factor(growS.N$response.level, 
         levels = c("decrease", "tabletop", "flat"))

data.grow.S$group <- "1"

growS.N.fig <- 
  ggplot2::ggplot(growS.N, aes(x = x, y = predicted, 
                               group = response.level,
                               colour = response.level,
                               fill = response.level)) + 
  xlab(expression("N dep (kg ha"^-1*" yr"^-1*")")) +
  labs(y = "Probability of growth\nresponse to S") +
  #geom_smooth(se = FALSE) +
  geom_text(aes(x = -1.15,
                y = 1.1, 
                label = paste0("χ²(", N.anova.growS$'Df', ") = ",
                               c(round(N.anova.growS$'LR Chisq', 2)),
                               "; p = ", round(N.anova.growS$'Pr(>Chisq)', 4))),
            size = 2.5, vjust = 1.5, hjust = 0.4,
            color = "black", check_overlap = TRUE) +
  geom_ribbon(aes(ymin = conf.low, ymax = conf.high), alpha = 0.2, linetype = 1) +
  facet_wrap(~group)+
  scale_fill_manual("response.level", 
                    values = shape.cols.S, 
                    labels = shape.cols.labels.S, 
                    name = "Growth response to S") +
  scale_colour_manual("response.level", 
                      values = shape.cols.S, 
                      labels = shape.cols.labels.S, 
                      name = "Growth response to S") +
  scale_x_continuous(breaks = N.grow.scaled,
                     labels = N.grow.raw) +
  scale_y_continuous(breaks = c(0.0,  0.5, 1.0),
                     limits = c(-0.1, 1.1)) +
  theme_bw() + 
  theme(text = element_text(size = 10, color = "black"),
        axis.text = element_text(size = 10, color = "black"),
        panel.grid = element_blank(),
        strip.background = element_blank(),
        strip.text = element_text(size = 10, colour = "white"),
        legend.position = "none") +
  geom_point(data = data.grow.S, aes (x = z.N.mean, y = -0.1), 
             pch = 73)
legend <- cowplot::get_legend(growS.N.fig)

# Fig 6B) S x pH: S-growth
growS.SxpH <- ggeffects::ggeffect(ord.grow.S.selected, 
                                  terms = c("z.S.mean", "z.pH.mean"), 
                                  ci.lvl = 0.95)
pH_names_one <- c(
  `-1` = "Low pH (5.1)",
  `0` = "Medium pH (5.8)",
  `1` = "High pH (6.5)"
)


growS.SxpH$response.level <- 
  factor(growS.SxpH$response.level, 
         levels = c("decrease", "tabletop", "flat"))

data.grow.S <-
  data.grow.S %>%
  mutate(group = case_when(z.pH.mean < -0.5 ~ "-1",
                           z.pH.mean >= -0.5 & z.pH.mean < 0.5 ~ "0",
                           TRUE ~ "1"))

growS.SxpH.fig <- 
  ggplot2::ggplot(growS.SxpH, 
                  aes(x = x, y = predicted, 
                      group = response.level, 
                      colour = response.level,
                      fill = response.level)) + 
  xlab(expression("S deposition (kg ha"^-1*" yr"^-1*")")) +
  labs(y = "Probability of growth\n response to S")  +
  facet_wrap(~group, labeller = as_labeller(pH_names_one), nrow = 1) +
  #geom_smooth(se = FALSE) +
  geom_ribbon(aes(ymin = conf.low, ymax = conf.high), alpha = 0.2, linetype = 1) +
  geom_text(data = subset(growS.SxpH,
                          group == -1 ),
            aes(x = -Inf,
                y = 1.1, 
                label = paste0("χ²(", pHxS.anova.growS$'Df', ") = ",
                               c(round(pHxS.anova.growS$'LR Chisq', 2)),
                               "; p = ", round(pHxS.anova.growS$'Pr(>Chisq)', 4))),
            size = 2.75, vjust = 1.5, hjust = -0.05,
            color = "black", check_overlap = TRUE) +
  scale_fill_manual("response.level", 
                    values = shape.cols.S, 
                    labels = shape.cols.labels.S, 
                    name = "Growth or survival response to S") +
  scale_colour_manual("response.level", 
                      values = shape.cols.S, 
                      labels = shape.cols.labels.S, 
                      name = "Growth or survival response to S") +
  scale_x_continuous(breaks = S.grow.scaled,
                     labels = S.grow.raw) +
  scale_y_continuous(breaks = c(0.0,  0.5,  1.0),
                     limits = c(-0.1, 1.1)) +
  theme_bw() + 
  theme(text = element_text(size = 10, color = "black"),
        axis.text = element_text(size = 10, color = "black"),
        panel.grid = element_blank(),
        strip.background = element_blank(),
        strip.text = element_text(size = 10),
        legend.position = "none") +
  geom_point(data = data.grow.S, aes (x = z.S.mean, y = -0.1), 
             pch = 73)

tiff(filename = "TreeCLA1_FFGC_Fig6_resubmitted.tiff", 
     height = 2.5, width = 7.5, units="in", 
     res = 1000, compression = "lzw")

figure6 <- 
  cowplot::ggdraw() +
  cowplot::draw_plot(growS.N.fig, x = 0, y = 0, width = 0.27, height = 1) +
  cowplot::draw_plot(growS.SxpH.fig, x = 0.27, y = 0, width = 0.63, height = 1) +
  cowplot::draw_plot_label(label = c("A)", "B)"), 
                           size = 12,
                           x = c(0, 0.25), 
                           y = c(1, 1))
cowplot::plot_grid(figure6, legend, nrow = 2, rel_heights = c(1, 0.1))

dev.off()

################################################################################
# 12D) - Fig. 7. Myco S-surv & environmental covariate
################################################################################

#Figure 7A) myco x Ndep: S-survival
survS.mycoxNdep <- ggeffects::ggeffect(ord.surv.S.selected, 
                                       terms = c("z.N.mean", "myco"), 
                                       ci.lvl = 0.95)

print(min.N.survN <- min(data.surv.N$N.mean)) # 1.543697
print(max.N.survN <- max(data.surv.N$N.mean)) # 12.7922

N.surv.raw <- c(1, 4, 7, 10, 13)

N.surv.mux <- mean(data.surv.N$N.mean, na.rm = T)
N.surv.sdx <- sd(data.surv.N$N.mean, na.rm = T)
tr1 <- N.surv.raw - N.surv.mux
N.surv.scaled <- tr1/N.surv.sdx

survS.mycoxNdep$response.level <- 
  factor(survS.mycoxNdep$response.level, 
         levels = c("decrease", "tabletop", "flat"))

data.surv.S$group <- data.surv.S$myco

survS.mycoxNdep.fig <- 
  ggplot2::ggplot(survS.mycoxNdep, 
                  aes(x = x, y = predicted, 
                      group = response.level, 
                      colour = response.level,
                      fill = response.level)) + 
  xlab(expression("N deposition (kg ha"^-1*" yr"^-1*")")) +
  labs(y = "Probability of survival\n response to S")  +
  facet_wrap(~group, labeller = as_labeller(myco_names), nrow = 1) +
  #geom_smooth(se = FALSE, linetype = "dashed") +
  geom_ribbon(aes(ymin = conf.low, ymax = conf.high), alpha = 0.2, linetype = 2) +
  geom_text(data = subset(survS.mycoxNdep,
                          group == "AM" ),
            aes(x = -2,
                y = 1, 
                label = paste0("χ²(", Nxmyco.anova.survS$'Df', ") = ",
                               c(round(Nxmyco.anova.survS$'LR Chisq', 2)),
                               "; p = ", round(Nxmyco.anova.survS$'Pr(>Chisq)', 4))),
            size = 3, vjust = 1, hjust = 0.1,
            color = "black", check_overlap = TRUE) +
  scale_fill_manual("response.level", 
                    values = shape.cols.S, 
                    labels = shape.cols.labels.S, 
                    name = "Survival response to S") +
  scale_colour_manual("response.level", 
                      values = shape.cols.S, 
                      labels = shape.cols.labels.S, 
                      name = "Survival response to S") +
  scale_x_continuous(breaks = N.surv.scaled,
                     labels = N.surv.raw) +
  scale_y_continuous(breaks = c(0.0,  0.5,  1.0),
                     limits = c(-0.1, 1)) +
  theme_bw() + 
  theme(text = element_text(size = 10, color = "black"),
        axis.text = element_text(size = 10, color = "black"),
        panel.grid = element_blank(),
        strip.background = element_blank(),
        strip.text = element_text(size = 10),
        legend.position = "none") +
  geom_point(data = data.surv.S, aes (x = z.N.mean, y = -0.1), 
             pch = 73)

#Figure 7B) myco x pH: S-survival

pH.surv.raw <- c(5, 6, 7, 8)

pH.surv.mux <- mean(data.surv.S$pH.mean, na.rm = T)
pH.surv.sdx <- sd(data.surv.S$pH.mean, na.rm = T)
tr1 <- pH.surv.raw - pH.surv.mux
pH.surv.scaled <- tr1/pH.surv.sdx

pH.surv.labels <-  c(5, 6, 7, 8)

myco_names <- c(
  `AM` = "AMF",
  `EM` = "EcM"
)
survS.mycoxpH <- ggeffects::ggeffect(ord.surv.S.selected, 
                                         terms = c("z.pH.mean", "myco"), 
                                         ci.lvl = 0.95)
survS.mycoxpH$response.level <- 
  factor(survS.mycoxpH$response.level, 
         levels = c("decrease", "tabletop", "flat"))

survS.mycoxpH.fig <- 
  ggplot2::ggplot(survS.mycoxpH, 
                  aes(x = x, y = predicted, 
                      group = response.level, 
                      colour = response.level,
                      fill = response.level)) + 
  xlab(expression("Soil pH")) +
  labs(y = "Probability of survival\n response to S")  +
  facet_wrap(~group, labeller = as_labeller(myco_names), nrow = 1) +
  #geom_smooth(se = FALSE, linetype = "dashed") +
  geom_ribbon(aes(ymin = conf.low, ymax = conf.high), alpha = 0.2, linetype = 2) +
  geom_text(data = subset(survS.mycoxpH,
                          group == "AM" ),
            aes(x = -1,
                y = 1, 
                label = paste0("χ²(", pHxmyco.anova.survS$'Df', ") = ",
                               c(round(pHxmyco.anova.survS$'LR Chisq', 2)),
                               "; p = ", round(pHxmyco.anova.survS$'Pr(>Chisq)', 4))),
            size = 3, vjust = 1, hjust = 0.1,
            color = "black", check_overlap = TRUE) +
  scale_fill_manual("response.level", 
                    values = shape.cols.S, 
                    labels = shape.cols.labels.S, 
                    name = "Survival response to S") +
  scale_colour_manual("response.level", 
                      values = shape.cols.S, 
                      labels = shape.cols.labels.S, 
                      name = "Survival response to S") +
  scale_x_continuous(breaks = pH.surv.scaled,
                     labels = pH.surv.labels) +
  scale_y_continuous(breaks = c(0.0,  0.5,  1.0),
                     limits = c(-0.1, 1)) +
  theme_bw() + 
  theme(text = element_text(size = 10, color = "black"),
        axis.text = element_text(size = 10, color = "black"),
        axis.text.x = element_text(size = 8),
        panel.grid = element_blank(),
        strip.background = element_blank(),
        strip.text = element_text(size = 10),
        legend.position = "none") +
  geom_point(data = data.surv.S, aes (x = z.pH.mean, y = -0.1), 
             pch = 73)

tiff(filename = "TreeCLA1_FFGC_Fig7_resubmitted.tiff", 
     height = 5.5, width = 4.5, units="in", 
     res = 1000, compression = "lzw")

ggarrange(nrow = 2, labels = c("A)", "B)"),
          common.legend = T, 
          vjust = 1.1,
          font.label = list(face = "bold", family = NULL),
          legend = "bottom", align = "hv",
          survS.mycoxNdep.fig,
          survS.mycoxpH.fig)
dev.off() 

################################################################################
# 13. Phylogenetic analysis on residuals
#     Presented in the methods section
################################################################################

fia.tree <- ape::read.tree("C:/Users/rdalton/OneDrive - Environmental Protection Agency (EPA)/Profile/Documents/Projects/TreeCLA1/Manuscript/FFGC submission/Data and R code/data_Rcode_regionaltree/Potterwoodall2012_phylogenetic.txt")

plot(fia.tree)
fia.tree$node.label<-NULL
zoom(fia.tree, list(grep("Acer", fia.tree$tip.label)), subtree=FALSE)
fia.all <- as.data.frame(unique(fia.tree$tip.label))
names(fia.all)[names(fia.all) == "unique(fia.tree$tip.label)"] <- "genus.species"
data.all <- as.data.frame(unique(data$genus.species))
names(data.all)[names(data.all) == "unique(data$genus.species)"] <- "genus.species"
data.all$genus.species <- sub(" ", "_", data.all$genus.species)

data.all.tree <- merge(data.all, fia.all,
                       by = c("genus.species"),
                       all.x = T, all.y = F
)
print(species.to.check <- setdiff(data.all, fia.all))

# 1 Abies_shastensis

spec.to.remove <- setdiff(fia.all, data.all)
names(spec.to.remove) <- NULL
spec.to.remove <- as.list(spec.to.remove)
spec.to.remove <- print(unlist(spec.to.remove))     

fia.tree2 <- drop.tip(fia.tree, spec.to.remove)
plot(fia.tree2)
plot.phylo(fia.tree2, type="fan", edge.color="black", 
           tip.color="black", cex=0.5)

##### Nitrogen growth
# model residuals - N growth (selected model)
data.grow.N$index <- rownames(data.grow.N)
resid.grow.N <- as.data.frame(sure::resids(ord.grow.N.selected))
dataset.resid.grow.N <- data.frame(index = rownames(resid.grow.N), resid.grow.N)

# join or match the residuals and the variables by their observation identifier
cor.data.grow.N <- dplyr::inner_join(dataset.resid.grow.N, data.grow.N, by = "index")
names(cor.data.grow.N)[names(cor.data.grow.N) == "sure..resids.ord.grow.N.selected."] <- "resid"

# join to genus.species
cor.data.grow.N$genus.species <- sub(" ", "_", cor.data.grow.N$genus.species)
cor.data.new.grow.N <- as.data.frame(cor.data.grow.N %>%
                                       group_by(genus.species) %>%
                                       summarise(mean.resid = mean(resid)))
cor.data.new.grow.N1 <- setNames(cor.data.new.grow.N$mean.resid, cor.data.new.grow.N$genus.species)

lambda.Ngrow <- phytools::phylosig(fia.tree2, 
                                   cor.data.new.grow.N1,
                                   method = "lambda",
                                   test=TRUE, 
                                   nsim = 10000)
print(lambda.Ngrow)
# Phylogenetic signal lambda : 0.0000733137 
# logL(lambda) : -238.349 
# LR(lambda=0) : -0.00371839 
# P-value (based on LR test) : 1 

K.Ngrow <- phytools::phylosig(fia.tree2, 
                              cor.data.new.grow.N1,
                              method = "K",
                              test=TRUE, 
                              nsim = 10000)
print(K.Ngrow)
# Phylogenetic signal K : 0.160339 
# P-value (based on 10000 randomizations) : 0.424 
# note the above value will differ slightly each run

# model residuals - N growth (intercept-only model)
data.grow.N$index <- rownames(data.grow.N)
resid.grow.N.int <- as.data.frame(sure::resids(ord.grow.N.int))
dataset.resid.grow.N.int <- data.frame(index = rownames(resid.grow.N.int), resid.grow.N.int)

# join or match the residuals and the variables by their observation identifier
cor.data.grow.N.int <- dplyr::inner_join(dataset.resid.grow.N.int, data.grow.N, by = "index")
names(cor.data.grow.N.int)[names(cor.data.grow.N.int) == "sure..resids.ord.grow.N.int."] <- "resid"

# join to genus.species
cor.data.grow.N.int$genus.species <- sub(" ", "_", cor.data.grow.N.int$genus.species)
cor.data.new.grow.N.int <- as.data.frame(cor.data.grow.N.int %>%
                                           group_by(genus.species) %>%
                                           summarise(mean.resid = mean(resid)))
cor.data.new.grow.N1.int <- setNames(cor.data.new.grow.N.int$mean.resid, cor.data.new.grow.N.int$genus.species)

lambda.Ngrow.int <- phytools::phylosig(fia.tree2, 
                                       cor.data.new.grow.N1.int,
                                       method = "lambda",
                                       test=TRUE, 
                                       nsim = 10000)
print(lambda.Ngrow.int)
# Phylogenetic signal lambda : 0.0000733137 
# logL(lambda) : -225.838 
# LR(lambda=0) : -0.00023597 
# P-value (based on LR test) : 1 

K.Ngrow.int <- phytools::phylosig(fia.tree2, 
                                  cor.data.new.grow.N1.int,
                                  method = "K",
                                  test=TRUE, 
                                  nsim = 10000)
print(K.Ngrow.int)
# Phylogenetic signal K : 0.192972 
# P-value (based on 10000 randomizations) : 0.0807 

##### Nitrogen survival
# model residuals - N survival
data.surv.N$index <- rownames(data.surv.N)
resid.surv.N <- as.data.frame(sure::resids(ord.surv.N.selected))
dataset.resid.surv.N <- data.frame(index = rownames(resid.surv.N), resid.surv.N)

# join or match the residuals and the variables by their observation identifier
cor.data.surv.N <- dplyr::inner_join(dataset.resid.surv.N, data.surv.N, by = "index")
names(cor.data.surv.N)[names(cor.data.surv.N) == "sure..resids.ord.surv.N.selected."] <- "resid"

# join to genus.species
cor.data.surv.N$genus.species <- sub(" ", "_", cor.data.surv.N$genus.species)
cor.data.new.surv.N <- as.data.frame(cor.data.surv.N %>%
                                       group_by(genus.species) %>%
                                       summarise(mean.resid = mean(resid)))
cor.data.new.surv.N1 <- setNames(cor.data.new.surv.N$mean.resid, cor.data.new.surv.N$genus.species)

lambda.Nsurv <- phytools::phylosig(fia.tree2, 
                                   cor.data.new.surv.N1,
                                   method = "lambda",
                                   test=TRUE, 
                                   nsim = 10000)
print(lambda.Nsurv)
# Phylogenetic signal lambda : 0.0000733137 
# logL(lambda) : -268.722 
# LR(lambda=0) : -0.00608587 
# P-value (based on LR test) : 1 

K.Nsurv <- phytools::phylosig(fia.tree2, 
                              cor.data.new.surv.N1,
                              method = "K",
                              test=TRUE, 
                              nsim = 10000)
print(K.Nsurv)
# Phylogenetic signal K : 0.142897 
# P-value (based on 10000 randomizations) : 0.4336 

# model residuals - N survival (intercept-only model)
data.surv.N$index <- rownames(data.surv.N)
resid.surv.N.int <- as.data.frame(sure::resids(ord.surv.N.int))
dataset.resid.surv.N.int <- data.frame(index = rownames(resid.surv.N.int), resid.surv.N.int)

# join or match the residuals and the variables by their observation identifier
cor.data.surv.N.int <- dplyr::inner_join(dataset.resid.surv.N.int, data.surv.N, by = "index")
names(cor.data.surv.N.int)[names(cor.data.surv.N.int) == "sure..resids.ord.surv.N.int."] <- "resid"

# join to genus.species
cor.data.surv.N.int$genus.species <- sub(" ", "_", cor.data.surv.N.int$genus.species)
cor.data.new.surv.N.int <- as.data.frame(cor.data.surv.N.int %>%
                                           group_by(genus.species) %>%
                                           summarise(mean.resid = mean(resid)))
cor.data.new.surv.N1.int <- setNames(cor.data.new.surv.N.int$mean.resid, cor.data.new.surv.N.int$genus.species)

lambda.Nsurv.int <- phytools::phylosig(fia.tree2, 
                                       cor.data.new.surv.N1.int,
                                       method = "lambda",
                                       test=TRUE, 
                                       nsim = 10000)
print(lambda.Nsurv.int)
# Phylogenetic signal lambda : 0.0000733137 
# logL(lambda) : -250.185 
# LR(lambda=0) : -0.0057348 
# P-value (based on LR test) : 1  

K.Nsurv.int <- phytools::phylosig(fia.tree2, 
                                  cor.data.new.surv.N1.int,
                                  method = "K",
                                  test=TRUE, 
                                  nsim = 10000)
print(K.Nsurv.int)
# Phylogenetic signal K : 0.143436 
# P-value (based on 10000 randomizations) : 0.3765 

##### Sulfur growth
# model residuals - S growth
data.grow.S$index <- rownames(data.grow.S)
resid.grow.S <- as.data.frame(sure::resids(ord.grow.S.selected))
dataset.resid.grow.S <- data.frame(index = rownames(resid.grow.S), resid.grow.S)

# join or match the residuals and the variables by their observation identifier
cor.data.grow.S <- dplyr::inner_join(dataset.resid.grow.S, data.grow.S, by = "index")
names(cor.data.grow.S)[names(cor.data.grow.S) == "sure..resids.ord.grow.S.selected."] <- "resid"

# join to genus.species
cor.data.grow.S$genus.species <- sub(" ", "_", cor.data.grow.S$genus.species)
cor.data.new.grow.S <- as.data.frame(cor.data.grow.S %>%
                                       group_by(genus.species) %>%
                                       summarise(mean.resid = mean(resid)))
cor.data.new.grow.S1 <- setNames(cor.data.new.grow.S$mean.resid, cor.data.new.grow.S$genus.species)

lambda.Sgrow <- phytools::phylosig(fia.tree2, 
                                   cor.data.new.grow.S1,
                                   method = "lambda",
                                   test=TRUE, 
                                   nsim = 10000)
print(lambda.Sgrow)
# Phylogenetic signal lambda : 0.0000733137 
# logL(lambda) : -218.638 
# LR(lambda=0) : -0.00427381 
# P-value (based on LR test) : 1

K.Sgrow <- phytools::phylosig(fia.tree2, 
                              cor.data.new.grow.S1,
                              method = "K",
                              test=TRUE, 
                              nsim = 10000)
print(K.Sgrow)
# Phylogenetic signal K : 0.158587 
# P-value (based on 10000 randomizations) : 0.3299 

# model residuals - S growth (intercept-only model)
data.grow.S$index <- rownames(data.grow.S)
resid.grow.S.int <- as.data.frame(sure::resids(ord.grow.S.int))
dataset.resid.grow.S.int <- data.frame(index = rownames(resid.grow.S.int), resid.grow.S.int)

# join or match the residuals and the variables by their observation identifier
cor.data.grow.S.int <- dplyr::inner_join(dataset.resid.grow.S.int, data.grow.N, by = "index")
names(cor.data.grow.S.int)[names(cor.data.grow.S.int) == "sure..resids.ord.grow.S.int."] <- "resid"

# join to genus.species
cor.data.grow.S.int$genus.species <- sub(" ", "_", cor.data.grow.S.int$genus.species)
cor.data.new.grow.S.int <- as.data.frame(cor.data.grow.S.int %>%
                                           group_by(genus.species) %>%
                                           summarise(mean.resid = mean(resid)))
cor.data.new.grow.S1.int <- setNames(cor.data.new.grow.S.int$mean.resid, cor.data.new.grow.S.int$genus.species)

lambda.Sgrow.int <- phytools::phylosig(fia.tree2, 
                                       cor.data.new.grow.S1.int,
                                       method = "lambda",
                                       test=TRUE, 
                                       nsim = 10000)
print(lambda.Sgrow.int)
# Phylogenetic signal lambda : 0.0000733137 
# logL(lambda) : -213.773 
# LR(lambda=0) : -0.00114627 
# P-value (based on LR test) : 1 

K.Sgrow.int <- phytools::phylosig(fia.tree2, 
                                  cor.data.new.grow.S1.int,
                                  method = "K",
                                  test=TRUE, 
                                  nsim = 10000)
print(K.Sgrow.int)
# Phylogenetic signal K : 0.147578 
# P-value (based on 10000 randomizations) : 0.5761 

##### Sulfur survival
# model residuals - S survival
data.surv.S$index <- rownames(data.surv.S)
resid.surv.S <- as.data.frame(sure::resids(ord.surv.S.selected))
dataset.resid.surv.S <- data.frame(index = rownames(resid.surv.S), resid.surv.S)

# join or match the residuals and the variables by their observation identifier
cor.data.surv.S <- dplyr::inner_join(dataset.resid.surv.S, data.surv.S, by = "index")
names(cor.data.surv.S)[names(cor.data.surv.S) == "sure..resids.ord.surv.S.selected."] <- "resid"

# join to genus.species
cor.data.surv.S$genus.species <- sub(" ", "_", cor.data.surv.S$genus.species)
cor.data.new.surv.S <- as.data.frame(cor.data.surv.S %>%
                                       group_by(genus.species) %>%
                                       summarise(mean.resid = mean(resid)))
cor.data.new.surv.S1 <- setNames(cor.data.new.surv.S$mean.resid, cor.data.new.surv.S$genus.species)

lambda.Ssurv <- phytools::phylosig(fia.tree2, 
                                   cor.data.new.surv.S1,
                                   method = "lambda",
                                   test=TRUE, 
                                   nsim = 10000)
print(lambda.Ssurv)
# Phylogenetic signal lambda : 0.0245704 
# logL(lambda) : -248.369 
# LR(lambda=0) : 0.386445 
# P-value (based on LR test) : 0.534174 

K.Ssurv <- phytools::phylosig(fia.tree2, 
                              cor.data.new.surv.S1,
                              method = "K",
                              test=TRUE, 
                              nsim = 10000)
print(K.Ssurv)
# Phylogenetic signal K : 0.139231 
# P-value (based on 10000 randomizations) : 0.4849 

# model residuals - S surv (intercept-only model)
data.surv.S$index <- rownames(data.surv.S)
resid.surv.S.int <- as.data.frame(sure::resids(ord.surv.S.int))
dataset.resid.surv.S.int <- data.frame(index = rownames(resid.surv.S.int), resid.surv.S.int)

# join or match the residuals and the variables by their observation identifier
cor.data.surv.S.int <- dplyr::inner_join(dataset.resid.surv.S.int, data.surv.N, by = "index")
names(cor.data.surv.S.int)[names(cor.data.surv.S.int) == "sure..resids.ord.surv.S.int."] <- "resid"

# join to genus.species
cor.data.surv.S.int$genus.species <- sub(" ", "_", cor.data.surv.S.int$genus.species)
cor.data.new.surv.S.int <- as.data.frame(cor.data.surv.S.int %>%
                                           group_by(genus.species) %>%
                                           summarise(mean.resid = mean(resid)))
cor.data.new.surv.S1.int <- setNames(cor.data.new.surv.S.int$mean.resid, cor.data.new.surv.S.int$genus.species)

lambda.Ssurv.int <- phytools::phylosig(fia.tree2, 
                                       cor.data.new.surv.S1.int,
                                       method = "lambda",
                                       test=TRUE, 
                                       nsim = 10000)
print(lambda.Ssurv.int)
# Phylogenetic signal lambda : 0.0368315 
# logL(lambda) : -228.759 
# LR(lambda=0) : 1.09478 
# P-value (based on LR test) : 0.295415 

K.Ssurv.int <- phytools::phylosig(fia.tree2, 
                                  cor.data.new.surv.S1.int,
                                  method = "K",
                                  test=TRUE, 
                                  nsim = 10000)
print(K.Ssurv.int)
# Phylogenetic signal K : 0.130246 
# P-value (based on 10000 randomization) : 0.647 

################################################################################
# 14. Compare 2023 and 2024 outputs mistake found when selecting "best model" 
# in Part 1. Section 5. Note, 2023 file will not be available in SciHub but can 
# reach out to authors for it
# THIS SECTION ADDED AUGUST 2024
################################################################################

data23 <- read.csv("TreeCLA1_combined_df_FFGC_2023.csv",
                           header = T, sep = ",",
                           fileEncoding = 'UTF-8-BOM')

data24 <- read.csv("TreeCLA1_combined_df_FFGC_2024.csv",
                 header = T, sep = ",",
                 fileEncoding = 'UTF-8-BOM')

# first, figure out which rows should be affected

data23.incorrect <- data23 %>% dplyr::filter(new.dAIC >= 4)
dim(data23.incorrect) # 33 rows

data23 %>%
  dplyr::filter(new.dAIC >= 4) %>%
  dplyr::group_by(process) %>%
  dplyr::summarise(n = dplyr::n()) 

# 29 growth and 4 survival responses

data23 %>%
  dplyr::filter(new.dAIC >= 4) %>%
  dplyr::group_by(spcd, division) %>%
  dplyr::summarise(n = dplyr::n()) 

# 19 species

data24.incorrect <- data24 %>% dplyr::filter(new.dAIC >= 4)
dim(data24.incorrect) # 0 rows because we fixed the error (whew)

# okay, let's see the shape response and CL changes
# rename columns

data23.sub <-
  data23 %>%
  dplyr::select(c(spcd, genus.species, division, process,
                  N.shape, S.shape, NS.shape,
                  n1, s1T, s1bar)) %>%
  dplyr::rename(N.shape.23 = N.shape,
                S.shape.23 = S.shape,
                NS.shape.23 = NS.shape,
                n1.23 = n1,
                s1T.23 = s1T,
                s1bar.23 = s1bar)

data24.sub <-
  data24 %>%
  dplyr::select(c(spcd, genus.species, division, process,
                  N.shape, S.shape, NS.shape,
                  n1, s1T, s1bar)) %>%
  dplyr::rename(N.shape.24 = N.shape,
                S.shape.24 = S.shape,
                NS.shape.24 = NS.shape,
                n1.24 = n1,
                s1T.24 = s1T,
                s1bar.24 = s1bar)

data2324 <- merge(x = data23.sub, y = data24.sub, 
                   by = c("spcd", "genus.species", "division", "process"),
                  all = T)


# 29 mismatches for growth
print(grow.mistmatch <-
  data2324 %>%
  dplyr::filter(process == "growth") %>%
  dplyr::filter(is.na(N.shape.24) & !is.na(N.shape.23)) %>%
  dplyr::select(spcd, genus.species, division, process, N.shape.23, N.shape.24,
                S.shape.23, S.shape.24) %>%
  dplyr::arrange(genus.species, division))

# spcd         genus.species division process N.shape.23 N.shape.24 S.shape.23 S.shape.24
# 1   312     Acer macrophyllum       24  growth   increase       <NA>   decrease       <NA>
#   2   312     Acer macrophyllum    CONUS  growth   increase       <NA>       flat       <NA>
#   3   318        Acer saccharum       22  growth   unimodal       <NA>       flat       <NA>
#   4   391  Carpinus caroliniana    CONUS  growth       flat       <NA>   decrease       <NA>
#   5   409            Carya alba       22  growth   increase       <NA>       flat       <NA>
#   6   409            Carya alba    CONUS  growth       flat       <NA>       flat       <NA>
#   7   407           Carya ovata       22  growth   increase       <NA>       flat       <NA>
#   8   461      Celtis laevigata       23  growth   unimodal       <NA>   tabletop       <NA>
#   9   461      Celtis laevigata    CONUS  growth       flat       <NA>   tabletop       <NA>
#   10  521  Diospyros virginiana       22  growth       flat       <NA>       flat       <NA>
#   11  541    Fraxinus americana       22  growth   unimodal       <NA>   tabletop       <NA>
#   12  762       Prunus serotina       22  growth   unimodal       <NA>       flat       <NA>
#   13  762       Prunus serotina       25  growth   increase       <NA>       flat       <NA>
#   14  762       Prunus serotina    CONUS  growth   unimodal       <NA>   tabletop       <NA>
#   15  802          Quercus alba       25  growth   increase       <NA>       flat       <NA>
#   16  812       Quercus falcata       22  growth   unimodal       <NA>       flat       <NA>
#   17  812       Quercus falcata       23  growth   unimodal       <NA>   tabletop       <NA>
#   18  822        Quercus lyrata       23  growth       flat       <NA>       flat       <NA>
#   19  822        Quercus lyrata    CONUS  growth       flat       <NA>       flat       <NA>
#   20  826 Quercus muehlenbergii       22  growth   increase       <NA>   decrease       <NA>
#   21  826 Quercus muehlenbergii    CONUS  growth   increase       <NA>   tabletop       <NA>
#   22  833         Quercus rubra       22  growth   increase       <NA>   tabletop       <NA>
#   23  833         Quercus rubra       23  growth       flat       <NA>       flat       <NA>
#   24  835      Quercus stellata       23  growth       flat       <NA>       flat       <NA>
#   25  263    Tsuga heterophylla       24  growth   unimodal       <NA>       flat       <NA>
#   26  263    Tsuga heterophylla    CONUS  growth   unimodal       <NA>   tabletop       <NA>
#   27  971           Ulmus alata       22  growth       flat       <NA>       flat       <NA>
#   28  971           Ulmus alata       23  growth       flat       <NA>       flat       <NA>
#   29  971           Ulmus alata    CONUS  growth       flat       <NA>       flat       <NA>

# 4 mistmatches
print(surv.mistmatch <-
        data2324 %>%
        dplyr::filter(process == "survival") %>%
        dplyr::filter(is.na(N.shape.24) & !is.na(N.shape.23))  %>%
        dplyr::select(spcd, genus.species, division, process, 
                      N.shape.23, N.shape.24, S.shape.23, S.shape.24) %>%
  dplyr::arrange(genus.species, division))

# spcd     genus.species division  process N.shape.23 N.shape.24 S.shape.23 S.shape.24
# 1  402 Carya cordiformis       25 survival       flat       <NA>       flat       <NA>
#  2  105   Pinus banksiana       22 survival   decrease       <NA>   decrease       <NA>
#  3  802      Quercus alba       22 survival   unimodal       <NA>   tabletop       <NA>
#  4  971       Ulmus alata       22 survival       flat       <NA>   tabletop       <NA>

# now check parameters

print(n1.mistmatch <-
        data2324 %>%
        dplyr::filter(
          # (1) n1.24 is NA, but n1.23 is filled in (should be the only type)
          is.na(n1.24) & !is.na(n1.23) |
          # (2) n1.24 is not equal to n1.23 
          n1.24 != n1.23 | 
          # (3) n1.23 is NA, but n1.24 is filled in
          is.na(n1.23) & !is.na(n1.24)) %>%
        dplyr::select(spcd, genus.species, division, process, 
                      n1.24, n1.23) %>%
        dplyr::arrange(genus.species, division, process))

# spcd         genus.species division  process n1.24      n1.23
# 1   312     Acer macrophyllum       24   growth    NA  24.983980
# 2   312     Acer macrophyllum    CONUS   growth    NA  18.124910
# 3   318        Acer saccharum       22   growth    NA  12.773480
# 4   409            Carya alba       22   growth    NA 109.884900
# 5   407           Carya ovata       22   growth    NA 102.922100
# 6   461      Celtis laevigata       23   growth    NA  16.624450
# 7   541    Fraxinus americana       22   growth    NA  14.864320
# 8   105       Pinus banksiana       22 survival    NA   2.142751
# 9   762       Prunus serotina       22   growth    NA  11.696060
# 10  762       Prunus serotina       25   growth    NA  36.616760
# 11  762       Prunus serotina    CONUS   growth    NA  15.942860
# 12  802          Quercus alba       22 survival    NA   4.771976
# 13  802          Quercus alba       25   growth    NA 109.915400
# 14  812       Quercus falcata       22   growth    NA  12.679620
# 15  812       Quercus falcata       23   growth    NA  10.112130
# 16  826 Quercus muehlenbergii       22   growth    NA 109.232800
# 17  826 Quercus muehlenbergii    CONUS   growth    NA 108.090700
# 18  833         Quercus rubra       22   growth    NA 109.918100
# 19  263    Tsuga heterophylla       24   growth    NA   6.265956
# 20  263    Tsuga heterophylla    CONUS   growth    NA   5.949018

print(s1.mistmatch <-
        data2324 %>%
        dplyr::filter(
          (# (1) s1T.24 is NA, but s1T.23 is filled in (should be the only type)
          is.na(s1T.24) & !is.na(s1T.23) |
          # (2) s1T.24 is not equal to s1T.23 
          s1T.24 != s1T.23 | 
          # (3) s1T.23 is NA, but s1T.24 is filled in
          is.na(s1T.23) & !is.na(s1T.24)) |
          (# (1) s1bar.24 is NA, but s1bar.23 is filled in (should be the only type)
          is.na(s1bar.24) & !is.na(s1bar.23) |
          # (2) s1bar.24 is not equal to s1bar.23 
          s1bar.24 != s1bar.23 | 
          # (3) s1bar.23 is NA, but s1bar.24 is filled in
          is.na(s1bar.23) & !is.na(s1bar.24))) %>%
        dplyr::select(spcd, genus.species, division, process, 
                      s1T.23, s1T.24, s1bar.23, s1bar.24) %>%
        dplyr::arrange(genus.species, division, process))

# spcd         genus.species division  process    s1T.23 s1T.24  s1bar.23 s1bar.24
# 1   312     Acer macrophyllum       24   growth        NA     NA 0.2025470       NA
# 2   391  Carpinus caroliniana    CONUS   growth        NA     NA 0.5406178       NA
# 3   461      Celtis laevigata       23   growth 14.976350     NA        NA       NA
# 4   461      Celtis laevigata    CONUS   growth 14.783900     NA        NA       NA
# 5   541    Fraxinus americana       22   growth 36.125260     NA        NA       NA
# 6   105       Pinus banksiana       22 survival        NA     NA 0.2255955       NA
# 7   762       Prunus serotina    CONUS   growth 16.947130     NA        NA       NA
# 8   802          Quercus alba       22 survival 36.413870     NA        NA       NA
# 9   812       Quercus falcata       23   growth  9.000122     NA        NA       NA
# 10  826 Quercus muehlenbergii       22   growth        NA     NA 0.1394096       NA
# 11  826 Quercus muehlenbergii    CONUS   growth  4.391339     NA        NA       NA
# 12  833         Quercus rubra       22   growth 36.263690     NA        NA       NA
# 13  263    Tsuga heterophylla    CONUS   growth  4.165275     NA        NA       NA
# 14  971           Ulmus alata       22 survival 12.351420     NA        NA       NA

################################################################################
# END CODE
################################################################################